*-------------------------------------------------------------------------------
* TABLE 2. PREDICTIONS 
*-------------------------------------------------------------------------------

/*
NOTES/QUESTIONS:

	- Original do file path: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SSPP/predictionsTable.do

	*** For Bailey:
	- It seems like using the two different datasets (clean_panel_* and means_coefs_) is redundant.
	- The one thing that I'm uncertain is why the standard errors are different in means_coefs_* datasets than the ones we computed first...
	- The numbers in the table can just come from clean_panel_* datasets. So, why need to use the means_coefs_* datasets?

	- In clean_panel_* datasets, there are no labels in the variables. Need documentation on what variables represent what.
	
	- Please label all the variables. 
*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

*-------------------------------------------------------------------------------
* CALCULATE THE STANDARD ERROR OF THE MEAN
*-------------------------------------------------------------------------------

* Load Panel A dataset // 8 question variables in Panel A
project, original("$da/clean_panel_A_final.csv")
import delimited using "$da/clean_panel_A_final.csv", clear  varn(1)
foreach var of varlist q* {
	count if !mi(`var')
	assert `r(N)'==61 
}

* Generate the s.e. of the mean from the raw data 
local n = 8 
foreach var of varlist q* {
	local n = `n' +1 
	summ `var', d
	*display "`=`r(sd)'/sqrt(`r(N)')'"
	local var`n'_sem  = string(`=`r(sd)'/sqrt(`r(N)')', "%15.2fc")
	
	display r(mean)
	display "Local macro name: var`n'_sem, value: `var`n'_sem'"
	display r(p10)
	display r(p90)
}

* Load Panel B dataset // 3 question variables in Panel B 
project, original("$da/clean_panel_B.csv") preserve
import delimited using "$da/clean_panel_B.csv", clear  varn(1)
count if !mi(q19_1,q20_1,q21_1)
assert `r(N)'==63

* Generate the s.e. of the mean from the raw data 
local n = 3 
foreach var of varlist q19_1 q20_1 q21_1 {
	local n = `n' +1 
	summ `var'
	*display "`=`r(sd)'/sqrt(`r(N)')'"
	local var`n'_sem  = string(`=`r(sd)'/sqrt(`r(N)')', "%15.2fc")
	
	display r(mean)
	display "Local macro name: var`n'_sem, value: `var`n'_sem'"
	display r(p10)
	display r(p90)
}

*-------------------------------------------------------------------------------
* CREATE PREDICTION TABLE 
*-------------------------------------------------------------------------------

* Import + Append the summary statistics 
project, original("$da/means_coefs_A.csv") preserve
import delimited using "$da/means_coefs_A.csv", clear  varn(1)
preserve 
	project, original("$da/means_coefs_B.csv") preserve
	import delimited using "$da/means_coefs_B.csv", clear  varn(1)
	tempfile panelb 
	save `panelb', replace 
restore 
append using `panelb', gen(panel)

keep if type=="Prediction"

replace var_name = ustrregexra(var_name,"Predicted ","")
replace var_name = ustrregexra(var_name,"4-12 months","Midline")
replace var_name = ustrregexra(var_name,"12-18 months","Endline")

destring percentile_10 percentile_90, replace 
rename percentile_* p_*

* Panel A
file open fh using "$dtab/predictions_panela.tex", replace write
forv n = 9/16 {
	foreach var in mean p_10 p_90 {
		summ `var' if v1==`n'
		loc var`n'_`var'  = string(`r(mean)', "%15.2fc")
		
	}
	levelsof var_name if v1==`n', local(name)  clean
	
	file write fh " `name' & `var`n'_mean' & `var`n'_sem' & `var`n'_p_10' & `var`n'_p_90' & 61  \\  [0.1em] " _n
}
file close fh 
project, creates("$dtab/predictions_panela.tex") preserve 

* Panel B
file open fh using "$dtab/predictions_panelb.tex", replace write
forv n = 4/6 {
	foreach var in mean p_10 p_90 {
		summ `var' if v1==`n'
		loc var`n'_`var'  = string(`r(mean)', "%15.2fc")
		
	}
	levelsof var_name if v1==`n', local(name)  clean
	
	file write fh " `name' & `var`n'_mean' & `var`n'_sem' & `var`n'_p_10' & `var`n'_p_90' & 63 \\  [0.1em] " _n
}
file close fh 
project, creates("$dtab/predictions_panelb.tex") preserve
