*-------------------------------------------------------------------------------
* TABLE 3. PANEL RETENTION AND COMPLIANCE
*-------------------------------------------------------------------------------

/*
NOTES/QUESTIONS: 

	- Original do file path: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/1_attrition_compliance.do

	- Double-check this file as this comes from many different rounds.
	- Fixing localities code should be taken care in the construction part (not in analysis part).
	
*/

clear all
set more off
program drop _all
set maxvar 10000


* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

*-------------------------------------------------------------------------------
* ATTRITION
*-------------------------------------------------------------------------------

project, original("$da/SampleList_Final_deid.dta")
use "$da/SampleList_Final_deid.dta", replace

g A_HighSubsidy = .
	replace A_HighSubsidy = 0 if regex(Assignment, "FC")
	replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")
g A_LowSubsidy = .
	replace A_LowSubsidy = 0 if regex(Assignment, "REC") 
	replace A_LowSubsidy = 1 if regex(Assignment, "RET")
drop if A_HighSubsidy==. & A_LowSubsidy==.

ta A_HighSubsidy A_LowSubsidy, m
ta A_HighSubsidy
	
* Fix Localities 
replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"

project, original("$da/LocalityAssignments_Complete.dta") preserve
merge m:1 LocalityName using "$da/LocalityAssignments_Complete.dta", assert(2 3) keep(3) ///
	keepusing(LocalityName _ID order GOVCODE FTreatment RETreatment) nogen //_ID and order have 334 unique vars (if keep 2 and 3, which looks right)

rename GOVCODE Gov

* Check that treatment assignment is the same across files to double check its right
assert FTreatment=="Control" if Assignment=="In-FControl"
assert FTreatment=="Treatment" if Assignment=="In-FLEXTreat"
assert RETreatment=="Control" if Assignment=="In-REControl"
assert RETreatment=="Treatment" if Assignment=="In-RETreat"

* Merge in locality quartiles
preserve 
	project, original("$da/LocalityAssignments_Quartiles.dta") preserve
	use  "$da/LocalityAssignments_Quartiles.dta", clear 
	replace LocalityName = subinstr(LocalityName, "`=char(10)'" , "" , . )
	tempfile quartiles 
	save `quartiles',replace 
restore 

merge m:1 LocalityName using `quartiles',  assert(2 3) keep(3) ///
	keepusing(MAQuartile IRQuartile)

drop locality LocalityName _ID _merge //a bunch of not-right locality vars 
rename order Locality

* Phone survey 1
preserve
	project, original("$da/PS_all_outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/PS_all_outcomes.dta"
	as _merge!=2
	g attrition=.
		replace attrition=1 if _merge==1
		replace attrition=0 if _merge==3 
	g Retention = 100*(1 - attrition)
	su Retention if !mi(A_HighSubsidy)
		gl r1 = string(r(mean), "%15.1fc") 
		gl r1_N = string(r(N), "%15.0fc")
	su Retention if A_HighSubsidy==0
		gl r1_c = string(r(mean), "%15.1fc")
	su Retention if A_HighSubsidy==1
		gl r1_t = string(r(mean), "%15.1fc")
	reg Retention A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl r1_p = string(`M'[4,1], "%15.3fc")
	ta Retention if !mi(A_HighSubsidy)
	su Retention if A_HighSubsidy==0
		loc m1 = r(mean)
	su Retention if A_HighSubsidy==1
		loc m2 = r(mean)
	di `m2' - `m1' 
	di scalar(`M'[1,1])
restore 

* Face to face
preserve
	project, original("$da/F2F_Outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/F2F_Outcomes.dta" 
	as _merge!=2
	g attrition=.
		replace attrition=1 if _merge==1
		replace attrition=0 if _merge==3 
	g Retention = 100*(1 - attrition)
	su Retention if !mi(A_HighSubsidy)
		gl r2 = string(r(mean), "%15.1fc")
		gl r2_N = string(r(N), "%15.0fc")
	su Retention if A_HighSubsidy==0  
		gl r2_c = string(r(mean), "%15.1fc")
	su Retention if A_HighSubsidy==1  
		gl r2_t = string(r(mean), "%15.1fc")
	reg Retention A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		mat list `M' 
		gl r2_p = string(`M'[4,1], "%15.3fc")
		ta Retention if !mi(A_HighSubsidy)
restore

* Phone survey 2
preserve
	project, original("$da/RCT_PS2_all_outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/RCT_PS2_all_outcomes.dta"
	as _merge!=2
	g attrition=.
		replace attrition=1 if _merge==1
		replace attrition=0 if _merge==3 
	g Retention = 100*(1 - attrition)
	su Retention if !mi(A_HighSubsidy)
		gl r3 = string(r(mean), "%15.1fc")
		gl r3_N = string(r(N), "%15.0fc")
	su Retention if A_HighSubsidy==0  
		gl r3_c = string(r(mean), "%15.1fc")
	su Retention if A_HighSubsidy==1  
		gl r3_t = string(r(mean), "%15.1fc")
	reg Retention A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl r3_p = string(`M'[4,1], "%15.3fc")
	ta Retention if !mi(A_HighSubsidy)
restore	
	
* ANY ATTRITION
preserve
	project, original("$da/PS_all_outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/PS_all_outcomes.dta", assert(1 3) gen(round1) keepusing(IID Key_USE)
	
	project, original("$da/F2F_Outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/F2F_Outcomes.dta", assert(1 3) gen(round2) keepusing(IID Key_USE)
	
	project, original("$da/RCT_PS2_all_outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/RCT_PS2_all_outcomes.dta", assert(1 3) gen(round3) keepusing(IID Key_USE)

	g       ever_found = .
	replace ever_found = 0   if round1==1 & round2==1 & round3 == 1
	replace ever_found = 100 if round1==3 | round2==3 | round3 == 3
	
	g times_found = .
	replace times_found = 0 if round1==1 & round2==1 & round3 == 1
	replace times_found = 1 if round1==3
	replace times_found = times_found + 1 if round2==3
	replace times_found = times_found + 1 if round3==3
	
	ta times_found ever_found if !mi(A_H), m 
	ta ever_found if !mi(A_HighSubsidy)
	ta round1  if !mi(A_HighSubsidy)
	ta round2  if !mi(A_HighSubsidy)
	ta round3 if !mi(A_HighSubsidy)
	
	su ever_found if !mi(A_HighSubsidy)
		gl ever = string(r(mean), "%15.1fc")
		gl ever_N = string(r(N), "%15.0fc")
	su ever_found if A_HighSubsidy==0  
		gl ever_c = string(r(mean), "%15.1fc")
	su ever_found if A_HighSubsidy==1  
		gl ever_t = string(r(mean), "%15.1fc")
	reg ever_found A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl ever_p = string(`M'[4,1], "%15.3fc")
		tempfile attrition
		save `attrition', replace 
restore

preserve 
	project, original("$da/PooledAll.dta") preserve
	use "$da/PooledAll.dta", clear
	keep if round == 1
	drop _merge
	
	merge 1:1 IID using `attrition'
		gl HighSubsidyX FemaleFR i.AgeFR i.HighSubsidyQrt i.Month_Year HighScMoreLow /// 
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile 
		gl vars hhsize_pool FemaleFR AgeFR kids_hh_pool toilet filter subj_health
	reg times_found $vars ${HighSubsidyX} if !mi(A_H), r cl(Locality)
		test $vars
restore

* Social cohesion
preserve
	project, original("$da/NS_sample_deidentified.dta") preserve
	use "$da/NS_sample_deidentified.dta", clear		

	duplicates report IID 
	assert  `r(unique_value)' ==  2145 & `r(N)'==2146
						  
	count if IID == "31691984"
	assert `r(N)'==2

	* start time of interview 
	levelsof q101 if IID == "31691984"
	assert "`r(levels)'" == "33365.75 43982.704"
	
	* drop the later interview 
	drop if IID == "31691984" & q101==43982.704

	duplicates report IID 
	assert  `r(unique_value)' ==  2145 & `r(N)'==2145
	unique Key_USE
	drop if mi(Key_USE) //3 cases
	tempfile sc 
	save `sc', replace 
restore
	
preserve
	unique Key_USE
	tostring IID, replace
	merge 1:1 Key_USE using `sc'
	as _merge!=2
	g attrition=.
		replace attrition=1 if _merge==1
		replace attrition=0 if _merge==3 
	g Retention = 100*(1 - attrition)
	su Retention if !mi(A_HighSubsidy)
		gl sc3 = string(r(mean), "%15.1fc")
		gl sc3_N = string(r(N), "%15.0fc")
	su Retention if A_HighSubsidy==0  
		gl sc3_c = string(r(mean), "%15.1fc")
	su Retention if A_HighSubsidy==1  
		gl sc3_t = string(r(mean), "%15.1fc")
	reg Retention A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl sc3_p = string(`M'[4,1], "%15.3fc")
	ta Retention if !mi(A_HighSubsidy)
restore


*-------------------------------------------------------------------------------
* CREATE TABLES
*-------------------------------------------------------------------------------

cap file close
file open fh using "$dtab/attrition1.tex", replace write
	file write fh " All             & $ever\%    & $r1\%   & $r2\%    & $r3\% \\  " _n
	file write fh " Treatment       & $ever_t\%  & $r1_t\% & $r2_t\%  & $r3_t\% \\  " _n
	file write fh " Control         & $ever_c\%  & $r1_c\% & $r2_c\%  & $r3_c\% \\  " _n
	file write fh " p-value (T-C)   & $ever_p    & $r1_p   & $r2_p    & $r3_p  \\  " _n
	file write fh " N               & $ever_N    & $r1_N   & $r2_N    & $r3_N  \\  " _n
	file write fh "\midrule" _n
file close fh 
project, creates("$dtab/attrition1.tex") preserve
	
cap file close
file open fh using "$dtab/attrition2.tex", replace write
	file write fh " All             & $sc3\%   & --   & --   & -- \\  " _n
	file write fh " Treatment       & $sc3_t\% & --   & --   &  -- \\  " _n
	file write fh " Control         & $sc3_c\% & --   & --   &  -- \\  " _n
	file write fh " p-value (T-C)   & $sc3_p   & --   & --   & --  \\  " _n
	file write fh " N               & $sc3_N   & --   & --   &  --  \\  " _n
	file write fh "\bottomrule" _n
file close fh 
project, creates("$dtab/attrition2.tex") preserve
	
	
*-------------------------------------------------------------------------------
* COMPLIANCE/TAKE-UP
*-------------------------------------------------------------------------------

project, original("$da/compliance_all.dta") preserve
merge 1:1 Key using "$da/compliance_all.dta", nogen

drop assign_flex 
ren receiveflex T_HighSubsidy
ta A_HighSubsidy T_HighSubsidy, m
ta T Assignment, m
g Complied = 100*(T_HighSubsidy)

* Phone survey 1
preserve
	project, original("$da/PS_all_outcomes.dta") preserve
	merge 1:1 Key using "$da/PS_all_outcomes.dta"
	as _merge!=2
	su Complied if !mi(A_HighSubsidy) & _merge==3
		gl compl1 = string(r(mean), "%15.1fc")
		gl compl1_N = string(r(N), "%15.0fc")
	su Complied if A_HighSubsidy==0  & _merge==3
		gl compl1_c = string(r(mean), "%15.1fc")
	su Complied if A_HighSubsidy==1 & _merge==3
		gl compl1_t = string(r(mean), "%15.1fc")
	reg Complied A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl compl1_p = string(`M'[4,1], "%15.3fc")
restore 

* Face to face
preserve
	project, original("$da/F2F_Outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/F2F_Outcomes.dta" 
	as _merge!=2
	su Complied if !mi(A_HighSubsidy) & _merge==3
		gl compl2 = string(r(mean), "%15.1fc")
		gl compl2_N = string(r(N), "%15.0fc")
	su Complied if A_HighSubsidy==0  & _merge==3
		gl compl2_c = string(r(mean), "%15.1fc")
	su Complied if A_HighSubsidy==1 & _merge==3
		gl compl2_t = string(r(mean), "%15.1fc")
	reg Complied A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl compl2_p = string(`M'[4,1], "%15.3fc")
restore

* Phone survey 2
preserve
	project, original("$da/RCT_PS2_all_outcomes.dta") preserve
	merge 1:1 Key_USE using "$da/RCT_PS2_all_outcomes.dta"
		as _merge!=2
	su Complied if !mi(A_HighSubsidy) & _merge==3
		gl compl3 = string(r(mean), "%15.1fc")
		gl compl3_N = string(r(N), "%15.0fc")
	su Complied if A_HighSubsidy==0  & _merge==3
		gl compl3_c = string(r(mean), "%15.1fc")
	su Complied if A_HighSubsidy==1 & _merge==3
		gl compl3_t = string(r(mean), "%15.1fc")
	reg Complied A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl compl3_p = string(`M'[4,1], "%15.3fc")
restore	
	
* ANY COMPLIANCE 
preserve
	project, original("$da/PS_all_outcomes.dta") preserve
	merge 1:1 Key using "$da/PS_all_outcomes.dta"
	as _merge!=2
	su Complied if !mi(A_HighSubsidy) 
		gl ever = string(r(mean), "%15.1fc")
		gl ever_N = string(r(N), "%15.0fc")
	su Complied if A_HighSubsidy==0  
		gl ever_c = string(r(mean), "%15.1fc")
	su Complied if A_HighSubsidy==1 
		gl ever_t = string(r(mean), "%15.1fc")
	reg Complied A_HighSubsidy, r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl ever_p = string(`M'[4,1], "%15.3fc")
restore 

*-------------------------------------------------------------------------------
* CREATE TABLE
*-------------------------------------------------------------------------------

cap file close
file open fh using "$dtab/takeup.tex", replace write
	file write fh " All             & $ever\%  & $compl1\%   & $compl2\%    & $compl3\%  \\  " _n
	file write fh " Treatment       & $ever_t\%  & $compl1_t\%   & $compl2_t\%    & $compl3_t\%  \\  " _n
	file write fh " Control         & $ever_c\%  & $compl1_c\%   & $compl2_c\%   & $compl3_c\% \\  " _n
	file write fh " p-value (T-C)   & $ever_p   & $compl1_p   & $compl2_p   & $compl3_p  \\  " _n
	file write fh " N               & $ever_N  & $compl1_N   & $compl2_N   & $compl3_N  \\  " _n
	file write fh "\midrule" _n
file close fh 
project, creates("$dtab/takeup.tex") preserve
