*-------------------------------------------------------------------------------
* TABLE 4 (+ Appendix A1). POOLED TREATMENT EFFECTS (WITH LEE BOUNDS)
*-------------------------------------------------------------------------------

/*
NOTES/QUE STIONS:

	- Original do file path: 
		- Panel A: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/2_primary.do
		- Panel B: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/5_credit.do
		- Panel B: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/4_food.do
	
	- [Solved]: For housing_exp_ppp: the IV regression is run for round 2 only (although there's data for that for both rounds 1 and 2). Why is that?
	- bys round: summ housing_exp_ppp
		- Answer: because the question in round 1 was not precise/wrong. 

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

set seed 5693

*-------------------------------------------------------------------------------
* LOAD THE POOLED DATASET
*-------------------------------------------------------------------------------
project,original("$da/PooledAll.dta") preserve
use "$da/PooledAll.dta", replace	

*-------------------------------------------------------------------------------
* PANEL A: PRIMARY OUTCOMES (6 VARIABLES)
*-------------------------------------------------------------------------------

local table_loc primary
local primary housing_indexHigh housing_exp_ppp log_ConsTot_win LogTotalConsumption CESD_rev_sd SDQ_rev_sd

gl HighSubsidyX FemaleFR i.AgeFR i.HighSubsidyQrt i.Month_Year HighScMoreLow /// 
                HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.round i.enumID_pool

* Regression
local T "High"
	loc i=0	 
	loc n : list sizeof `table_loc'
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ``table_loc'' {
		if "`y'"!="housing_exp_ppp" { 
			ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight], r cl(Locality)
		}
		else { 
			ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if round==2, r cl(Locality)			
		}
		
		tempname M
		mat `M' = r(table)
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
		loc `T'_N_`y' = string(e(N), "%15.0fc")
		qui sum `y' if A_`T'Subsidy==0 & e(sample) 
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]

		levelsof round if e(sample)==1, local(rounds)
		if "`rounds'"=="1 2 3" {
			local `T'_rnd_`y' "1, 2, 3"
		}
		if "`rounds'"=="2 3" {
			local `T'_rnd_`y' "2, 3"
		}
		if "`rounds'"=="2" {
			local `T'_rnd_`y' "2"
		}
	}
	mat list High_plist 
	
	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	mat list High_qlist

	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}

* Outcome labels 
local lab_housing_indexHigh "Overall Housing Quality (Z-Score)"
local lab_housing_exp_ppp "Total Monthly Housing Expenditures (USD PPP)"
local lab_log_ConsTot_win "Food Consumption (Log USD PPP)" 
local lab_LogTotalConsumption "Log Total Consumption (Log USD PPP)"
local lab_SDQ_rev_sd "SDQ Score (Higher: Better Child Wellbelling)"
local lab_CESD_rev_sd "CESD Score (Higher: Less Depression)"

* Create table 
cap file close fh 
file open fh using "$dtab/pooled_`table_loc'.tex", replace write
local q = 0
foreach y in ``table_loc'' {
	local q = `q' + 1
	file write fh " `lab_`y'' & ``T'_b_`y''``T'_star_`y'' & (``T'_se_`y'') &   [``T'qval`q''] &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' & ``T'_rnd_`y'' \\  [0.1em] " _n
}
file close fh 
project, creates("$dtab/pooled_`table_loc'.tex") preserve



*-------------------------------------------------------------------------------
* PANEL B: OTHER OUTCOMES (SAVINGS/CREDIT)
*-------------------------------------------------------------------------------

ren AllSubsidyQrt_H AllSubsidyQrt

loc table_loc credit
loc credit savings30jd lend borrow borrow_amt lend_amt borrow_amtIHS lend_amtIHS

foreach x in `credit' { 
	tabstat `x', by(round)
}
		
* Regression
foreach T in /*All*/ High /*Low*/ { 
	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
	       HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.round i.enumID_pool  
	
	loc i=0	 
	loc n : list sizeof `table_loc'
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ``table_loc'' {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=poolweight], r cl(Locality)
		tempname M
		mat `M' = r(table)
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
		loc `T'_N_`y' = string(e(N), "%15.0fc")
		qui sum `y' if A_`T'Subsidy==0 
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
		
		levelsof round if e(sample)==1, local(rounds)
		if "`rounds'"=="1 2 3" {
			local `T'_rnd_`y' "1, 2, 3"
		}
		if "`rounds'"=="2 3" {
			local `T'_rnd_`y' "2, 3"
		}
		if "`rounds'"=="2" {
			local `T'_rnd_`y' "2"
		}
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}
 
* Outcome labels 
loc lab_savings30jd    "At least 30 JD (95 USD PPP) in savings (=1)"
loc lab_lend  		   "Gave loan (=1)"
loc lab_borrow         "Took loan (=1)"
loc lab_borrow_amt     "Average monthly loans taken, USD PPP"
loc lab_lend_amt       "Average monthly loans given, USD PPP"
loc lab_borrow_amtIHS  "Average monthly loans taken, IHS"
loc lab_lend_amtIHS    "Average monthly loans given, IHS"   

* Create table 
cap file close fh 
file open fh using "$dtab/pooled_panelb_`table_loc'.tex",  replace write
local q = 0 
foreach y in ``table_loc'' {
    local q = `q' + 1
     * High subsidy
     if inlist("`y'","savings30jd")  {
             file write fh " `lab_`y'' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') & [`Highqval`q''] & `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' & `High_rnd_`y'' \\ " _n
     }
}
file close fh
project, creates("$dtab/pooled_panelb_`table_loc'.tex") preserve


*-------------------------------------------------------------------------------
* PANEL B: OTHER OUTCOMES (FOOD)
*-------------------------------------------------------------------------------

local table_loc food
		 
su rCSI_index_High if A_HighSubsidy==0 & round==2
su rCSI_index_High if A_HighSubsidy==0 & round==3	 		
su rCSI_index_Low if A_LowSubsidy==0 & round==2
su rCSI_index_Low if A_LowSubsidy==0 & round==3

* Regression
foreach T in High /*Low*/ {  
	cap rename rCSI_index_`T' rCSI_index
	local food log_ConsTot_win ConsPurchTotPPP_win ConsAssistPPP_win ConsProdTot_jdPPP_win /// 
	     MeatConsumption_win MealConsumption RespHungry AdultHungry child_slp_hgry_7 /// 
		 RespHungryD AdultHungryD child_slp_hgry_7D FoodDiversityTotal rCSI_index food_c_assist_ppp
		 
	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
	       HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.round i.enumID_pool  
	
	loc i=0	 
	loc n : list sizeof `table_loc'
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ``table_loc'' {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=poolweight], r cl(Locality)
		tempname M
		mat `M' = r(table)
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
		loc `T'_N_`y' = string(e(N), "%15.0fc")
		qui sum `y' if A_`T'Subsidy==0 
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
			
		levelsof round if e(sample)==1, local(rounds)
		if "`rounds'"=="1 2 3" {
			local `T'_rnd_`y' "1, 2, 3"
		}
		if "`rounds'"=="2 3" {
			local `T'_rnd_`y' "2, 3"
		}
		if "`rounds'"=="2" {
			local `T'_rnd_`y' "2"
		}
		}
		
		* Q-Values
		minq `T'_plist, q(`T'_qlist) step(0.001)
		forv q=1/`i' {
			loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
		}
	}
  
* Outcome labels 	
loc lab_food_c_assist_ppp   "Food consumption (aid) USD PPP"
loc lab_assist_person       "\textit{per capita} Food consumption (aid) USD PPP"
loc lab_meals_yes           "Number of meals consumed the day prior"
loc lab_overall_food_change "$\Delta$ Overall food consumption vs. pre-covid"
loc lab_cereal_change       "$\Delta$ Cereal consumption vs. pre-covid"
loc lab_meat_change         "$\Delta$ Meat consumption vs. pre-covid"
loc lab_log_ConsTot_win "Total Consumption (Log USD PPP)"
loc lab_ConsPurchTotPPP_win "Out-of-pocket Consumption (USD PPP)"
loc lab_ConsAssistPPP_win "Assistance Consumption (USD PPP)"
loc lab_ConsProdTot_jdPPP_win "Home Production Consumption (USD PPP)"
loc lab_MeatConsumption_win "Meat Consumption"
loc lab_MealConsumption "\# Meals Eaten by Respondent Yesterday"
loc lab_RespHungry "Respondent Hunger Last Week (Days)"
loc lab_AdultHungry "Adult Hunger Last Week (Days)"
loc lab_RespHungryD "Respondent Hunger Last Week (=1)"
loc lab_AdultHungryD "Adult Hunger Last Week (=1)"
loc lab_child_slp_hgry_7D "Child Hunger Last Week (=1)"	
loc lab_child_slp_hgry_7 "Child Hunger Last Week (Days)"
loc lab_FoodDiversityTotal "Food Diversity"
loc lab_rCSI_index_High "Reduced Coping Strategy Index"	
loc lab_rCSI_index_Low "Reduced Coping Strategy Index"	
loc lab_rCSI_index "Reduced Coping Strategy Index"	
loc lab_ food_c_assist_ppp "Food assistance consumption (USD PPP)"

* Create table 
cap file close fh 
file open fh using "$dtab/pooled_panelb_`table_loc'.tex",  replace write
local q = 0 
foreach y in ``table_loc'' {
    local q = `q' + 1
     * High subsidy
     if inlist("`y'","RespHungryD","AdultHungryD","child_slp_hgry_7D")  {
             file write fh " `lab_`y'' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') & [`Highqval`q''] & `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' & `High_rnd_`y'' \\ " _n
     }
}
file close fh
project, creates("$dtab/pooled_panelb_`table_loc'.tex") preserve

