*-------------------------------------------------------------------------------
* TABLE 5 (+ Appendix A2): Midline (with Lee Bounds)
*-------------------------------------------------------------------------------

/*
NOTES/QUE STIONS:

	- Original do file path: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/Phone Survey/4. Analyze/code/main/TOT_Regressions.do
	
	- Lower Lee bounds are a little off but not a concern (I set seed...)

*/

/*
OUTCOMES:

Panel A (Housing Improvements): filter occupied_rooms
Panel B (Loans): loan_pre_covid loan_at_covid loan_aft_covid
Panel C (Food Aid and Insecurity): food_c_assist_ppp_w assist_person_w hungry_fr hungry_bi_other hungry_bi_child 
Panel D (Household Recomposition): n_children boys_13to17_hh
Panel E (Covid 19): tot_covid_sympt  tot_sympt_hh sympt_child health_visits_w not_kept_distance
Paenl F (Other effects): school_day_per_child alert_child_flex Self_Care_z learn_activities travel_network_flex 

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

set seed 5693

*-------------------------------------------------------------------------------
* IMPORT DATA 
*-------------------------------------------------------------------------------

* Load the all outcomes dataset 
project, original("$da/PS_all_outcomes.dta")
use "$da/PS_all_outcomes.dta", clear

* Merge with controls dataset 
project, uses("$da/PS_controls_clean.dta") preserve
merge 1:1 Key_USE using "$da/PS_controls_clean.dta", generate(_in_ps_controls)
	drop if _in_ps_controls==2

* Fix inconsistencies in localities
replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"
replace locality=302 if LocalityName=="Alhusban"
replace locality=302 if LocalityName=="Alrabya"

drop district subdistrict Governorate mafraq irbid

* Merge with localities dataset 
project, original("$da/localities.dta") preserve
merge m:1 LocalityName locality using "$da/localities.dta"
	
keep if _merge==3
drop _merge locality
rename order locality 
	label define treat 0 "Control" 1 "Treat"
	label val assign_flex treat
	label val assign_re treat
encode Governorate, gen(gov)
	label drop gov
	label define gov 0 "Irbid" 1 "Mafraq"
replace gov = 0 if gov == 1
replace gov = 1 if gov == 2
	label val gov gov
	encode District, gen(district)
rename Subdistrict subdistrict
rename SubdistrictID subdistrict_id
	encode enumerator_name, gen(enumerator)
	label val enumerator
	label define enum 1 "Enumerator1" 2 "Enumerator2" 3 "Enumerator3" 4 "Enumerator4"
	label define enum 5 "Enumerator5" 6 "Enumerator6" 7 "Enumerator7", add
	label define enum 8 "Enumerator8" 9 "Enumerator9" 10 "Enumerator10", add
	label define enum 11 "Enumerator11" 12 "Enumerator12" 13 "Enumerator13", add
	label define enum 14 "Enumerator14" 15 "Enumerator15" 16 "Enumerator16", add
	label define enum 17 "Enumerator17" 18 "Enumerator18" 19 "Enumerator19", add
	label val enumerator enum

gen female_endline = (gender==2) if gender!=.
egen agecat_endline = cut(q202a), at(18,30,40,50,60,70,85)
gen pc_housing_exp0_w=housing_exp_ppp_w/hhsize_b
	
* Add weights
project, original("$da/duplicateWeights.dta") preserve
merge 1:1 IID using "$da/duplicateWeights.dta"
	ta _merge 
	drop if _merge==2
	drop _merge
	ren locality Locality
	
* Add lee bounds 
project, original("$da/SampleList_Final_deid.dta") preserve
merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta"

g retention = _merge==3 if !mi(_merge)
	as _merge!=1
	drop _merge
	
g A_HighSubsidy = .
	replace A_HighSubsidy = 0 if regex(Assignment, "FC")
	replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")
g A_LowSubsidy = .
	replace A_LowSubsidy = 0 if regex(Assignment, "REC") 
	replace A_LowSubsidy = 1 if regex(Assignment, "RET")
	drop if A_HighSubsidy==. & A_LowSubsidy==.
	ta A_HighSubsidy A_LowSubsidy, m
	ta A_HighSubsidy

	tabstat retention, by(A_HighSubsidy) stat(mean N)
	count if A_HighSubsidy==1
	as r(N)==990
	count if A_HighSubsidy==0
	as r(N)==1027

	
*-------------------------------------------------------------------------------
* DEFINE GLOBALS
*-------------------------------------------------------------------------------

g T_HighSubsidy = receiveflex
g T_LowSubsidy  = receivere
	
g housing_indexAll = housing_index_all
g housing_indexLow = housing_index_re
g housing_indexHigh = housing_index_flex
	
g cesd_normAll = cesd_norm_all 
g cesd_normLow = cesd_norm_re 
g cesd_normHigh = cesd_norm_flex 
	
g perceived_stressAll = perceived_stress_all
g perceived_stressLow = perceived_stress_re
g perceived_stressHigh = perceived_stress_flex
	
g covid_sympt_indexAll = covid_sympt_index_all
g covid_sympt_indexLow = covid_sympt_index_re
g covid_sympt_indexHigh = covid_sympt_index_flex

g covid_behav_indexAll = covid_behav_index_all
g covid_behav_indexLow = covid_behav_index_re
g covid_behav_indexHigh = covid_behav_index_flex
	
foreach x in T A { 
	g `x'_AllSubsidy=1 if `x'_HighSubsidy==1 | `x'_LowSubsidy==1
	replace `x'_AllSubsidy=0 if `x'_HighSubsidy==0 | `x'_LowSubsidy==0
		
	ta `x'_AllSubsidy `x'_HighSubsidy, m
	ta `x'_AllSubsidy `x'_LowSubsidy, m		
}

ta A_AllSubsidy T_AllSubsidy, m
	
g HighSubsidyQrt = flex_qrt 
g LowSubsidyQrt = re_qrt 
xtile AllSubsidyQrt = flex_sc if T_HighSubsidy!=. | T_LowSubsidy!=., nq(4)
	
g FLEX_Sample = regex(Assignment, "F")
	
foreach T in High Low All {
	if `"`T'"'=="All" { 
		gl `T'SubsidyX female_endline i.agecat_endline i.`T'SubsidyQrt i.month_yr2 flex_bi /// 
                hhsize_b n_children_b i.gov i.MAQuartile i.IRQuartile i.enumerator i.FLEX_Sample					
	}
	else { 
		gl `T'SubsidyX female_endline i.agecat_endline i.`T'SubsidyQrt i.month_yr2 flex_bi /// 
                hhsize_b n_children_b i.gov i.MAQuartile i.IRQuartile i.enumerator		
	}
}
	
	
*-------------------------------------------------------------------------------
* REGRESSIONS 
// Do them in familities to compute correct values 
*-------------------------------------------------------------------------------

*** Globals + Regressions for each family 

*gl outcomes ///
filter occupied_rooms ///
loan_pre_covid loan_at_covid loan_aft_covid ///
food_c_assist_ppp_w assist_person_w hungry_fr hungry_bi_other hungry_bi_child ///
n_children boys_13to17_hh ///
tot_covid_sympt  tot_sympt_hh sympt_child health_visits_w not_kept_distance ///
school_day_per_child alert_child_flex Self_Care_z learn_activities travel_network_flex 

*** Family1 Dwelling
foreach T in High {
	foreach v in housing_index {
		cap gen `v'=.
		cap replace `v'=`v'`T'
	}
}

gl dwelling housing_index material_index toilet main_pipe main_water_access /// 
		        filter safe_water electr generator shared_hh tot_families rooms occupied_rooms /// 
		        housing_exp_ppp_w pc_housing_exp_ppp_w rent_pay_ppp_w rent_agreed_ppp_w /*debt_ppp_w*/ /// 
		        hhsize tot_id own_house chores_fr childcare_fr chores_childcare_fr chores_childcare_hh locked 
				
foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(dwelling) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${dwelling} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $dwelling { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
	
*** Family2 Expenditure

* Standardized scores for Family2 Expenditure
foreach x in overall_food_change cereal_change meat_change { 
	su `x' if A_HighSubsidy==0
	replace `x' = (`x' - r(mean))/r(sd)
}

gl consumption food_c_assist_ppp_w assist_person_w meals_yes 

foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(consumption) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${consumption} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $consumption { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
				
*** Family5 Migration 
gl migration moved_2019 times_moved travel_network_flex live_camp move_plan

foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(migration) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${migration} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $migration { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

*** Family6 Health 

foreach T in High {
	foreach v in cesd_norm perceived_stress {
		cap gen `v'=.
		cap replace `v'=`v'`T'
	}
}
gl health subj_health Disability1 Disability2 Disability3 Disability4 /// 
		      hungry_fr hungry_bi_other hungry_days_fr hungry_days_other /// 
			  cesd_norm perceived_stress depressed
			  
foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(health) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${health} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $health { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
	
*** Family8 Children
gl child n_children school_day_per_child hungry_days_child hungry_bi_child
			 
foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(child) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${child} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $child { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
	
*** Family(?) Composition
gl composition adults_hh girls_hh boys_hh kids_0to12_hh girls_0to12_hh boys_0to12_hh /// 
		 kids_13to17_hh girls_13to17_hh boys_13to17_hh     
			 
foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(composition) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${composition} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $composition { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
	
*** Family14 Covid 
ren foregone_health_visits foregone_visit
ren income_at_covid_ppp_w income_covid_ppp_w

foreach T in High {
	foreach v in covid_sympt_index covid_behav_index {
		cap gen `v'=.
		cap replace `v'=`v'`T'
	}
}

	gl covid test_covid_adult num_test_covid_adult test_covid_child num_test_covid_child /// 
		     /*pos_covid_hh*/ test_unable tot_covid_sympt covid_sympt_index /// 
		     tot_sympt_hh sympt_child sympt_appear recover_sympt_fr recover_sympt_hh /// 
		     covid_behav_index tot_covid_activities health_visits_w seen_by_prof health_exp_ppp_w /// 
		     medicine_exp_ppp_w foregone_visit denied_service major_health num_major_health /// 
			 overall_food_change cereal_change meat_change /// 
		     /*cesd_levels not_kept_distance attendedchurch*/ /// 
			 learn_activities learn_act_bi /*learn_time_high learn_time_low*/ /// 
		     learn_time happy_child alert_child_flex /// 
			 hr_work_pre_covid_w hr_work_at_covid_w hr_work_aft_covid_w /// 
	         income_pre_covid_ppp_w income_covid_ppp_w income_aft_covid_ppp_w asset_sold_pre_covid /// 
		     asset_sold_at_covid asset_sold_aft_covid miss_days_covid jobloss ///
			 loan_pre_covid log_loan_pre_covid_w loan_at_covid log_loan_at_covid_w /// 
		     loan_aft_covid log_loan_aft_covid_w give_loan_pre_covid give_loan_at_covid give_loan_aft_covid 
			 
foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(covid) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${covid} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $covid { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

*** Indices 
ren q8_2_01abothered_reverse q8_2_01abothered2
ren q8_2_01bconcentration_reverse q8_2_01bconcent2
ren q8_2_01cdepressed_reverse q8_2_01cdepressed2                
ren q8_2_01dnoenergy_reverse q8_2_01dnoenergy2              
ren q8_2_01fafraid_reverse q8_2_01fafraid2                    
ren q8_2_01gpoorsleep_reverse q8_2_01gpoorsleep2                    
ren q8_2_01ilonely_reverse q8_2_01ilonely2                    
ren q8_2_01jmotivation_reverse q8_2_01jmotivation2   

* Generate self-care standardized score 
su Self_Care if A_HighSubsidy==0
g Self_Care_z = (Self_Care-r(mean))/r(sd)

gl indices housing_index quality_floor quality_roof grid drink_pipe ppl_room /// 
			   Disability3 Vision Hearing Mobility Cognition Self_Care_z Communication  /// 
			   cesd_norm q8_2_01ehopeful q8_2_01hhappy q8_2_01abothered2 /// 
               q8_2_01bconcent2 q8_2_01cdepressed2 q8_2_01dnoenergy2 /// 
	           q8_2_01fafraid2 q8_2_01gpoorsleep2 q8_2_01ilonely2 q8_2_01jmotivation2 /// 
			   covid_sympt_index covid_pos_bi tot_covid_sympt /// 
			   covid_behav_index left_home socialgathering not_kept_distance /// 
			   attendedchurch went2market left_village
			   
foreach T in High {

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(indices) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${indices} {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps], r cl(Locality)
		tempname M
		mat `M' = r(table)
		gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
		gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
		gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
		gl `T'_mean_`y'= string(r(mean), "%12.2fc")
		gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}

loc j=0
foreach y in $indices { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}
	
********************************************************************************

*** Variable labels
gl lab_quality_roof				"Quality Roof (=1)"  
gl lab_filter            		"Clean water (=1)"
gl lab_occupied_rooms     		"Occupied Rooms"

gl lab_loan_pre_covid  		    "Loans taken pre-first-lockdown (=1)"
gl lab_loan_at_covid  		    "Loans taken during first lockdown (=1)"
gl lab_loan_aft_covid  		    "Loans taken after first lockdown (=1)"
	
gl lab_food_c_assist_ppp_w 		"Food consumption (aid) USD PPP"
gl lab_assist_person_w     		"Food consumption (aid) USD PPP (\textit{Per capita})"
gl lab_hungry_fr           		"Respondent hunger last week (=1)"
gl lab_hungry_bi_other      	"Adults hunger last week (=1)"
gl lab_hungry_bi_child       	"Child hunger last week (=1)"
	
gl lab_n_children            	"Number of children under 18 years"
gl lab_boys_13to17_hh       	"Number of boys aged 13-17 years in household"
	
gl lab_income_covid_ppp_w  		"Weekly adult income (during first lockdown)"
gl lab_tot_covid_sympt      	"Total COVID-19 symptoms"
gl lab_tot_sympt_hh  		    "Number of people who are symptomatic"
gl lab_sympt_child          	"Number of children who are symptomatic"
gl lab_health_visits_w  		"Number of visits to healthcare institutions"
gl lab_not_kept_distance  		"Did not keep distance (=1)"

gl lab_school_day_per_child  	"Total number of school days attended per child"
gl lab_alert_child_flex      	"Child alertness (s.d. units)"	
gl lab_Self_Care_z           	"Difficulty with self-care (z-score)"
gl lab_learn_activities      	"Number of learning activities"
gl lab_travel_network_flex 		"Respondent networks (s.d. units)"


*-------------------------------------------------------------------------------
* CREATE TABLES 
*-------------------------------------------------------------------------------

* PANEL A
gl panel_a quality_roof filter occupied_rooms
file open fh using "$dtab/midline_panel_a.tex", replace write
local i = 0
foreach T in High { 
	foreach y in $panel_a {
		local i = `i' + 1
			file write fh " ${lab_`y'} & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) & [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file write fh "\midrule" _n
file close fh 
project, creates("$dtab/midline_panel_a.tex") preserve

	
* PANEL E
gl panel_e loan_pre_covid loan_at_covid loan_aft_covid 
file open fh using "$dtab/midline_panel_e.tex", replace write
foreach T in High { 
	foreach y in $panel_e {
		local i = `i' + 1
			file write fh " ${lab_`y'} & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) & [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file write fh "\midrule" _n
file close fh
project, creates("$dtab/midline_panel_e.tex") preserve
 

* PANEL B 
gl panel_b food_c_assist_ppp_w assist_person_w hungry_fr hungry_bi_other hungry_bi_child 
file open fh using "$dtab/midline_panel_b.tex", replace write
foreach T in High { 
	foreach y in $panel_b {
		local i = `i' + 1
			file write fh " ${lab_`y'} & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) & [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file write fh "\midrule" _n
file close fh 
project, creates("$dtab/midline_panel_b.tex") preserve

* PANEL C
gl panel_c n_children boys_13to17_hh
file open fh using "$dtab/midline_panel_c.tex", replace write
foreach T in High { 
	foreach y in $panel_c {
		local i = `i' + 1
			file write fh " ${lab_`y'} & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) & [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file write fh "\midrule" _n
file close fh 
project, creates("$dtab/midline_panel_c.tex") preserve


* PANEL D 
gl panel_d income_covid_ppp_w tot_covid_sympt tot_sympt_hh sympt_child health_visits_w not_kept_distance
file open fh using "$dtab/midline_panel_d.tex", replace write
foreach T in High { 
	foreach y in $panel_d {
		local i = `i' + 1
			file write fh " ${lab_`y'} & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) & [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file write fh "\midrule" _n
file close fh 
project, creates("$dtab/midline_panel_d.tex") preserve

	
* PANEL F 
gl panel_f school_day_per_child alert_child_flex Self_Care_z learn_activities
file open fh using "$dtab/midline_panel_f.tex", replace write
foreach T in High { 
	foreach y in $panel_f {
		local i = `i' + 1
			file write fh " ${lab_`y'} & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) & [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file write fh "\bottomrule" _n
file close fh 
project, creates("$dtab/midline_panel_f.tex") preserve

