*-------------------------------------------------------------------------------
* TABLE 6 (+ Appendix A3). ENDLINE + FOLLOW-UP 
*-------------------------------------------------------------------------------

/*
NOTES:

- endline1.tex: 2_TOT_F1_Dwelling & Composition_collect.do
- endline2.tex: 5_TOT_Sections 12, 14, 16, 18, 22-24_collect.do // The variables aren't in F2F_Outcomes.dta 
- endline3.tex: 5_TOT_Sections 12, 14, 16, 18, 22-24_collect // The variables aren't in F2F_Outcomes.dta 
- endline4.tex: 6_TOT_F4_Employment_collect.do
- endline5.tex: 4_TOT_F15_NGOs_collect.do
- endline6.tex: 8_TOT_F11_12_13_Time_Education_Behavioral_collect.do 

- follow-up.tex: TOT_T1.do 
*/

/*
QUESTIONS:

- Lower Lee bounds are a little off but not a concern (I set seed...)

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

set seed 5693


*-------------------------------------------------------------------------------
* LOAD AND MERGE THE DATASETS
*-------------------------------------------------------------------------------
project, original("$da/F2F_Outcomes.dta")
use "$da/F2F_Outcomes.dta", clear

project, original("$da/Section12_14_16_18.dta") preserve
merge 1:1 Key_USE using "$da/Section12_14_16_18.dta", keep(match) nogen // For endline2.tex and endline3.tex variables

project, original("$da/Covariates_Compliance.dta") preserve
merge 1:1 Key_USE using "$da/Covariates_Compliance.dta"
	drop if _merge==2
	drop _merge

project, original("$da/children_baseline.dta") preserve
merge 1:1 Key_USE using "$da/children_baseline.dta"
	drop if _merge==2
	drop _merge
	
// merge 1:1 Key_USE using "$da/Localities_wKey.dta"
// 	drop if _merge==2
// 	drop _merge

project, original("$da/SampleList_Final_deid.dta") preserve
merge m:1 IID using "${da}/SampleList_Final_deid.dta", nogen assert(2 3 ) keep(3)  /// 
	keepusing(locality LocalityName Assignment IID) update 
replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"

project, original("$da/LocalityAssignments_Complete.dta") preserve
merge m:1 LocalityName using "${da}/LocalityAssignments_Complete.dta", assert(2 3) keep(3) ///
	keepusing(LocalityName _ID order GOVCODE FTreatment RETreatment) nogen //_ID and order have 334 unique vars (if keep 2 and 3, which looks right)
rename GOVCODE Gov
//check that treatment assignment is the same across files to double check its right
assert FTreatment=="Control" if Assignment=="In-FControl"
assert FTreatment=="Treatment" if Assignment=="In-FLEXTreat"
assert RETreatment=="Control" if Assignment=="In-REControl"
assert RETreatment=="Treatment" if Assignment=="In-RETreat"
//merge in locality quartiles
preserve 
project, original("$da/LocalityAssignments_Quartiles.dta") preserve
use  "${da}/LocalityAssignments_Quartiles.dta", clear 
replace LocalityName = subinstr(LocalityName, "`=char(10)'" , "" , . )
tempfile quartiles 
save `quartiles',replace 
restore 
merge m:1 LocalityName using `quartiles',  assert(2 3) keep(3) ///
	keepusing(MAQuartile IRQuartile)
drop locality LocalityName _ID //a bunch of not-right locality vars 
rename order Locality
drop _merg	

project, original("$da/duplicateWeights.dta") preserve
merge 1:1 IID using "$da/duplicateWeights.dta"
	drop if _merge==2
	drop _merge

ta q110, m
keep if q110==1 /*to remove if Lee Bounds are needed*/
// ren order Locality
	
g FLEX_Sample = regex(Assignment, "F")
ta Assignment FLEX_Sample

ren AllSubsidyQrt_H AllSubsidyQrt
ren TotalEarnings30D_PPP_W_IHS Earnings30D_PPP_W_IHS
ren NetSalary30D_PPP_W_IHS Salary30D_PPP_W_IHS


*-------------------------------------------------------------------------------
* PANEL A: ENDLINE (8 VARIABLES)
*-------------------------------------------------------------------------------

* Globals for each family

*** Endline 1 (T2)
cap drop HousingIndex
cap gen HousingIndex = HousingIndex_High

gl el1 HousingIndex MaterialIndex Toilet DrinkPipe MainWaterPipe MainWaterEasy /// 
			  Filter DrinkWaterSafe Electricity GridElectricity Generator SharedDwelling /// 
			  Families Rooms OccupiedRooms HousingExpPPP HousingExpPCPPP RentPaidPPP /// 
			  HHSize HHSize_All_2011 HHSizeDiff TotalIDs OwnHouse ChoresChildcareFR /// 
			  ChoresChildcareHH LandOwnTotal /*MortgagePPP*/
			  
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el1) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el1} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el1 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}
			  
********************************************************************************
			  
* Endline 2 (Savings and Credit)
gl el2 savings30 loans_in_usdppp r_loan_in r_loan_in_weight loans_out_usdppp ///flat_rate
			currDflt applLoan applTake applNotTake nSenders total_transfersIn nRecipients total_transfersOut
			

foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el2) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el2} {
		if ustrregexm("`y'", "r_loan_in_weight") {
			qui ivregress 2sls r_loan_in (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [aw = loans_in_usdppp] ///
				, r cl(Locality)
			tempname M
				mat `M' = r(table)
				loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
				loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
				loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
				loc `T'_s_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
				loc `T'_N_`y' = string(e(N), "%15.0fc")
			su r_loan_in if A_`T'Subsidy==0 [aw = loans_in_usdppp]
				loc `T'_mean_`y'= string(r(mean), "%12.2fc")
				loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
				loc i=`i'+1
				mat `T'_plist[`i',1]=`M'[4,1]
		}
		else {
			qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
			tempname M
				mat `M' = r(table)
				gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
				gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
				gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
				gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
				gl `T'_N_`y' = string(e(N), "%15.0fc")
			su `y' if A_`T'Subsidy==0 
				gl `T'_mean_`y'= string(r(mean), "%12.2fc")
				gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
				loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
		}
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el2 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

* Endline 3 (Marriage and Childbearing)
foreach var in varlist marriageIndex decisionIndex {
	cap drop `var'
	cap gen `var' = `var'High
}

gl el3 marriageIndex decisionIndex age1stmarriage marr_registered n_marriages remarriages ///
	got_promptdowry age_gap age_marriage_end polygamous selected_spouse n_preg ///
	n_preg_partner bc_currentspouse child_mortality agemenarche miscarriages abortions hospitalbirths preemies 
	
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el3) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el3} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el3 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

* Endline 4 (T6)
gl el4 BusinessDummy EmployeeDummy WorkingDummy /// 								
		  Earnings30D_PPP_W_IHS /*Taxes30D_PPP_W*/ TotalHours7D TotalHours7D_wChores /// 							
		  TypicalHoursM SalaryHours7D BusinessHours7D Hours7DAdults /// 							
		  Salary30D_PPP_W_IHS /*Profit30D_IHS_W*/ SeasonalWork Manufacturing Construction /// 							
		  Service ServiceH ServiceL Trade FormalBusiness /*Revenue30D_IHS_W*/ Revenue12M_PPP_W_IHS /// 							
		  /*BusinessWorkers30D_W*/ WaiveBusiness /*Profit30D_PPP_W*/ Profit12M_PPP /// 							
		  /*BusinessExp30D_PPP_W BusinessExp12M_PPP_W BusinessRent30D_PPP_W*/ /// 							
		  JobSearchWeeks ChoresChildcareFR
		  
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el4) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el4} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el4 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

* Endline 5 (Extra)
gl el5 AidGovt_Dummy AidUNHCR_Dummy AidWFP_Dummy AidNRC_Dummy /// 
			 AidComm_Dummy AidOther_Dummy /// 
			 CashAidTotal_PPP InKindAidTotal_PPP AidTotal_PPP /// 
		     AidGovtTotal_PPP AidUNHCRTotal_PPP AidWFPTotal_PPP /// 
			 AidNRCTotal_PPP AidCommTotal_PPP AidOtherTotal_PPP
			 
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el5) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el5} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el5 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}
			 
********************************************************************************

* Endline 6
gl el6 Happiness3Levels JDSchool

foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el6) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el6} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el6 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

* Variable labels 
loc lab_ChoresChildcareFR 		"Focus Respondent Childcare \& Chores (Hours)"
loc lab_TotalHours7D_wChores    "Total Labor and Chores Hours Last Week"
loc lab_Happiness3Levels     	"General Happiness (Scale 1-3)"
local lab_savings30 			"At least 30 JD (95 USD PPP) in savings (=1)"
local lab_applNotTake 			"Applied but Did Not Take Loan (=1)"
loc lab_AidNRC_Dummy        	"NRC Assistance in Last 12 Months (=1)"
loc lab_AidNRCTotal_PPP    		"NRC Assistance in Last 12 Months (USD PPP)"
local lab_n_preg_partner 		"Number of any partner's pregnancies" 

* Create table 
gl outcomes "ChoresChildcareFR TotalHours7D_wChores Happiness3Levels savings30 applNotTake AidNRC_Dummy AidNRCTotal_PPP"
file open fh using "$dtab/endline.tex", replace write
foreach T in High { 
	foreach y in $outcomes {
		file write fh " `lab_`y'' & ${`T'_b_`y'}${`T'_star_`y'} & (${`T'_se_`y'}) &   [${q_`y'}] &  ${`T'_mean_`y'} & (${`T'_sd_`y'}) &  ${`T'_N_`y'} \\ " _n		
	}
}
file close fh 	
project,creates("$dtab/endline.tex") preserve



*-------------------------------------------------------------------------------
* PANEL B: FOLLOW-UP (1 VARIABLE)
*-------------------------------------------------------------------------------

clear
project,original("$da/RCT_PS2_all_outcomes.dta")
use "$da/RCT_PS2_all_outcomes.dta", clear 

* Reverse code SDQ
replace total_problems_sd = total_problems_sd*-1

*-------------------------------------------------------------------------------
* PANEL B: FOLLOW-UP REGRESSIONS
*-------------------------------------------------------------------------------

* Global the follow-up family 
gl flup_outcomes "hqual_index log_ConsTot_win CESD_sd total_problems_sd"

foreach T in High { 
	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	
			
	***Treatment-on-Treated
		foreach v in hqual_index {
			cap gen `v'=.
			cap replace `v'=`v'_`T'
		}
			
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(flup_outcomes) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${flup_outcomes} {
        * Perform the IV regression for the main outcome
        qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps2], r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
        
	
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
		
		* Store p-values in plist matrix for q-value calculation
		local i = `i' + 1
		mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $flup_outcomes { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}


*-------------------------------------------------------------------------------
* PANEL B: FOLLOW-UP TABLES
*-------------------------------------------------------------------------------

* Variable label
loc lab_total_problems_sd 		"Child SDQ score, std"

* Create table 
file open fh using "$dtab/followup.tex", replace write
foreach T in High { 
	foreach y in total_problems_sd {
		file write fh " `lab_`y'' & ``T'_b_`y''``T'_star_`y'' & (``T'_se_`y'') &   [`q_`y''] &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' \\ " _n		
	}
}
file close fh	
project,creates("$dtab/followup.tex") preserve

