*-------------------------------------------------------------------------------
* TABLE 7 (+ Appendix A4): Social Cohesion (with Lee Bounds)
*-------------------------------------------------------------------------------

/*
NOTES/QUESTIONS: 
 
- Original do file path: 
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/table1.do
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/primary_and_socialindexcomponent.do
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/table5.do
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/table11.do

*/

clear all
set more off
program drop _all
set maxvar 10000

capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

*-------------------------------------------------------------------------------
* IMPORT DATA 
*-------------------------------------------------------------------------------

project, original("$da/NS_sample_deidentified.dta")
use "$da/NS_sample_deidentified.dta", clear



project, original("$da/NS_T1.dta") preserve
merge 1:1 IID q101 using "$da/NS_T1.dta", assert(3) nogen 

project, original("$da/NS_T3.dta") preserve
merge 1:1 IID q101 using "$da/NS_T3.dta", assert(3) nogen 

project, original("$da/NS_T5.dta") preserve
merge 1:1 IID q101 using "$da/NS_T5.dta", assert(3) nogen 

project, original("$da/NS_T11.dta") preserve
merge 1:1 IID q101 using "$da/NS_T11.dta", assert(3) nogen 

project, original("$da/NS_T12.dta") preserve
merge 1:1 IID q101 using "$da/NS_T12.dta", assert(3) nogen 

* Duplicates 
duplicates report IID 
assert  `r(unique_value)' ==  2145 & `r(N)'==2146
                  
count if IID == "31691984"
assert `r(N)'==2

* Start time of interview 
levelsof q101 if IID == "31691984"
assert "`r(levels)'" == "33365.75 43982.704"

* Drop the later interview 
drop if IID == "31691984" & q101==43982.704

duplicates report IID 
assert  `r(unique_value)' ==  2145 & `r(N)'==2145

* Covariaties - need a m:1 merge because there are 3 obs with missing Key_USE
duplicates tag Key_USE, gen(tag)
assert mi(Key_USE) if tag!=0
drop tag 

project, original("$da/Localities_wKey.dta") preserve
merge m:1 Key_USE using "$da/Localities_wKey.dta", assert(1 2 3) keep(1 3) nogen ////
    keepusing(IRQuartile MAQuartile Gov order )
rename order Locality 

project, original("$da/Covariates_Compliance.dta") preserve
merge m:1 Key_USE using "$da/Covariates_Compliance.dta" , assert(1 2 3) keep(1 3) nogen ////
    keepusing(A_*Subsidy T_*Subsidy HighScMoreLow HHSize_IA )

project, original("$da/children_baseline.dta") preserve
merge m:1 Key_USE using "$da/children_baseline.dta" , assert(1 2 3) keep(1 3) nogen ////
    keepusing(kids_hh0)

g FLEX_Sample = regex(Assignment, "In-F")


*-------------------------------------------------------------------------------
* REGRESSIONS
*-------------------------------------------------------------------------------

* Rename 
ren (AvgAidReceiv99_ppp_w) (ppp_w) // The name was too long when _U and _L were added 

* Set globals for controls 
global refugeecontrols HighScMoreLow HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile 

global HighSubsidyX ${refugeecontrols} MarlowCrowneIndex_High NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id
global LowSubsidyX ${refugeecontrols} MarlowCrowneIndex_Low NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id
global AllSubsidyX ${refugeecontrols} MarlowCrowneIndex_All NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id

********************************************************************************

*** Globals + Regressions for each family 

global sc_primary "SocialIndex_sd econIndex_sd policyIndex_sd Dict_Syrian"

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_primary) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_primary} {
        * Perform the IV regression for the main outcome
        ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_primary { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

global sc_socialindex_comp syrian_friends syrian_advice syrian_frnds_kid syrian_rec_space  ///
         net_societyHigh hardworkingHigh syrianmarriageHigh syrianneighborHigh

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_socialindex_comp) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_socialindex_comp} {
        * Perform the IV regression for the main outcome
        ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_socialindex_comp { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

global sc_social "MediaConsumption ppp_w"

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_social) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_social} {
        * Perform the IV regression for the main outcome
        ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_social { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

global sc_mentalhealth "lifeSat_sd subjHlth_sd"

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_mentalhealth) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_mentalhealth} {
        * Perform the IV regression for the main outcome
        qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_mentalhealth { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
// Social Attitudes & Policy Preferences

global regoutcomes refToCamp_sd RefRightWork_sd RefugeeCitizenship_sd RefEffctEcon_sd ///
    RefEffctSoc_sd PosEffctTotal_sd NegEffctTotal_sd proTaxes workEthic ///
    proWrkPrmits_sd proIntSchool_sd proFreeMove_sd ProHousAsstnce_sd ///
    ProIntlAsstnce_sd RefIntIndex_sd PrimIdentityRelig PrimIdentityNotJord ///
    MediaConsumption ChallengesForJordan perceptEcon_sd PropSyriansGetAid ppp_w

foreach T in High { 
    //Set up i and matrix for q-values 
    loc i=0  
    loc n : list sizeof global(regoutcomes) 
    local n = `n' 
    mat `T'_plist = J(`n', 1, .)

    //LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${regoutcomes} {
            ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
            tempname M
            mat `M' = r(table) //matrix that contains beta's, standard errors, p-vals etc 
            //stick the coeficients, se's etc in locals to write them to a table later
            local `T'_b_`y'          = string(`M'[1,1], "%15.2fc") 
            local `T'_se_`y'         = string(`M'[2,1], "%12.2fc")
            local `T'_p_`y'          = `M'[4,1]
            local `T'_star_`y'       =cond(``T'_p_`y''<=.01,"***", /// 
                                    cond(``T'_p_`y''<=.05,"**", /// 
                                    cond(``T'_p_`y''<=.1,"*","")))
            local `T'_N_`y'          = string(e(N), "%15.0fc")
            summ `y' if A_`T'Subsidy ==0 
            local `T'_mean_`y'       = string(r(mean), "%12.2fc")
            local `T'_sd_`y'         = string(r(sd), "%12.2fc")

            //stick the p-vlaues in plist matrix to generate q-values below
            loc i=`i'+1
            mat `T'_plist[`i',1]=`M'[4,1]
    }
    ***Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)

    forv q=1/`i' {
        loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        di ``T'qval`q''
    }   
}

loc j=0
foreach y in $regoutcomes { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}
	

********************************************************************************

* Variable labels 
local SocialIndex_sd_name "Social attitudes \& perceptions (SD)"
local econIndex_sd_name "Economic attitudes \& perceptions (SD)"
local policyIndex_sd_name "Policy preferences (SD)"
local Dict_Syrian_name "Altruism to Syrians"

local syrian_advice_name1 "Of the 3 people you exchange advice" 
local syrian_advice_name2 "with, how many are Syrian refugees?"
local syrian_frnds_kid_name1 "Do the children in this household"
local syrian_frnds_kid_name2 "have any Syrian refugee friends?"

local ppp_w_name1 "Neighbor perceptions of average"
local ppp_w_name "refugee aid receipt (PPP)"
local MediaConsumption_name "Days of media consumption (last week)"

local subjHlth_sd_name "Subjective Health (SD)"
local lifeSat_sd_name "Life Satisfaction (SD)"



*-------------------------------------------------------------------------------
* TABLES OUTPUT
*-------------------------------------------------------------------------------
global regoutcomes ///
SocialIndex_sd econIndex_sd policyIndex_sd Dict_Syrian ///
syrian_advice syrian_frnds_kid ///
MediaConsumption ppp_w /// 
lifeSat_sd subjHlth_sd

cap file close fh 

* PANEL A  
file open fh using "$dtab/mainpaper_sc_primary.tex",  replace write
foreach y in $regoutcomes {
    if inlist("`y'", "SocialIndex_sd", "econIndex_sd", "policyIndex_sd", "Dict_Syrian") {
		file write fh "``y'_name' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] &  `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n
    }
}
file close fh
project,creates("$dtab/mainpaper_sc_primary.tex") preserve

* PANEL B
file open fh using "$dtab/mainpaper_sc_socialindex_comp.tex",  replace write
foreach y in $regoutcomes {
    if inlist("`y'", "syrian_advice","syrian_frnds_kid") {
        file write fh "``y'_name1'  \\ " _n
        file write fh "``y'_name2' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] &  `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n
    }
}
file close fh
project,creates("$dtab/mainpaper_sc_socialindex_comp.tex") preserve


* PANEL C.1
file open fh using "$dtab/mainpaper_sc_social.tex",  replace write
local q = 0 
foreach y in $regoutcomes {
    local q = `q' + 1
    if inlist("`y'","ppp_w")  {
		file write fh "``y'_name1'  \\ " _n
     }
     if inlist("`y'","MediaConsumption","ppp_w")  {
		file write fh "``y'_name' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] &  `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n
     }
}
file close fh 
project,creates("$dtab/mainpaper_sc_social.tex") preserve


* PANEL C.2 
file open fh using "$dtab/mainpaper_mentalhealth.tex",  replace write
foreach y in $regoutcomes {
    if inlist("`y'", "lifeSat_sd", "subjHlth_sd") {
		file write fh "``y'_name' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] &  `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n
    }
}
file close fh
project,creates("$dtab/mainpaper_mentalhealth.tex") preserve

