*-------------------------------------------------------------------------------
* TABLE 4 (+ Appendix A1). POOLED TREATMENT EFFECTS (WITH LEE BOUNDS)
*-------------------------------------------------------------------------------

/*
NOTES/QUE STIONS:

	- Original do file path: 
		- Panel A: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/2_primary.do
		- Panel B: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/5_credit.do
		- Panel B: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/CrossRound/Analysis/4_food.do
	
	- [Solved]: For housing_exp_ppp: the IV regression is run for round 2 only (although there's data for that for both rounds 1 and 2). Why is that?
	- bys round: summ housing_exp_ppp
		- Answer: because the question in round 1 was not precise/wrong. 

*/

clear all
set more off
program drop _all
set maxvar 10000



* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
*	- Defaults to current working directory if project is not being used
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

set seed 5693


*-------------------------------------------------------------------------------
* LOAD THE POOLED DATASET
*-------------------------------------------------------------------------------
di "Data path is: ${project_dir}"

project, original("$da/PooledAll.dta")
use "$da/PooledAll.dta", replace	
drop _merge

*-------------------------------------------------------------------------------
* Lee Bound Program
*-------------------------------------------------------------------------------

capture  program drop get_retention_gap
program define get_retention_gap, rclass
	args y rs
	
	// Main Regression to identify which observations are in the retention sample

	if "`y'"!="housing_exp_ppp" { 
		quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if !missing(A_HighSubsidy) & round==`rs', r cl(Locality)
		
		}
		else { 
			quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if round==2 & !missing(A_HighSubsidy), r cl(Locality)			
		}
	
	capture drop `y'_in_reg_`rs'
	capture drop `y'_tempsamp_`rs'

	g `y'_in_reg_`rs' = e(sample) // used in get_retention_gap program
	g `y'_tempsamp_`rs' = e(sample) if e(sample)==1 //will be 1 or missing, missing get sorted to the end


	preserve
		keep if round==`rs'
		
		project,  original("$da/SampleList_Final_deid.dta") preserve
		merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta" // For endline2.tex and endline3.tex variables
		
		replace A_HighSubsidy = .
			replace A_HighSubsidy = 0 if regex(Assignment, "FC")
			replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")
		
		//	Keep only the Flex sample and assign 0 to obs not f2f outcomes	
		keep if !missing(A_HighSubsidy)
		replace `y'_in_reg_`rs' = 0 if missing(`y'_in_reg_`rs')
		
		di "Retention by treatment assignment for outcome `y':"
		tab `y'_in_reg_`rs' A_HighSubsidy, m col matcell(`y'_rm)
		global `y'_c_r_`rs'= `y'_rm[2,1]
		global `y'_t_r_`rs' = `y'_rm[2,2]
		quietly regress `y'_in_reg_`rs' A_HighSubsidy
		return scalar `y'_gap_`rs' = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		global `y'_gp_`rs' = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		
	restore

end

*-----------------
* Lee Bound Estimates
*-----------------
capture  program drop get_lee_bounds
program define get_lee_bounds
	args y

	capture drop `y'_tempsamp
	capture drop `y'_temprand 
	capture drop `y'_obs_num
	capture drop `y'_in_reg
	capture drop `y'_kl_L
	capture drop `y'_kl_U
	
	gen `y'_kl_L = 0
	gen `y'_kl_U = 0
	
	// Get Retention Gap for each outcome
		if "`y'"!="housing_exp_ppp" { 
		quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if !missing(A_HighSubsidy), r cl(Locality)
		}
		else { 
			quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if round==2 & !missing(A_HighSubsidy), r cl(Locality)			
		}

	levelsof round if e(sample)==1, local(`y'_rs)
	

	foreach rs in ``y'_rs'{
		di "Round is `rs'"

		get_retention_gap `y' `rs'
		scalar `y'_gap_`rs' = r(`y'_gap_`rs')

			
		di "Retention gap is " `y'_gap_`rs' " for outcome `y'"
		
		//get percentage for trimming
		count if A_HighSubsidy==1 & `y'_tempsamp_`rs'==1 & round==`rs' //number of people who ran in the regression and who are assigned to treatment
		
		local ntrim_`rs' = round(`r(N)' * `y'_gap_`rs', 1) //cutoff 
		di "Need to trim `ntrim_`rs'' observations for outcome `y'"
		global `y'_ntrim_`rs' = `ntrim_`rs''


		*-----------------
		* Trim Observations
		*-----------------
		// This sets the same seed for all outcomes. Is that okay?
		set seed 123456789 
		set sortseed 123456789 

		isid IID Key_USE round, sort //necessary to ensure random variable is reproducible 
		capture drop `y'_temprand_`rs'
		g `y'_temprand_`rs' = runiform() 
	 

		//sort the data for trimming
		
		
		di "Untrimmed summary of `y':"
		tabstat `y' if `y'_in_reg_`rs'==1, by(A_HighSubsidy) statistics(n mean min max p50) save
			global `y'_m_c_`rs' = r(Stat1)[2,1]
		global `y'_m_t_`rs' = r(Stat2)[2,1]
		
		
		//	Loop over lower and upper bounds
		foreach bound_type in L U {
			 if "`bound_type'" == "L" {
				// Sort outcome in descending order		 	
				gsort `y'_tempsamp_`rs' -A_HighSubsidy -`y' `y'_temprand_`rs' 
			}
			else if "`bound_type'" == "U"{
				// Sort outcome in ascending order
				gsort `y'_tempsamp_`rs' -A_HighSubsidy `y' `y'_temprand_`rs' 
			}

		capture drop `y'_obs_num_`rs'
		capture drop `y'_kl_`bound_type'_`rs'
		gen `y'_obs_num_`rs' = _n
		// variable indicating if obs should be kept in lee (kl) calculation
		gen `y'_kl_`bound_type'_`rs' = (`y'_obs_num_`rs' >`ntrim_`rs'') & (round==`rs')
		//replace `y'_kl_`bound_type' = 1 if ((`y'_kl_`bound_type'_`rs'==1) & (`y'_kl_`bound_type'==1))
		replace `y'_kl_`bound_type' = 1 if (`y'_obs_num_`rs' >`ntrim_`rs'') & (round==`rs')

			
		}
	}
	
		
	foreach bound_type in L U {

		quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if `y'_kl_`bound_type'==1, r cl(Locality)
			
		tempname M
			
			mat `M' = r(table)

		di "Ran regression on trimmed `y' with `e(N)' observations for `bound_type' bound. Summary: "
		tabstat `y' if e(sample), by(A_HighSubsidy) statistics(n mean min max p50) save

		global `y'_m_`bound_type'_c = r(Stat1)[2,1]
		global `y'_m_`bound_type'_t = r(Stat2)[2,1]
		
			global `y'_n_`bound_type'_c = r(Stat1)[1,1]
		global `y'_n_`bound_type'_t = r(Stat2)[1,1]

			
			gl High_b_`y'_`bound_type'  = string(`M'[1,1], "%15.2fc")
			gl High_p_`y'_`bound_type'  = string(`M'[4,1], "%12.2fc")
			gl High_star_`y'_`bound_type' = cond(${High_p_`y'_`bound_type'}<=.01,"***",cond(${High_p_`y'_`bound_type'}<=.05,"**",cond(${High_p_`y'_`bound_type'}<=.1,"*","")))
			
			bysort round: tabstat `y' if e(sample), by(A_HighSubsidy) statistics(n mean min max p50)



}


end
*-------------------------------------------------------------------------------
* PANEL A: PRIMARY OUTCOMES (6 VARIABLES)
*-------------------------------------------------------------------------------

local table_loc primary
local primary housing_indexHigh housing_exp_ppp log_ConsTot_win LogTotalConsumption CESD_rev_sd SDQ_rev_sd

gl HighSubsidyX FemaleFR i.AgeFR i.HighSubsidyQrt i.Month_Year HighScMoreLow /// 
                HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.round i.enumID_pool

* Regression
local T "High"
	loc i=0	 
	loc n : list sizeof `table_loc'
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ``table_loc'' {
		if "`y'"!="housing_exp_ppp" { 
			ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight], r cl(Locality)
		}
		else { 
			ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=poolweight] if round==2, r cl(Locality)			
		}
		
		tempname M
		mat `M' = r(table)
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
		loc `T'_N_`y' = string(e(N), "%15.0fc")
		qui sum `y' if A_`T'Subsidy==0 & e(sample) 
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]

		levelsof round if e(sample)==1, local(rounds)
		if "`rounds'"=="1 2 3" {
			local `T'_rnd_`y' "1, 2, 3"
		}
		if "`rounds'"=="2 3" {
			local `T'_rnd_`y' "2, 3"
		}
		if "`rounds'"=="2" {
			local `T'_rnd_`y' "2"
		}
	}
	mat list High_plist 
	
	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	mat list High_qlist

	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}

* Outcome labels 
local lab_housing_indexHigh "Overall Housing Quality (Z-Score)"
local lab_housing_exp_ppp "Total Monthly Housing Expenditures (USD PPP)"
local lab_log_ConsTot_win "Food Consumption (Log USD PPP)" 
local lab_LogTotalConsumption "Log Total Consumption (Log USD PPP)"
local lab_SDQ_rev_sd "SDQ Score (Higher: Better Child Wellbelling)"
local lab_CESD_rev_sd "CESD Score (Higher: Less Depression)"

capture drop _merge

// Lee Bounds for Primary Outcomes

foreach y in `primary' {
get_lee_bounds `y'		
}

local q = 0
cap file close
file open fh using "$dtab/tablea1_primary.tex", replace write
foreach T in High { 
	foreach y in `primary'  {
		local q = `q' + 1
		file write fh " `lab_`y'' & ``T'_b_`y''``T'_star_`y'' & (``T'_se_`y'') &  [``T'qval`q''] & ${`T'_b_`y'_L}${`T'_star_`y'_L}  & ${`T'_b_`y'_U}${`T'_star_`y'_U}  &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' & `High_rnd_`y''\\ " _n		
	}
}
file close fh 
project, creates("$dtab/tablea1_primary.tex") preserve




*-------------------------------------------------------------------------------
* PANEL B: OTHER OUTCOMES (SAVINGS/CREDIT)
*-------------------------------------------------------------------------------

ren AllSubsidyQrt_H AllSubsidyQrt

loc table_loc credit
loc credit savings30jd lend borrow borrow_amt lend_amt borrow_amtIHS lend_amtIHS

foreach x in `credit' { 
	tabstat `x', by(round)
}
		
* Regression
foreach T in /*All*/ High /*Low*/ { 
	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
	       HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.round i.enumID_pool  
	
	loc i=0	 
	loc n : list sizeof `table_loc'
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ``table_loc'' {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=poolweight], r cl(Locality)
		tempname M
		mat `M' = r(table)
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
		loc `T'_N_`y' = string(e(N), "%15.0fc")
		qui sum `y' if A_`T'Subsidy==0 
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
		
		levelsof round if e(sample)==1, local(rounds)
		if "`rounds'"=="1 2 3" {
			local `T'_rnd_`y' "1, 2, 3"
		}
		if "`rounds'"=="2 3" {
			local `T'_rnd_`y' "2, 3"
		}
		if "`rounds'"=="2" {
			local `T'_rnd_`y' "2"
		}
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}
}
 
* Outcome labels 
loc lab_savings30jd    "At least 30 JD (95 USD PPP) in savings (=1)"
loc lab_lend  		   "Gave loan (=1)"
loc lab_borrow         "Took loan (=1)"
loc lab_borrow_amt     "Average monthly loans taken, USD PPP"
loc lab_lend_amt       "Average monthly loans given, USD PPP"
loc lab_borrow_amtIHS  "Average monthly loans taken, IHS"
loc lab_lend_amtIHS    "Average monthly loans given, IHS"   

// Lee Bounds for Panel B credit

foreach y in `credit' {
get_lee_bounds `y'		
}

local q = 0
cap file close
file open fh using "$dtab/tablea1_credit.tex", replace write
foreach T in High { 
	foreach y in `credit'  {
		local q = `q' + 1
		     if inlist("`y'","savings30jd")  {
		file write fh " `lab_`y'' & ``T'_b_`y''``T'_star_`y'' & (``T'_se_`y'') &    [``T'qval`q''] & ${`T'_b_`y'_L}${`T'_star_`y'_L}  & ${`T'_b_`y'_U}${`T'_star_`y'_U}  &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' & `High_rnd_`y'' \\ " _n		
			 }
		}
}
file close fh 
project, creates("$dtab/tablea1_credit.tex") preserve



*-------------------------------------------------------------------------------
* PANEL B: OTHER OUTCOMES (FOOD)
*-------------------------------------------------------------------------------

local table_loc food
		 
su rCSI_index_High if A_HighSubsidy==0 & round==2
su rCSI_index_High if A_HighSubsidy==0 & round==3	 		
su rCSI_index_Low if A_LowSubsidy==0 & round==2
su rCSI_index_Low if A_LowSubsidy==0 & round==3

* Regression
foreach T in High /*Low*/ {  
	cap rename rCSI_index_`T' rCSI_index
	local food log_ConsTot_win ConsPurchTotPPP_win ConsAssistPPP_win ConsProdTot_jdPPP_win /// 
	     MeatConsumption_win MealConsumption RespHungry AdultHungry child_slp_hgry_7 /// 
		 RespHungryD AdultHungryD child_slp_hgry_7D FoodDiversityTotal rCSI_index food_c_assist_ppp
		 
	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
	       HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.round i.enumID_pool  
	
	loc i=0	 
	loc n : list sizeof `table_loc'
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ``table_loc'' {
		ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=poolweight], r cl(Locality)
		tempname M
		mat `M' = r(table)
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
		loc `T'_N_`y' = string(e(N), "%15.0fc")
		qui sum `y' if A_`T'Subsidy==0 
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
		loc i=`i'+1
		mat `T'_plist[`i',1]=`M'[4,1]
			
		levelsof round if e(sample)==1, local(rounds)
		if "`rounds'"=="1 2 3" {
			local `T'_rnd_`y' "1, 2, 3"
		}
		if "`rounds'"=="2 3" {
			local `T'_rnd_`y' "2, 3"
		}
		if "`rounds'"=="2" {
			local `T'_rnd_`y' "2"
		}
		}
		
		* Q-Values
		minq `T'_plist, q(`T'_qlist) step(0.001)
		forv q=1/`i' {
			loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
		}
	}
  
* Outcome labels 	
loc lab_food_c_assist_ppp   "Food consumption (aid) USD PPP"
loc lab_assist_person       "\textit{per capita} Food consumption (aid) USD PPP"
loc lab_meals_yes           "Number of meals consumed the day prior"
loc lab_overall_food_change "$\Delta$ Overall food consumption vs. pre-covid"
loc lab_cereal_change       "$\Delta$ Cereal consumption vs. pre-covid"
loc lab_meat_change         "$\Delta$ Meat consumption vs. pre-covid"
loc lab_log_ConsTot_win "Total Consumption (Log USD PPP)"
loc lab_ConsPurchTotPPP_win "Out-of-pocket Consumption (USD PPP)"
loc lab_ConsAssistPPP_win "Assistance Consumption (USD PPP)"
loc lab_ConsProdTot_jdPPP_win "Home Production Consumption (USD PPP)"
loc lab_MeatConsumption_win "Meat Consumption"
loc lab_MealConsumption "\# Meals Eaten by Respondent Yesterday"
loc lab_RespHungry "Respondent Hunger Last Week (Days)"
loc lab_AdultHungry "Adult Hunger Last Week (Days)"
loc lab_RespHungryD "Respondent Hunger Last Week (=1)"
loc lab_AdultHungryD "Adult Hunger Last Week (=1)"
loc lab_child_slp_hgry_7D "Child Hunger Last Week (=1)"	
loc lab_child_slp_hgry_7 "Child Hunger Last Week (Days)"
loc lab_FoodDiversityTotal "Food Diversity"
loc lab_rCSI_index_High "Reduced Coping Strategy Index"	
loc lab_rCSI_index_Low "Reduced Coping Strategy Index"	
loc lab_rCSI_index "Reduced Coping Strategy Index"	
loc lab_ food_c_assist_ppp "Food assistance consumption (USD PPP)"


********************************************************************************
* Lee Bounds
********************************************************************************

*-----------------
* Retention Gap
*-----------------
/* 
- Calculates the retention gap between treatment and control
- An observation is considered to be in the retention sample if the observation is
  included in the regression (i.e. no variables used in the regression are missing)
  The `y'_in_reg variable identifies.
*/


// Lee Bounds for Panel B food
local  food_report RespHungryD AdultHungryD child_slp_hgry_7D
foreach y in `food_report' {
get_lee_bounds `y'		
}

local q = 0
cap file close
file open fh using "$dtab/tablea1_food.tex", replace write
foreach T in High { 
	foreach y in `food'  {
		local q = `q' + 1
		     if inlist("`y'","RespHungryD","AdultHungryD","child_slp_hgry_7D")  {

		file write fh " `lab_`y'' & ``T'_b_`y''``T'_star_`y'' & (``T'_se_`y'') &    [``T'qval`q''] & ${`T'_b_`y'_L}${`T'_star_`y'_L}  & ${`T'_b_`y'_U}${`T'_star_`y'_U}  &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' & `High_rnd_`y'' \\ " _n		
			 }
			}
}
file close fh 
project, creates("$dtab/tablea1_food.tex") preserve

* Outcome labels 	
loc lab_food_c_assist_ppp   "Food consumption (aid) USD PPP"
loc lab_assist_person       "\textit{per capita} Food consumption (aid) USD PPP"
loc lab_meals_yes           "Number of meals consumed the day prior"
loc lab_overall_food_change "$\Delta$ Overall food consumption vs. pre-covid"
loc lab_cereal_change       "$\Delta$ Cereal consumption vs. pre-covid"
loc lab_meat_change         "$\Delta$ Meat consumption vs. pre-covid"
loc lab_log_ConsTot_win "Total Consumption (Log USD PPP)"
loc lab_ConsPurchTotPPP_win "Out-of-pocket Consumption (USD PPP)"
loc lab_ConsAssistPPP_win "Assistance Consumption (USD PPP)"
loc lab_ConsProdTot_jdPPP_win "Home Production Consumption (USD PPP)"
loc lab_MeatConsumption_win "Meat Consumption"
loc lab_MealConsumption "\# Meals Eaten by Respondent Yesterday"
loc lab_RespHungry "Respondent Hunger Last Week (Days)"
loc lab_AdultHungry "Adult Hunger Last Week (Days)"
loc lab_RespHungryD "Respondent Hunger Last Week (=1)"
loc lab_AdultHungryD "Adult Hunger Last Week (=1)"
loc lab_child_slp_hgry_7D "Child Hunger Last Week (=1)"	
loc lab_child_slp_hgry_7 "Child Hunger Last Week (Days)"
loc lab_FoodDiversityTotal "Food Diversity"
loc lab_rCSI_index_High "Reduced Coping Strategy Index"	
loc lab_rCSI_index_Low "Reduced Coping Strategy Index"	
loc lab_rCSI_index "Reduced Coping Strategy Index"	
loc lab_ food_c_assist_ppp "Food assistance consumption (USD PPP)"

loc lab_savings30jd    "At least 30 JD (95 USD PPP) in savings (=1)"
loc lab_lend  		   "Gave loan (=1)"
loc lab_borrow         "Took loan (=1)"
loc lab_borrow_amt     "Average monthly loans taken, USD PPP"
loc lab_lend_amt       "Average monthly loans given, USD PPP"
loc lab_borrow_amtIHS  "Average monthly loans taken, IHS"
loc lab_lend_amtIHS    "Average monthly loans given, IHS"   

local lab_housing_indexHigh "Overall Housing Quality (Z-Score)"
local lab_housing_exp_ppp "Total Monthly Housing Expenditures (USD PPP)"
local lab_log_ConsTot_win "Food Consumption (Log USD PPP)" 
local lab_LogTotalConsumption "Log Total Consumption (Log USD PPP)"
local lab_SDQ_rev_sd "SDQ Score (Higher: Better Child Wellbelling)"
local lab_CESD_rev_sd "CESD Score (Higher: Less Depression)"



local  check_outcomes housing_indexHigh housing_exp_ppp log_ConsTot_win LogTotalConsumption CESD_rev_sd SDQ_rev_sd savings30jd RespHungryD AdultHungryD child_slp_hgry_7D
foreach y in `check_outcomes' {
	foreach rs in 1 2 3{
	di "`rs', `lab_`y'', ${`y'_c_r_`rs'}, ${`y'_t_r_`rs'}, ${`y'_m_c_`rs'}, ${`y'_m_t_`rs'},  ${`y'_n_U_c}, ${`y'_n_U_t}, ${`y'_m_U_c}, ${`y'_m_U_t}, ${`y'_n_L_c}, ${`y'_n_L_t}, ${`y'_m_L_c}, ${`y'_m_L_t},  ${`y'_ntrim_`rs'},  ${`y'_gp_`rs'}"
		
	}
	

}

