*-------------------------------------------------------------------------------
* TABLE 6 (+ Appendix A3). ENDLINE + FOLLOW-UP 
*-------------------------------------------------------------------------------

/*
NOTES:

- endline1.tex: 2_TOT_F1_Dwelling & Composition_collect.do
- endline2.tex: 5_TOT_Sections 12, 14, 16, 18, 22-24_collect.do // The variables aren't in F2F_Outcomes.dta 
- endline3.tex: 5_TOT_Sections 12, 14, 16, 18, 22-24_collect // The variables aren't in F2F_Outcomes.dta 
- endline4.tex: 6_TOT_F4_Employment_collect.do
- endline5.tex: 4_TOT_F15_NGOs_collect.do
- endline6.tex: 8_TOT_F11_12_13_Time_Education_Behavioral_collect.do 

- follow-up.tex: TOT_T1.do 
*/

/*
QUESTIONS:

- Lower Lee bounds are a little off but not a concern (I set seed...)

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
*	- Defaults to current working directory if project is not being used
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

set seed 5693


*-------------------------------------------------------------------------------
* LOAD AND MERGE THE DATASETS
*-------------------------------------------------------------------------------
project, original("$da/F2F_Outcomes.dta")
use "$da/F2F_Outcomes.dta", clear

project, original("$da/Section12_14_16_18.dta") preserve
merge 1:1 Key_USE using "$da/Section12_14_16_18.dta", keep(match) nogen // For endline2.tex and endline3.tex variables

project, original("$da/Covariates_Compliance.dta") preserve
merge 1:1 Key_USE using "$da/Covariates_Compliance.dta"
	drop if _merge==2
	drop _merge

project, original("$da/children_baseline.dta") preserve
merge 1:1 Key_USE using "$da/children_baseline.dta"
	drop if _merge==2
	drop _merge
	
// merge 1:1 Key_USE using "$da/Localities_wKey.dta"
// 	drop if _merge==2
// 	drop _merge

project, original("${da}/SampleList_Final_deid.dta") preserve
merge m:1 IID using "${da}/SampleList_Final_deid.dta", nogen assert(2 3 ) keep(3)  /// 
	keepusing(locality LocalityName Assignment IID) update 

replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"

project, original("${da}/LocalityAssignments_Complete.dta") preserve
merge m:1 LocalityName using "${da}/LocalityAssignments_Complete.dta", assert(2 3) keep(3) ///
	keepusing(LocalityName _ID order GOVCODE FTreatment RETreatment) nogen //_ID and order have 334 unique vars (if keep 2 and 3, which looks right)
rename GOVCODE Gov
//check that treatment assignment is the same across files to double check its right
assert FTreatment=="Control" if Assignment=="In-FControl"
assert FTreatment=="Treatment" if Assignment=="In-FLEXTreat"
assert RETreatment=="Control" if Assignment=="In-REControl"
assert RETreatment=="Treatment" if Assignment=="In-RETreat"

//merge in locality quartiles
preserve 
project, original("${da}/LocalityAssignments_Quartiles.dta") preserve
use  "${da}/LocalityAssignments_Quartiles.dta", clear 
replace LocalityName = subinstr(LocalityName, "`=char(10)'" , "" , . )
tempfile quartiles 
save `quartiles',replace 
restore 
merge m:1 LocalityName using `quartiles',  assert(2 3) keep(3) ///
	keepusing(MAQuartile IRQuartile)

drop locality LocalityName _ID //a bunch of not-right locality vars 
rename order Locality

drop _merge


project, original("${da}/duplicateWeights.dta") preserve
merge 1:1 IID using "$da/duplicateWeights.dta"
	drop if _merge==2
	drop _merge

ta q110, m
keep if q110==1 /*to remove if Lee Bounds are needed*/
// ren order Locality
	
g FLEX_Sample = regex(Assignment, "F")
ta Assignment FLEX_Sample

ren AllSubsidyQrt_H AllSubsidyQrt
ren TotalEarnings30D_PPP_W_IHS Earnings30D_PPP_W_IHS
ren NetSalary30D_PPP_W_IHS Salary30D_PPP_W_IHS


*-------------------------------------------------------------------------------
* PANEL A: ENDLINE (8 VARIABLES)
*-------------------------------------------------------------------------------

* Globals for each family



*** Endline 1 (T2)
cap drop HousingIndex
cap gen HousingIndex = HousingIndex_High

gl el1 HousingIndex MaterialIndex Toilet DrinkPipe MainWaterPipe MainWaterEasy /// 
			  Filter DrinkWaterSafe Electricity GridElectricity Generator SharedDwelling /// 
			  Families Rooms OccupiedRooms HousingExpPPP HousingExpPCPPP RentPaidPPP /// 
			  HHSize HHSize_All_2011 HHSizeDiff TotalIDs OwnHouse ChoresChildcareFR /// 
			  ChoresChildcareHH LandOwnTotal /*MortgagePPP*/
			  
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el1) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el1} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
		}	
}

loc j=0
foreach y in $el1 { 
	local j = `j' + 1
	if inlist("`y'","ChoresChildcareFR"){
		gl q_`y'_1 = string(`Highqval`j'', "%15.2fc")
	}
	else{
		gl q_`y' = string(`Highqval`j'', "%15.2fc")
		
	}
}
			  
********************************************************************************
			  
* Endline 2 (Savings and Credit)
gl el2 savings30 loans_in_usdppp r_loan_in r_loan_in_weight loans_out_usdppp ///flat_rate
			currDflt applLoan applTake applNotTake nSenders total_transfersIn nRecipients total_transfersOut
			

foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el2) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el2} {
		if ustrregexm("`y'", "r_loan_in_weight") {
			qui ivregress 2sls r_loan_in (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [aw = loans_in_usdppp] ///
				, r cl(Locality)
			tempname M
				mat `M' = r(table)
				loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
				loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")
				loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
				loc `T'_s_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))
				loc `T'_N_`y' = string(e(N), "%15.0fc")
			su r_loan_in if A_`T'Subsidy==0 [aw = loans_in_usdppp]
				loc `T'_mean_`y'= string(r(mean), "%12.2fc")
				loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
				loc i=`i'+1
				mat `T'_plist[`i',1]=`M'[4,1]
		}
		else {
			qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
			tempname M
				mat `M' = r(table)
				gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
				gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
				gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
				gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
				gl `T'_N_`y' = string(e(N), "%15.0fc")
			su `y' if A_`T'Subsidy==0 
				gl `T'_mean_`y'= string(r(mean), "%12.2fc")
				gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
				loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
		}
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el2 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

* Endline 3 (Marriage and Childbearing)
foreach var in varlist marriageIndex decisionIndex {
	cap drop `var'
	cap gen `var' = `var'High
}

gl el3 marriageIndex decisionIndex age1stmarriage marr_registered n_marriages remarriages ///
	got_promptdowry age_gap age_marriage_end polygamous selected_spouse n_preg ///
	n_preg_partner bc_currentspouse child_mortality agemenarche miscarriages abortions hospitalbirths preemies 
	
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el3) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el3} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el3 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

* Endline 4 (T6)
gl el4 BusinessDummy EmployeeDummy WorkingDummy /// 								
		  Earnings30D_PPP_W_IHS /*Taxes30D_PPP_W*/ TotalHours7D TotalHours7D_wChores /// 							
		  TypicalHoursM SalaryHours7D BusinessHours7D Hours7DAdults /// 							
		  Salary30D_PPP_W_IHS /*Profit30D_IHS_W*/ SeasonalWork Manufacturing Construction /// 							
		  Service ServiceH ServiceL Trade FormalBusiness /*Revenue30D_IHS_W*/ Revenue12M_PPP_W_IHS /// 							
		  /*BusinessWorkers30D_W*/ WaiveBusiness /*Profit30D_PPP_W*/ Profit12M_PPP /// 							
		  /*BusinessExp30D_PPP_W BusinessExp12M_PPP_W BusinessRent30D_PPP_W*/ /// 							
		  JobSearchWeeks ChoresChildcareFR
		  
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el4) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el4} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
		
	}	
}

loc j=0
foreach y in $el4 { 
	local j = `j' + 1
	if inlist("`y'","ChoresChildcareFR"){
		gl q_`y'_2 = string(`Highqval`j'', "%15.2fc")
	}
	else{
		gl q_`y' = string(`Highqval`j'', "%15.2fc")
		
	}

}

gl q_ChoresChildcareFR_min = string(min(${q_ChoresChildcareFR_1},${q_ChoresChildcareFR_2}), "%15.2fc")
gl q_ChoresChildcareFR_max = string(max(${q_ChoresChildcareFR_1},${q_ChoresChildcareFR_2}), "%15.2fc")
gl q_ChoresChildcareFR = "${q_ChoresChildcareFR_min}"

********************************************************************************

* Endline 5 (Extra)
gl el5 AidGovt_Dummy AidUNHCR_Dummy AidWFP_Dummy AidNRC_Dummy /// 
			 AidComm_Dummy AidOther_Dummy /// 
			 CashAidTotal_PPP InKindAidTotal_PPP AidTotal_PPP /// 
		     AidGovtTotal_PPP AidUNHCRTotal_PPP AidWFPTotal_PPP /// 
			 AidNRCTotal_PPP AidCommTotal_PPP AidOtherTotal_PPP
			 
foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el5) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el5} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el5 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}
			 
********************************************************************************

* Endline 6
gl el6 Happiness3Levels JDSchool

foreach T in High {
	
gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

* Treatment-on-Treated
	loc i=0	 
	loc n : list sizeof global(el6) 
	mat `T'_plist = J(`n', 1, .) 
	foreach y in ${el6} {
		qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
		tempname M
			mat `M' = r(table)
			gl `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 
			gl `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			gl `T'_p_`y'  = string(`M'[4,1], "%12.2fc")
			gl `T'_star_`y'=cond(${`T'_p_`y'}<=.01,"***",cond(${`T'_p_`y'}<=.05,"**",cond(${`T'_p_`y'}<=.1,"*","")))
			gl `T'_N_`y' = string(e(N), "%15.0fc")
		su `y' if A_`T'Subsidy==0 
			gl `T'_mean_`y'= string(r(mean), "%12.2fc")
			gl `T'_sd_`y'  = string(r(sd), "%12.2fc")
			loc i=`i'+1
			mat `T'_plist[`i',1]=`M'[4,1]
	}

	* Q-Values
	minq `T'_plist, q(`T'_qlist) step(0.001)
	forv q=1/`i' {
		loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
	}	
}

loc j=0
foreach y in $el6 { 
	local j = `j' + 1
	gl q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
* Lee Bounds
********************************************************************************

*-----------------
* Retention Gap
*-----------------
capture  program drop get_retention_gap
program define get_retention_gap, rclass
/* 
- Calculates the retention gap between treatment and control
- An observation is considered to be in the retention sample if the observation is
  included in the regression (i.e. no variables used in the regression are missing)
  The `y'_in_reg variable identifies.
*/


	args y
	
	// Main Regression to identify which observations are in the retention sample
	qui ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=weightf2f] if !missing(A_HighSubsidy), r cl(Locality)
	g `y'_in_reg = e(sample) // used in get_retention_gap program
	g `y'_tempsamp = e(sample) if e(sample)==1 //will be 1 or missing, missing get sorted to the end

	
	preserve
		project, original("$da/SampleList_Final_deid.dta") preserve
		merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta" // For endline2.tex and endline3.tex variables
		
		replace A_HighSubsidy = .
			replace A_HighSubsidy = 0 if regex(Assignment, "FC")
			replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")
		
		//	Keep only the Flex sample and assign 0 to obs not f2f outcomes	
		keep if !missing(A_HighSubsidy)
		replace `y'_in_reg = 0 if missing(`y'_in_reg)
		
		di "Retention by treatment assignment for outcome `y':"
		tab `y'_in_reg A_HighSubsidy, m col matcell(`y'_rm)
		global `y'_c_r= `y'_rm[2,1]
		global `y'_t_r = `y'_rm[2,2]
		regress `y'_in_reg A_HighSubsidy
		return scalar `y'_gap = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		global `y'_gp = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		
	restore
end

*-----------------
* Lee Bound Estimates
*-----------------
capture  program drop get_lee_bounds
program define get_lee_bounds
	args y


	capture drop `y'_tempsamp
	capture drop `y'_temprand 
	capture drop `y'_obs_num
	capture drop `y'_in_reg
	
	// Get Retention Gap for each outcome	
	get_retention_gap `y'
	scalar `y'_gap = r(`y'_gap)
	di "Retention gap is " `y'_gap " for outcome `y'"
	
	//get percentage for trimming
	count if A_HighSubsidy==1 & `y'_tempsamp==1 //number of people who ran in the regression and who are assigned to treatment
	
	local ntrim = round(`r(N)' * `y'_gap, 1) //cutoff 
	di "Need to trim `ntrim' observations for outcome `y'"
	global `y'_ntrim = `ntrim'


	*-----------------
	* Trim Observations
	*-----------------

	isid IID, sort //necessary to ensure random variable is reproducible 
	g `y'_temprand = runiform() 
 

	//sort the data for trimming
	
	// This sets the same seed for all outcomes. Is that okay?
	set seed 123456789 
	set sortseed 123456789 
	
	di "Untrimmed summary of `y':"
	tabstat `y' if `y'_in_reg==1, by(A_HighSubsidy) statistics(n mean min max p50) save
		global `y'_m_c = r(Stat1)[2,1]
	global `y'_m_t = r(Stat2)[2,1]

	
	
	//	Loop over lower and upper bounds
	foreach bound_type in L U {
		 if "`bound_type'" == "L" {
			// Sort outcome in descending order		 	
			gsort `y'_tempsamp -A_HighSubsidy -`y' `y'_temprand 
		}
		else if "`bound_type'" == "U"{
			// Sort outcome in ascending order
			gsort `y'_tempsamp -A_HighSubsidy `y' `y'_temprand 
		}
		

	capture drop `y'_obs_num
	gen `y'_obs_num = _n
	quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=weightf2f] if `y'_obs_num >`ntrim', r cl(Locality)
		
	tempname M
		
		mat `M' = r(table)

	di "Ran regression on trimmed `y' with `e(N)' observations for `bound_type' bound. Summary: "
	tabstat `y' if e(sample), by(A_HighSubsidy) statistics(n mean min max p50) save

	global `y'_m_`bound_type'_c = r(Stat1)[2,1]
	global `y'_m_`bound_type'_t = r(Stat2)[2,1]
	
		global `y'_n_`bound_type'_c = r(Stat1)[1,1]
	global `y'_n_`bound_type'_t = r(Stat2)[1,1]

		
		gl High_b_`y'_`bound_type'  = string(`M'[1,1], "%15.2fc")
		gl High_p_`y'_`bound_type'  = string(`M'[4,1], "%12.2fc")
		gl High_star_`y'_`bound_type' = cond(${High_p_`y'_`bound_type'}<=.01,"***",cond(${High_p_`y'_`bound_type'}<=.05,"**",cond(${High_p_`y'_`bound_type'}<=.1,"*","")))



}

end

gl HighSubsidyX FemaleFR i.AgeFR i.HighSubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	

global outcomes ChoresChildcareFR savings30 applNotTake TotalHours7D_wChores   AidNRC_Dummy AidNRCTotal_PPP Happiness3Levels 
	/* n_preg_partner (husband's pregnancies); kinda spurious result cause there's no impact on women's reported pregnancies so removing from table */


* Variable labels 
loc lab_ChoresChildcareFR 		"Focus Respondent Childcare \& Chores (Hours)"
local lab_savings30 			"At least 30 JD (95 USD PPP) in savings (=1)"
local lab_applNotTake 			"Applied but Did Not Take Loan (=1)"
loc lab_TotalHours7D_wChores    "Total Labor and Chores Hours Last Week"
loc lab_AidNRC_Dummy        	"NRC Assistance in Last 12 Months (=1)"
loc lab_AidNRCTotal_PPP    		"NRC Assistance in Last 12 Months (USD PPP)"
local lab_n_preg_partner 		"Number of any partner's pregnancies" 
loc lab_Happiness3Levels     	"General Happiness (Scale 1-3)"
local lab_n_preg_partner 		"Number of any partner's pregnancies" 


foreach y in $outcomes{
	get_lee_bounds `y'
}

* Create table 	
cap file close 
file open fh using "$dtab/table_a3_endline.tex", replace write
	local q = 0 
		foreach y in $outcomes {
		local q = `q' + 1

			if inlist("`y'","ChoresChildcareFR"){
				file write fh " `lab_`y'' & ${High_b_`y'}${High_star_`y'} & (${High_se_`y'}) &   [${q_`y'}]† & ${High_b_`y'_L}${High_star_`y'_L}  & ${High_b_`y'_U}${High_star_`y'_U}  &  ${High_mean_`y'} & (${High_sd_`y'}) &  ${High_N_`y'} \\ " _n
			}
			else{
				file write fh " `lab_`y'' & ${High_b_`y'}${High_star_`y'} & (${High_se_`y'}) &   [${q_`y'}] & ${High_b_`y'_L}${High_star_`y'_L}  & ${High_b_`y'_U}${High_star_`y'_U}  &  ${High_mean_`y'} & (${High_sd_`y'}) &  ${High_N_`y'} \\ " _n
				
			}
		}
file close fh
project, creates("$dtab/table_a3_endline.tex") preserve


* Max of q value for ChoresChildcareFR
cap file close 
file open fh using "$dtab/q_max_ChoresChildcareFR.tex", replace write
	file write fh "${q_ChoresChildcareFR_max}" 
file close fh
project, creates("$dtab/q_max_ChoresChildcareFR.tex") preserve



* Variable labels 
loc lab_ChoresChildcareFR 		"Focus Respondent Childcare \& Chores (Hours)"
local lab_savings30 			"At least 30 JD (95 USD PPP) in savings (=1)"
local lab_applNotTake 			"Applied but Did Not Take Loan (=1)"
loc lab_TotalHours7D_wChores    "Total Labor and Chores Hours Last Week"
loc lab_AidNRC_Dummy        	"NRC Assistance in Last 12 Months (=1)"
loc lab_AidNRCTotal_PPP    		"NRC Assistance in Last 12 Months (USD PPP)"
local lab_n_preg_partner 		"Number of any partner's pregnancies" 
loc lab_Happiness3Levels     	"General Happiness (Scale 1-3)"
local lab_n_preg_partner 		"Number of any partner's pregnancies" 



foreach y in $outcomes {
	di "`lab_`y'', $`y'_c_r, $`y'_t_r, $`y'_m_c, $`y'_m_t,  $`y'_n_U_c, $`y'_n_U_t, $`y'_m_U_c, $`y'_m_U_t, $`y'_n_L_c, $`y'_n_L_t, $`y'_m_L_c, $`y'_m_L_t,  $`y'_ntrim,  $`y'_gp"

}


// Variable to check if any outcome is available
capture drop is_retained r_loan_in_weight
gen is_retained = .
gen r_loan_in_weight = r_loan_in // 
global covariates FemaleFR AgeFR HighSubsidyQrt Month_Year HighScMoreLow HHSize_IA kids_hh0 Gov MAQuartile IRQuartile enumID Locality

// Check if any outcomes is available
foreach y in $el1 $el2 $el3 $el4 $el5 $el6{
	di "`y'"
	replace is_retained = 1 if !missing(`y') | is_retained == 1
}


// Check if any covariate is missing
foreach y in $covariates{
	di "`y'"
	replace is_retained = 0 if missing(`y')
}


ta is_retained, m

project, original("$da/SampleList_Final_deid.dta") preserve
merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta", nogen


replace A_HighSubsidy = .
	replace A_HighSubsidy = 0 if regex(Assignment, "FC")
	replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")

//	Keep only the Flex sample and assign 0 to obs not f2f outcomes	
keep if !missing(A_HighSubsidy)
replace is_retained = 0 if missing(is_retained) 
replace is_retained = 0 if weightf2f==0

eststo clear
eststo followup, refresh: regress is_retained A_HighSubsidy 
esttab followup using "${dtab}/retention_round2.tex", replace ///
	label booktabs
project, creates("${dtab}/retention_round2.tex") preserve
