*-------------------------------------------------------------------------------
* TABLE 6 (+ Appendix A3). ENDLINE + FOLLOW-UP 
*-------------------------------------------------------------------------------

/*
NOTES:

- endline1.tex: 2_TOT_F1_Dwelling & Composition_collect.do
- endline2.tex: 5_TOT_Sections 12, 14, 16, 18, 22-24_collect.do // The variables aren't in F2F_Outcomes.dta 
- endline3.tex: 5_TOT_Sections 12, 14, 16, 18, 22-24_collect // The variables aren't in F2F_Outcomes.dta 
- endline4.tex: 6_TOT_F4_Employment_collect.do
- endline5.tex: 4_TOT_F15_NGOs_collect.do
- endline6.tex: 8_TOT_F11_12_13_Time_Education_Behavioral_collect.do 

- follow-up.tex: TOT_T1.do 
*/

/*
QUESTIONS:

- Lower Lee bounds are a little off but not a concern (I set seed...)

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
*	- Defaults to current working directory if project is not being used
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

set seed 5693


*-------------------------------------------------------------------------------
* PANEL B: FOLLOW-UP (1 VARIABLE)
*-------------------------------------------------------------------------------

clear
project, original("$da/RCT_PS2_all_outcomes.dta")
use "$da/RCT_PS2_all_outcomes.dta", clear 

// merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta", keepusing(Assignment) generate(_in_samplelist)
// 	drop if _in_samplelist==2
//
// replace A_HighSubsidy = .
// 	replace A_HighSubsidy = 0 if regex(Assignment, "FC")
// 	replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")


* Reverse code SDQ
replace total_problems_sd = total_problems_sd*-1

* Add lee bounds 
foreach y in total_problems_sd { 
	gen id_`y' = _n if A_HighSubsidy==1 & !mi(`y')
 }
	 

*-------------------------------------------------------------------------------
* PANEL B: FOLLOW-UP REGRESSIONS
*-------------------------------------------------------------------------------

* Global the follow-up family 
gl flup_outcomes "hqual_index log_ConsTot_win CESD_sd total_problems_sd"

foreach T in High { 
	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow ///
			HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	
			
	***Treatment-on-Treated
		foreach v in hqual_index {
			cap gen `v'=.
			cap replace `v'=`v'_`T'
		}
			
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(flup_outcomes) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${flup_outcomes} {
        * Perform the IV regression for the main outcome
        qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightps2], r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
        
		
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
		
		* Store p-values in plist matrix for q-value calculation
		local i = `i' + 1
		mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $flup_outcomes { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}


*-------------------------------------------------------------------------------
* PANEL B: FOLLOW-UP TABLES
*-------------------------------------------------------------------------------

* Variable label
loc lab_total_problems_sd 		"Child SDQ score, std"



********************************************************************************
* Lee Bounds
********************************************************************************

*-----------------
* Retention Gap
*-----------------
capture  program drop get_retention_gap
program define get_retention_gap, rclass
/* 
- Calculates the retention gap between treatment and control
- An observation is considered to be in the retention sample if the observation is
  included in the regression (i.e. no variables used in the regression are missing)
  The `y'_in_reg variable identifies.
*/


	args y
	
	// Main Regression to identify which observations are in the retention sample
	qui ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=weightps2] if !missing(A_HighSubsidy), r cl(Locality)
	g `y'_in_reg = e(sample) // used in get_retention_gap program
	g `y'_tempsamp = e(sample) if e(sample)==1 //will be 1 or missing, missing get sorted to the end

	
	preserve
		project, original("$da/SampleList_Final_deid.dta") preserve
		merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta" // For endline2.tex and endline3.tex variables
		
		replace A_HighSubsidy = .
			replace A_HighSubsidy = 0 if regex(Assignment, "FC")
			replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")
		
		//	Keep only the Flex sample and assign 0 to obs not f2f outcomes	
		keep if !missing(A_HighSubsidy)
		replace `y'_in_reg = 0 if missing(`y'_in_reg)
		
		di "Retention by treatment assignment for outcome `y':"
		tab `y'_in_reg A_HighSubsidy, m col matcell(`y'_rm)
		global `y'_c_r= `y'_rm[2,1]
		global `y'_t_r = `y'_rm[2,2]
		regress `y'_in_reg A_HighSubsidy
		return scalar `y'_gap = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		global `y'_gp = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		
	restore
end

*-----------------
* Lee Bound Estimates
*-----------------
capture  program drop get_lee_bounds
program define get_lee_bounds
	args y


	capture drop `y'_tempsamp
	capture drop `y'_temprand 
	capture drop `y'_obs_num
	capture drop `y'_in_reg
	
	// Get Retention Gap for each outcome	
	get_retention_gap `y'
	scalar `y'_gap = r(`y'_gap)
	di "Retention gap is " `y'_gap " for outcome `y'"
	
	//get percentage for trimming
	count if A_HighSubsidy==1 & `y'_tempsamp==1 //number of people who ran in the regression and who are assigned to treatment
	
	local ntrim = round(`r(N)' * `y'_gap, 1) //cutoff 
	di "Need to trim `ntrim' observations for outcome `y'"
	global `y'_ntrim = `ntrim'


	*-----------------
	* Trim Observations
	*-----------------

	isid IID, sort //necessary to ensure random variable is reproducible 
	g `y'_temprand = runiform() 
 

	//sort the data for trimming
	
	// This sets the same seed for all outcomes. Is that okay?
	set seed 123456789 
	set sortseed 123456789 
	
	di "Untrimmed summary of `y':"
	tabstat `y' if `y'_in_reg==1, by(A_HighSubsidy) statistics(n mean min max p50) save
		global `y'_m_c = r(Stat1)[2,1]
	global `y'_m_t = r(Stat2)[2,1]

	
	
	//	Loop over lower and upper bounds
	foreach bound_type in L U {
		 if "`bound_type'" == "L" {
			// Sort outcome in descending order		 	
			gsort `y'_tempsamp -A_HighSubsidy -`y' `y'_temprand 
		}
		else if "`bound_type'" == "U"{
			// Sort outcome in ascending order
			gsort `y'_tempsamp -A_HighSubsidy `y' `y'_temprand 
		}
		

	capture drop `y'_obs_num
	gen `y'_obs_num = _n
	quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} [pw=weightps2] if `y'_obs_num >`ntrim', r cl(Locality)
		
	tempname M
		
		mat `M' = r(table)

	di "Ran regression on trimmed `y' with `e(N)' observations for `bound_type' bound. Summary: "
	tabstat `y' if e(sample), by(A_HighSubsidy) statistics(n mean min max p50) save

	global `y'_m_`bound_type'_c = r(Stat1)[2,1]
	global `y'_m_`bound_type'_t = r(Stat2)[2,1]
	
		global `y'_n_`bound_type'_c = r(Stat1)[1,1]
	global `y'_n_`bound_type'_t = r(Stat2)[1,1]

		
		gl High_b_`y'_`bound_type'  = string(`M'[1,1], "%15.2fc")
		gl High_p_`y'_`bound_type'  = string(`M'[4,1], "%12.2fc")
		gl High_star_`y'_`bound_type' = cond(${High_p_`y'_`bound_type'}<=.01,"***",cond(${High_p_`y'_`bound_type'}<=.05,"**",cond(${High_p_`y'_`bound_type'}<=.1,"*","")))



}

end

foreach y in total_problems_sd  {
get_lee_bounds `y'		
}

loc lab_total_problems_sd 		"Child SDQ score, std"

* Create table with Lee bounds 
cap file close
file open fh using "$dtab/TableA3_PanelB.tex", replace write
foreach T in High { 
	foreach y in total_problems_sd  {
		file write fh " `lab_`y'' & ``T'_b_`y''``T'_star_`y'' & (``T'_se_`y'') &   [`q_`y''] & ${`T'_b_`y'_L}${`T'_star_`y'_L}  & ${`T'_b_`y'_U}${`T'_star_`y'_U}  &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' \\ " _n		
	}
}
file close fh 
project, creates("$dtab/TableA3_PanelB.tex") preserve



global outcomes total_problems_sd
foreach y in $outcomes {
	di "`lab_`y'', $`y'_c_r, $`y'_t_r, $`y'_m_c, $`y'_m_t,  $`y'_n_U_c, $`y'_n_U_t, $`y'_m_U_c, $`y'_m_U_t, $`y'_n_L_c, $`y'_n_L_t, $`y'_m_L_c, $`y'_m_L_t,  $`y'_ntrim,  $`y'_gp"

}


// Variable to check if any outcome is available
capture drop is_retained
gen is_retained = .
global covariates FemaleFR AgeFR HighSubsidyQrt Month_Year HighScMoreLow HHSize_IA kids_hh0 Gov MAQuartile IRQuartile enumID

foreach y in $flup_outcomes{
	di "`y'"
  replace is_retained = 1 if !missing(`y') | is_retained == 1
}



// Check if any covariate is missing
foreach y in $covariates{
	di "`y'"
	replace is_retained = 0 if missing(`y')
}


ta is_retained, m

project, original("$da/SampleList_Final_deid.dta") preserve
merge 1:1 Key_USE using "$da/SampleList_Final_deid.dta", nogen


replace A_HighSubsidy = .
	replace A_HighSubsidy = 0 if regex(Assignment, "FC")
	replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")

//	Keep only the Flex sample and assign 0 to obs not f2f outcomes	
keep if !missing(A_HighSubsidy)
replace is_retained = 0 if missing(is_retained) 
replace is_retained = 0 if weightps2==0

eststo clear
eststo followup, refresh: regress is_retained A_HighSubsidy 
esttab followup using "$dtab/retention_round3.tex", replace ///
	label booktabs
project, creates("$dtab/retention_round3.tex") preserve
