*-------------------------------------------------------------------------------
* TABLE 7 (+ Appendix A4): Social Cohesion (with Lee Bounds)
*-------------------------------------------------------------------------------

/*
NOTES/QUESTIONS: 
 
- Original do file path: 
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/table1.do
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/primary_and_socialindexcomponent.do
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/table5.do
	- /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/SocialCohesion/Neighbor Survey_F2F/4. Analyze/table11.do

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

*-------------------------------------------------------------------------------
* IMPORT DATA 
*-------------------------------------------------------------------------------

project, original("$da/NS_sample_deidentified.dta")
use "$da/NS_sample_deidentified.dta", clear

project, original("$da/NS_T1.dta") preserve
merge 1:1 IID q101 using "$da/NS_T1.dta", assert(3) nogen 

project, original("$da/NS_T3.dta") preserve
merge 1:1 IID q101 using "$da/NS_T3.dta", assert(3) nogen 

project, original("$da/NS_T5.dta") preserve
merge 1:1 IID q101 using "$da/NS_T5.dta", assert(3) nogen 

project, original("$da/NS_T11.dta") preserve
merge 1:1 IID q101 using "$da/NS_T11.dta", assert(3) nogen 

project, original("$da/NS_T12.dta") preserve
merge 1:1 IID q101 using "$da/NS_T12.dta", assert(3) nogen 

* Duplicates 
duplicates report IID 
assert  `r(unique_value)' ==  2145 & `r(N)'==2146
                  
count if IID == "31691984"
assert `r(N)'==2

* Start time of interview 
levelsof q101 if IID == "31691984"
assert "`r(levels)'" == "33365.75 43982.704"

* Drop the later interview 
drop if IID == "31691984" & q101==43982.704

duplicates report IID 
assert  `r(unique_value)' ==  2145 & `r(N)'==2145

* Covariaties - need a m:1 merge because there are 3 obs with missing Key_USE
duplicates tag Key_USE, gen(tag)
assert mi(Key_USE) if tag!=0
drop tag 

project, original("$da/Localities_wKey.dta") preserve
merge m:1 Key_USE using "$da/Localities_wKey.dta", assert(1 2 3) keep(1 3) nogen ////
    keepusing(IRQuartile MAQuartile Gov order )
rename order Locality 

project, original("$da/Covariates_Compliance.dta") preserve
merge m:1 Key_USE using "$da/Covariates_Compliance.dta" , assert(1 2 3) keep(1 3) nogen ////
    keepusing(A_*Subsidy T_*Subsidy HighScMoreLow HHSize_IA )


project, original("$da/children_baseline.dta") preserve
merge m:1 Key_USE using "$da/children_baseline.dta" , assert(1 2 3) keep(1 3) nogen ////
    keepusing(kids_hh0)

g FLEX_Sample = regex(Assignment, "In-F")


*-------------------------------------------------------------------------------
* LEE BOUNDS ANALYSIS 
*-------------------------------------------------------------------------------

/* Notes:
	everfound:	82.4 vs 90.5	->	8.1/90.5	= 8.95%
	midline:	77.3 vs 83.3 	->	6/83		= 7.2%
	endline:	71.9 vs 80.4 	->	8.5/80		= 10.6%
	followup:	71.5 vs 80.1 	->	8.5/80		= 10.7% 
	
	For social cohesion (relevant here):
	everfound:	69.5 vs 74.7	-> 5.2/74.7		= 6.96%
	
		0.0895 * 632 ~= 57
*/

set seed 12345

********************************************************************************
*-------------------------------------------------------------------------------
* REGRESSIONS
*-------------------------------------------------------------------------------

* Rename 
ren (AvgAidReceiv99_ppp_w) (ppp_w) // The name was too long when _U and _L were added 

* Set globals for controls 
global refugeecontrols HighScMoreLow HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile 

global HighSubsidyX ${refugeecontrols} MarlowCrowneIndex_High NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id
global LowSubsidyX ${refugeecontrols} MarlowCrowneIndex_Low NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id
global AllSubsidyX ${refugeecontrols} MarlowCrowneIndex_All NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id

********************************************************************************

*** Globals + Regressions for each family 

global sc_primary "SocialIndex_sd econIndex_sd policyIndex_sd Dict_Syrian"

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_primary) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_primary} {
        * Perform the IV regression for the main outcome
        ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_primary { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

global sc_socialindex_comp syrian_friends syrian_advice syrian_frnds_kid syrian_rec_space  ///
         net_societyHigh hardworkingHigh syrianmarriageHigh syrianneighborHigh

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_socialindex_comp) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_socialindex_comp} {
        * Perform the IV regression for the main outcome
        ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_socialindex_comp { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

global sc_social "MediaConsumption ppp_w"

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_social) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_social} {
        * Perform the IV regression for the main outcome
        ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_social { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************

global sc_mentalhealth "lifeSat_sd subjHlth_sd"

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(sc_mentalhealth) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${sc_mentalhealth} {
        * Perform the IV regression for the main outcome
        qui ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
        tempname M
        mat `M' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
        
			* Store coefficients, SEs, p-values, etc. in locals
			local `T'_b_`y' = string(`M'[1,1], "%15.2fc") 
			local `T'_se_`y' = string(`M'[2,1], "%12.2fc")
			local `T'_p_`y' = `M'[4,1]
			local `T'_star_`y' = cond(``T'_p_`y''<=.01,"***", cond(``T'_p_`y''<=.05,"**", cond(``T'_p_`y''<=.1,"*","")))
			local `T'_N_`y' = string(e(N), "%15.0fc")
			
        * Summarize the outcome variable for A_`T'Subsidy == 0
        summ `y' if A_`T'Subsidy == 0 
        local `T'_mean_`y' = string(r(mean), "%12.2fc")
        local `T'_sd_`y' = string(r(sd), "%12.2fc")
        
			* Store p-values in plist matrix for q-value calculation
			local i = `i' + 1
			mat `T'_plist[`i',1] = `M'[4,1]
    }
    
    * Calculate Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)
    
    forval q=1/`i' {
        local `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        display ``T'qval`q''
    }   
}

loc j=0
foreach y in $sc_mentalhealth { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}

********************************************************************************
// Social Attitudes & Policy Preferences

global regoutcomes refToCamp_sd RefRightWork_sd RefugeeCitizenship_sd RefEffctEcon_sd ///
    RefEffctSoc_sd PosEffctTotal_sd NegEffctTotal_sd proTaxes workEthic ///
    proWrkPrmits_sd proIntSchool_sd proFreeMove_sd ProHousAsstnce_sd ///
    ProIntlAsstnce_sd RefIntIndex_sd PrimIdentityRelig PrimIdentityNotJord ///
    MediaConsumption ChallengesForJordan perceptEcon_sd PropSyriansGetAid ppp_w

foreach T in High { 
    //Set up i and matrix for q-values 
    loc i=0  
    loc n : list sizeof global(regoutcomes) 
    local n = `n' 
    mat `T'_plist = J(`n', 1, .)

    //LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${regoutcomes} {
            ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
            tempname M
            mat `M' = r(table) //matrix that contains beta's, standard errors, p-vals etc 
            //stick the coeficients, se's etc in locals to write them to a table later
            local `T'_b_`y'          = string(`M'[1,1], "%15.2fc") 
            local `T'_se_`y'         = string(`M'[2,1], "%12.2fc")
            local `T'_p_`y'          = `M'[4,1]
            local `T'_star_`y'       =cond(``T'_p_`y''<=.01,"***", /// 
                                    cond(``T'_p_`y''<=.05,"**", /// 
                                    cond(``T'_p_`y''<=.1,"*","")))
            local `T'_N_`y'          = string(e(N), "%15.0fc")
            summ `y' if A_`T'Subsidy ==0 
            local `T'_mean_`y'       = string(r(mean), "%12.2fc")
            local `T'_sd_`y'         = string(r(sd), "%12.2fc")

            //stick the p-vlaues in plist matrix to generate q-values below
            loc i=`i'+1
            mat `T'_plist[`i',1]=`M'[4,1]
    }
    ***Q-Values
    minq `T'_plist, q(`T'_qlist) step(0.001)

    forv q=1/`i' {
        loc `T'qval`q' = string(`T'_qlist[`q',1], "%15.2fc")
        di ``T'qval`q''
    }   
}

loc j=0
foreach y in $regoutcomes { 
	local j = `j' + 1
	local q_`y' = string(`Highqval`j'', "%15.2fc")
}
	
	
********************************************************************************

* Variable labels 
local SocialIndex_sd_name "Social attitudes \& perceptions (SD)"
local econIndex_sd_name "Economic attitudes \& perceptions (SD)"
local policyIndex_sd_name "Policy preferences (SD)"
local Dict_Syrian_name "Altruism to Syrians"

local syrian_advice_name1 "Of the 3 people you exchange advice" 
local syrian_advice_name2 "with, how many are Syrian refugees?"
local syrian_frnds_kid_name1 "Do the children in this household"
local syrian_frnds_kid_name2 "have any Syrian refugee friends?"

local ppp_w_name1 "Neighbor perceptions of average"
local ppp_w_name "refugee aid receipt (PPP)"
local MediaConsumption_name "Days of media consumption (last week)"

local subjHlth_sd_name "Subjective Health (SD)"
local lifeSat_sd_name "Life Satisfaction (SD)"


*-------------------------------------------------------------------------------
* LEE BOUNDS REGRESSION 
*-------------------------------------------------------------------------------



********************************************************************************
* Lee Bounds
********************************************************************************

*-----------------
* Retention Gap
*-----------------
capture  program drop get_retention_gap
program define get_retention_gap, rclass
/* 
- Calculates the retention gap between treatment and control
- An observation is considered to be in the retention sample if the observation is
  included in the regression (i.e. no variables used in the regression are missing)
  The `y'_in_reg variable identifies.
*/


	args y
	capture drop `y'_in_reg 
	capture drop `y'_tempsamp  	
	// Main Regression to identify which observations are in the retention sample
	qui ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} if !missing(A_HighSubsidy), r cl(Locality)
	g `y'_in_reg = e(sample) // used in get_retention_gap program
	g `y'_tempsamp = e(sample) if e(sample)==1 //will be 1 or missing, missing get sorted to the end

	
	preserve
		project, original("$da/SampleList_Final_deid.dta") preserve
		merge m:1 Key_USE using "$da/SampleList_Final_deid.dta", force // For endline2.tex and endline3.tex variables
		
		replace A_HighSubsidy = .
			replace A_HighSubsidy = 0 if regex(Assignment, "FC")
			replace A_HighSubsidy = 1 if regex(Assignment, "FLEXT")
		
		//	Keep only the Flex sample and assign 0 to obs not f2f outcomes	
		keep if !missing(A_HighSubsidy)
		replace `y'_in_reg = 0 if missing(`y'_in_reg)
		
		di "Retention by treatment assignment for outcome `y':"
		tab `y'_in_reg A_HighSubsidy, m col matcell(`y'_rm)
		global `y'_c_r= `y'_rm[2,1]
		global `y'_t_r = `y'_rm[2,2]
		regress `y'_in_reg A_HighSubsidy
		return scalar `y'_gap = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		global `y'_gp = _b[A_HighSubsidy] / (_b[A_HighSubsidy] + _b[_cons])
		
	restore
end

*-----------------
* Lee Bound Estimates
*-----------------
capture  program drop get_lee_bounds
program define get_lee_bounds
	args y

	
	capture drop `y'_tempsamp
	capture drop `y'_temprand 
	capture drop `y'_obs_num
	capture drop `y'_in_reg
	
	// Get Retention Gap for each outcome	
	get_retention_gap `y'
	scalar `y'_gap = r(`y'_gap)
	di "Retention gap is " `y'_gap " for outcome `y'"
	
	//get percentage for trimming
	count if A_HighSubsidy==1 & `y'_tempsamp==1 //number of people who ran in the regression and who are assigned to treatment
	
	local ntrim = round(`r(N)' * `y'_gap, 1) //cutoff 
	di "Need to trim `ntrim' observations for outcome `y'"
	global `y'_ntrim = `ntrim'


	*-----------------
	* Trim Observations
	*-----------------

	isid IID, sort //necessary to ensure random variable is reproducible 
	g `y'_temprand = runiform() 
 

	//sort the data for trimming
	
	// This sets the same seed for all outcomes. Is that okay?
	set seed 123456789 
	set sortseed 123456789 
	
	di "Untrimmed summary of `y':"
	tabstat `y' if `y'_in_reg==1, by(A_HighSubsidy) statistics(n mean min max p50) save
		global `y'_m_c = r(Stat1)[2,1]
	global `y'_m_t = r(Stat2)[2,1]

	
	
	//	Loop over lower and upper bounds
	foreach bound_type in L U {
		 if "`bound_type'" == "L" {
			// Sort outcome in descending order		 	
			gsort `y'_tempsamp -A_HighSubsidy -`y' `y'_temprand 
		}
		else if "`bound_type'" == "U"{
			// Sort outcome in ascending order
			gsort `y'_tempsamp -A_HighSubsidy `y' `y'_temprand 
		}
		

	capture drop `y'_obs_num
	gen `y'_obs_num = _n
	
	quietly ivregress 2sls `y' (T_HighSubsidy = A_HighSubsidy) ${HighSubsidyX} if `y'_obs_num >`ntrim', r cl(Locality)
		
	tempname M
		
		mat `M' = r(table)

	di "Ran regression on trimmed `y' with `e(N)' observations for `bound_type' bound. Summary: "
	tabstat `y' if e(sample), by(A_HighSubsidy) statistics(n mean min max p50) save

	global `y'_m_`bound_type'_c = r(Stat1)[2,1]
	global `y'_m_`bound_type'_t = r(Stat2)[2,1]
	
		global `y'_n_`bound_type'_c = r(Stat1)[1,1]
	global `y'_n_`bound_type'_t = r(Stat2)[1,1]

		
		gl High_b_`y'_`bound_type'  = string(`M'[1,1], "%15.2fc")
		gl High_p_`y'_`bound_type'  = string(`M'[4,1], "%12.2fc")
		gl High_star_`y'_`bound_type' = cond(${High_p_`y'_`bound_type'}<=.01,"***",cond(${High_p_`y'_`bound_type'}<=.05,"**",cond(${High_p_`y'_`bound_type'}<=.1,"*","")))



}

end

global regoutcomes ///
SocialIndex_sd econIndex_sd policyIndex_sd Dict_Syrian ///
syrian_advice syrian_frnds_kid ///
MediaConsumption ppp_w /// 
lifeSat_sd subjHlth_sd

foreach T in High { 
    * Set up index and matrix for q-values 
    local i=0  
    local n : list sizeof global(regoutcomes) 
    mat `T'_plist = J(`n', 1, .)

    * LOOP THROUGH ALL THE OUTCOMES 
    foreach y in ${regoutcomes} {
		
		get_lee_bounds `y'
//         * Perform the IV regression for the upper bound
//         qui ivregress 2sls `y'_U (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
//         tempname M_U
//         mat `M_U' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
//        
// 			* Store upper bound coefficients, SEs, p-values, etc. in locals
// 			local `T'_b_`y'_U = string(`M_U'[1,1], "%15.2fc") 
// 			local `T'_se_`y'_U = string(`M_U'[2,1], "%12.2fc")
// 			local `T'_p_`y'_U = `M_U'[4,1]
// 			local `T'_star_`y'_U = cond(``T'_p_`y'_U'<=.01,"***", cond(``T'_p_`y'_U'<=.05,"**", cond(``T'_p_`y'_U'<=.1,"*","")))
//        
//         * Perform the IV regression for the lower bound
//         qui ivregress 2sls `y'_L (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX}, r cl(Locality)
//         tempname M_L
//         mat `M_L' = r(table)  // matrix that contains betas, standard errors, p-values, etc.
//        
// 			* Store lower bound coefficients, SEs, p-values, etc. in locals
// 			local `T'_b_`y'_L = string(`M_L'[1,1], "%15.2fc") 
// 			local `T'_se_`y'_L = string(`M_L'[2,1], "%12.2fc")
// 			local `T'_p_`y'_L = `M_L'[4,1]
// 			local `T'_star_`y'_L = cond(``T'_p_`y'_L'<=.01,"***", cond(``T'_p_`y'_L'<=.05,"**", cond(``T'_p_`y'_L'<=.1,"*","")))
		
		
		
		}
}


*-------------------------------------------------------------------------------
* TABLES OUTPUT
*-------------------------------------------------------------------------------

cap file close fh 

file open fh using "$dtab/table_a4_panela.tex",  replace write
foreach y in $regoutcomes {
    if inlist("`y'", "SocialIndex_sd", "econIndex_sd", "policyIndex_sd", "Dict_Syrian") {
		file write fh "``y'_name' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] & ${High_b_`y'_L}${High_star_`y'_L}  & ${High_b_`y'_U}${High_star_`y'_U} & `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n 
       
    }
}
file close fh
project, creates("$dtab/table_a4_panela.tex") preserve


* PANEL B
file open fh using "$dtab/table_a4_panelb.tex",  replace write 
foreach y in $regoutcomes {
    if inlist("`y'", "syrian_advice","syrian_frnds_kid") {
        file write fh "``y'_name1'  \\ " _n
		file write fh "``y'_name2' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] & ${High_b_`y'_L}${High_star_`y'_L}  & ${High_b_`y'_U}${High_star_`y'_U} & `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n 
     }
}
file close fh       
project, creates("$dtab/table_a4_panelb.tex") preserve


* PANEL C.1
file open fh using "$dtab/table_a4_panelc1.tex",  replace write
foreach y in $regoutcomes {
    if inlist("`y'","ppp_w")  {
		file write fh "``y'_name1'  \\ " _n
     }
     if inlist("`y'","MediaConsumption","ppp_w")  {
		file write fh "``y'_name' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] & ${High_b_`y'_L}${High_star_`y'_L}  & ${High_b_`y'_U}${High_star_`y'_U} & `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n 
     }
}
file close fh 
project, creates("$dtab/table_a4_panelc1.tex") preserve

* PANEL C.2 
file open fh using "$dtab/table_a4_panelc2.tex",  replace write
foreach y in $regoutcomes {
    if inlist("`y'", "lifeSat_sd", "subjHlth_sd") {
		file write fh "``y'_name' & `High_b_`y''`High_star_`y'' & (`High_se_`y'') &   [`q_`y''] & ${High_b_`y'_L}${High_star_`y'_L}  & ${High_b_`y'_U}${High_star_`y'_U} & `High_mean_`y'' & (`High_sd_`y'') &  `High_N_`y'' \\ " _n 
       
    }
}
file close fh
project, creates("$dtab/table_a4_panelc2.tex") preserve
