*-------------------------------------------------------------------------------
* TABLE B1: GENDER HETEROGENEITY AT ENDLINE
*-------------------------------------------------------------------------------

/*
NOTES/QUESTIONS: 
 
*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"


*-------------------------------------------------------------------------------
* IMPORT DATA 
*-------------------------------------------------------------------------------
project, original("$da/F2F_Outcomes.dta")
use "$da/F2F_Outcomes.dta", clear

project, original("$da/Covariates_Compliance.dta") preserve
merge 1:1 Key_USE using "$da/Covariates_Compliance.dta"
	drop if _merge==2
	drop _merge

project, original("$da/children_baseline.dta") preserve
merge 1:1 Key_USE using "$da/children_baseline.dta"
	drop if _merge==2
	drop _merge

// project, original("$da/Localities_wKey.dta") preserve
// merge 1:1 Key_USE using "$da/Localities_wKey.dta"
// 	drop if _merge==2
// 	drop _merge

//merge in Localities 
project,original("${da}/SampleList_Final_deid.dta") preserve
merge m:1 IID using "${da}/SampleList_Final_deid.dta", nogen assert(2 3 ) keep(3)  /// 
	keepusing(locality LocalityName Assignment IID) update 

replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"

project,original("${da}/LocalityAssignments_Complete.dta") preserve
merge m:1 LocalityName using "${da}/LocalityAssignments_Complete.dta", assert(2 3) keep(3) ///
	keepusing(LocalityName _ID order GOVCODE FTreatment RETreatment) nogen //_ID and order have 334 unique vars (if keep 2 and 3, which looks right)
rename GOVCODE Gov
//check that treatment assignment is the same across files to double check its right
assert FTreatment=="Control" if Assignment=="In-FControl"
assert FTreatment=="Treatment" if Assignment=="In-FLEXTreat"
assert RETreatment=="Control" if Assignment=="In-REControl"
assert RETreatment=="Treatment" if Assignment=="In-RETreat"

//merge in locality quartiles
preserve 
project,original("${da}/LocalityAssignments_Quartiles.dta") preserve
use  "${da}/LocalityAssignments_Quartiles.dta", clear 
replace LocalityName = subinstr(LocalityName, "`=char(10)'" , "" , . )
tempfile quartiles 
save `quartiles',replace 
restore 
merge m:1 LocalityName using `quartiles',  assert(2 3) keep(3) ///
	keepusing(MAQuartile IRQuartile)

drop locality LocalityName _ID //a bunch of not-right locality vars 
rename order Locality

drop _merge		

project, original("$da/duplicateWeights.dta") preserve
merge 1:1 IID using "$da/duplicateWeights.dta"
	drop if _merge==2
	drop _merge									
									
ta q110, m								
keep if q110==1 /*to remove if Lee Bounds are needed*/								
// ren order Locality											
	
* Assign head gender as FR gender is FR is head
g FemaleRoster= q504_1=="2" if q504_1!=" "
g FemaleHead = FemaleFR if respondent_same_hhhead=="Respondent is the household head" 

* Enumerators were supposed to enumerate head first if not FR 
replace FemaleHead = FemaleRoster if respondent_same_hhhead=="Respondent is not the household head" & FemaleRoster!=.
/*There are 50 people who are indicated NOT to be the head, but they are of household size 1. Thus, will assign them as the head. */
replace FemaleHead = FemaleFR if HHSize==1
	
g FLEX_Sample = regex(Assignment, "F")
ta Assignment FLEX_Sample

	
*-------------------------------------------------------------------------------
* T14
*-------------------------------------------------------------------------------

	
ren AllSubsidyQrt_H AllSubsidyQrt


foreach T in High {
	if `"`T'"'=="All" { 
		gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
				HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	i.FLEX_Sample			
	}
	
	else { 
		gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
				HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID			
	}

	gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 								
				HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	
				
	ren CommunityReligiosity`T' CommunityRel`T'
	ren ReligionImporatnce`T' ReligionImp`T'
	gl T14 CrimeIndexBi CrimeIndexNum SafetyNow2011 ArrestSyria PrisonSyria /// 
			  RecSpaceswJDKids LanguagesSpoken LanguagesLearned GenderIndex /// 
			  CommunityRel ReligionImp MosqueDonations /// 
			  ReligiousSalience AttndMosque TimeDonation EconOptimism

	foreach y in $T14  {
		cap gen `y'=.
		cap replace `y'=`y'`T'
	}


***Treatment-on-Treated								
	loc i=0	 						
	loc n : list sizeof global(T14) 							
	mat `T'_plist = J(`n', 1, .) 							
	foreach y in $T14 {							
		cap ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)						
		tempname M						
		mat `M' = r(table)						
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 						
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")						
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")						
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))						
		loc `T'_N_`y' = string(e(N), "%15.0fc")						
		qui sum `y' if A_`T'Subsidy==0 						
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")						
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")						
		loc i=`i'+1						
		mat `T'_plist[`i',1]=`M'[4,1]						
	}							
								
	***Q-Values							
	minq `T'_plist, q(`T'_qlist) step(0.001)							
	forv q=1/`i' {							
		loc `T'qval`q' = string(qlist[`q',1], "%15.2fc")						
		di ``T'qval`q''						
	}							
}								


*-------------------------------------------------------------------------------
* EXTRA
*-------------------------------------------------------------------------------

cap ren AllSubsidyQrt_H AllSubsidyQrt

foreach T in High { 
	ren PoliticsComplexStt`T' PoliticsComStt`T'
	ren GoAloneMrktLevels`T' GoAloneMrktL`T'
	ren GoAloneVisitLevels`T' GoAloneVisitL`T'
	gl Extra ComMosqueAttend SectImportant JDFriendsFR SocializeJD3 /// 
			 SocializeSameGender3 ImpAdviceJD3 ImpAdviceSameGender3 /// 
			 FeelPartofComm CompetitionStt PoliticsComStt /// 
			 EconNow2Yrs Wasta SadaqaNotTaxes GoAloneMrktL GoAloneMrkt ///
			 GoAloneVisitL GoAloneVisit SafetyMen SafetyWomen /// 
			 WomanWorkStt HusbandDecideStt WomanPresStt DivorceEqualStt

foreach v in FeelPartofComm CompetitionStt PoliticsComStt /// 
			 EconNow2Yrs Wasta GoAloneMrktL  ///
			 GoAloneVisitL  SafetyMen SafetyWomen /// 
			 WomanWorkStt HusbandDecideStt WomanPresStt DivorceEqualStt {
				cap gen `v'=.
				cap replace `v'=`v'`T'
			 }
***Treatment-on-Treated								
	loc i=0	 						
	loc n : list sizeof global(Extra) 							
	mat `T'_plist = J(`n', 1, .) 							
	foreach y in ${Extra} {							
		qui cap ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)						
		tempname M						
		mat `M' = r(table)						
		loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc") 						
		loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")						
		loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")						
		loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))						
		loc `T'_N_`y' = string(e(N), "%15.0fc")						
		qui su `y' if A_`T'Subsidy==0 						
		loc `T'_mean_`y'= string(r(mean), "%12.2fc")						
		loc `T'_sd_`y'  = string(r(sd), "%12.2fc")						
		loc i=`i'+1						
		mat `T'_plist[`i',1]=`M'[4,1]	

	}							
								
	***Q-Values							
	minq `T'_plist, q(`T'_qlist) step(0.001)							
	forv q=1/`i' {							
		loc `T'qval`q' = string(qlist[`q',1], "%15.2fc")						
		di ``T'qval`q''						
		}	
	}						

*-------------------------------------------------------------------------------
* HETEROGENEITY
*-------------------------------------------------------------------------------

foreach H in FemaleFR { 
		foreach T in High { 
			gl Het_SocCapital GoAloneMrktLevels GoAloneVisitLevels SafetyWomen GenderIndex 
			loc i=0	 
			loc n : list sizeof global(Het_SocCapital) 
			mat `T'_plist = J(`n', 1, .) 
			foreach y in ${Het_SocCapital} {
				cap ren `y' `y'`T'
				ivregress 2sls `y'`T' (c.T_`T'Subsidy c.T_`T'Subsidy#c.`H' = /// 
					                    c.A_`T'Subsidy c.A_`T'Subsidy#c.`H') `H' ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)
				tempname M
				mat `M' = r(table)
				forv j=1/3 { 
					loc `T'_b`j'_`y'  = string(`M'[1,`j'], "%15.2fc") 
					loc `T'_se`j'_`y' = string(`M'[2,`j'], "%12.2fc")
					loc `T'_p`j'_`y'  = string(`M'[4,`j'], "%12.2fc")
					loc `T'_star`j'_`y'=cond(``T'_p`j'_`y''<=.01,"***",cond(``T'_p`j'_`y''<=.05,"**",cond(``T'_p`j'_`y''<=.1,"*","")))				
				}
					loc `T'_N_`y' = string(e(N), "%15.0fc")
					su `y'`T' if A_`T'Subsidy==0 
					loc `T'_mean_`y'= string(r(mean), "%12.2fc")
					loc `T'_sd_`y'  = string(r(sd), "%12.2fc")
			lincom c.T_`T'Subsidy + c.T_`T'Subsidy#c.`H'
			loc f_`T'_`y'=string(r(p), "%12.2fc")
			
			}
	loc lab_GoAloneMrktLevels`T'    "Market Freedom of Mobility (Z-Score)"
	loc lab_GoAloneVisitLevels`T'   "Visit Relatives Freedom of Mobility (Z-Score)"
	loc lab_SafetyWomen`T'          "Safety During the Day for Women (Z-Score)"
	loc lab_GenderIndex`T'          "Gender Equality Index"
		}
}


*-------------------------------------------------------------------------------
* CREATE TABLE 
*-------------------------------------------------------------------------------

cap file close fh 
file open fh using "$dtab/endline_het.tex", replace write
	foreach T in High { 
		file write fh "Treat&``T'_b1_GoAloneMrktLevels'``T'_star1_GoAloneMrktLevels' & ``T'_b1_GoAloneVisitLevels'``T'_star1_GoAloneVisitLevels' & ``T'_b1_SafetyWomen'``T'_star1_SafetyWomen' & ``T'_b1_GenderIndex'``T'_star1_GenderIndex' \\" _n
		file write fh "&(``T'_se1_GoAloneMrktLevels')                           & (``T'_se1_GoAloneVisitLevels')                            & (``T'_se1_SafetyWomen')                     & (``T'_se1_GenderIndex') & \\" _n
		file write fh "Female&``T'_b3_GoAloneMrktLevels'``T'_star3_GoAloneMrktLevels' & ``T'_b3_GoAloneVisitLevels'``T'_star3_GoAloneVisitLevels' & ``T'_b3_SafetyWomen'``T'_star3_SafetyWomen' & ``T'_b3_GenderIndex'``T'_star3_GenderIndex'  \\" _n
		file write fh "&(``T'_se3_GoAloneMrktLevels')                           & (``T'_se3_GoAloneVisitLevels')                            & (``T'_se3_SafetyWomen')                     & (``T'_se3_GenderIndex') &\\" _n
		file write fh "Treat*Female&``T'_b2_GoAloneMrktLevels'``T'_star2_GoAloneMrktLevels' & ``T'_b2_GoAloneVisitLevels'``T'_star2_GoAloneVisitLevels' & ``T'_b2_SafetyWomen'``T'_star2_SafetyWomen' & ``T'_b2_GenderIndex'``T'_star2_GenderIndex' \\" _n
		file write fh "&(``T'_se2_GoAloneMrktLevels')                           & (``T'_se2_GoAloneVisitLevels')                            & (``T'_se2_SafetyWomen')                     & (``T'_se2_GenderIndex') & \\" _n
		file write fh "\midrule\relax" _n
		file write fh "p-val: T + T*female=0 &`f_`T'_GoAloneMrktLevels' & `f_`T'_GoAloneVisitLevels' & `f_`T'_SafetyWomen' & `f_`T'_GenderIndex' \\" _n
		file write fh "Control mean&``T'_mean_GoAloneMrktLevels' & ``T'_mean_GoAloneVisitLevels' & ``T'_mean_SafetyWomen' & ``T'_mean_GenderIndex' & \\" _n
		file write fh "Control sd&``T'_sd_GoAloneMrktLevels'   & ``T'_sd_GoAloneVisitLevels'   & ``T'_sd_SafetyWomen'   & ``T'_sd_GenderIndex'   & \\" _n
		file write fh "N&``T'_N_GoAloneMrktLevels'    & ``T'_N_GoAloneVisitLevels'   & ``T'_N_SafetyWomen'   & ``T'_N_GenderIndex'    & \\" _n
	}

file close fh 
project, creates("$dtab/endline_het.tex") preserve
