

****************************
** S-RLS RCT Neighbor Survey **
** Analyze			      **                                     
****************************

 ** NOTES: Run the regressions
 ** WRITTEN BY:   Bailey Palmer
 ** Date created: April 23 2023

clear all
set more off
set maxvar 10000
//ssc install missings

***************************

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"


project, original("${da}/NS_sample_deidentified.dta")
use "${da}/NS_sample_deidentified.dta", clear

/////////////////////////////////////////////////
//IMPORT OUTCOMES 
/////////////////////////////////////////////////
project, original("${da}/NS_T1.dta") preserve
merge 1:1 IID q101 using "${da}/NS_T1.dta", assert(3) nogen 

project, original("${da}/NS_het.dta") preserve
merge 1:1 IID q101 using "${da}/NS_het.dta", assert(3) nogen 

project, original("${da}/NS_sample_deidentified.dta") preserve
merge 1:1 IID q101 using "${da}/NS_T12.dta", assert(3) nogen 

/////////////////////////////////////////////////
//DEAL WITH A DUPLICATE
/////////////////////////////////////////////////
duplicates report IID 
assert  `r(unique_value)' ==  2145 & `r(N)'==2146
                  
count if IID == "31691984"
assert `r(N)'==2

//start time of interview 
levelsof q101 if IID == "31691984"
assert "`r(levels)'" == "33365.75 43982.704"
//drop the later interview 
drop if IID == "31691984" & q101==43982.704

duplicates report IID 
assert  `r(unique_value)' ==  2145 & `r(N)'==2145

/////////////////////////////////////////

//covariaties - need a m:1 merge because there are 3 obs with missing Key_USE
duplicates tag Key_USE, gen(tag)
assert mi(Key_USE) if tag!=0
drop tag 


project, original("${da}/Localities_wKey.dta") preserve
merge m:1 Key_USE using "${da}/Localities_wKey.dta", assert(1 2 3) keep(1 3) nogen ////
    keepusing(IRQuartile MAQuartile Gov order )
rename order Locality 

project, original("${da}/Covariates_Compliance.dta") preserve
merge m:1 Key_USE using "${da}/Covariates_Compliance.dta" , assert(1 2 3) keep(1 3) nogen ////
    keepusing(A_*Subsidy T_*Subsidy HighScMoreLow HHSize_IA *SubsidyQrt)

project, original("${da}/Covariates_Compliance.dta") preserve
merge m:1 Key_USE using "${da}/children_baseline.dta" , assert(1 2 3) keep(1 3) nogen ////
    keepusing(kids_hh0)


g FLEX_Sample = regex(Assignment, "In-F")

/* destring IID, replace 

merge 1:1 IID using "${DropDir}/Weights/duplicateWeights.dta", keepusing(weightps weightf2f)
 */


//controls
global refugeecontrols HighScMoreLow HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile 

gl HighSubsidyX ${refugeecontrols} MarlowCrowneIndex_High NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id
gl HighSubsidyX_noMC ${refugeecontrols} NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id

gl LowSubsidyX ${refugeecontrols} MarlowCrowneIndex_Low NeighborEd* GenderNeighbor AgeNeighborBins i.enum_id

global regoutcomes SocialIndex_sd econIndex_sd policyIndex_sd Dict_Syrian




//run all the heterogeneity 
   
local SocialIndex_sd_name "Social attitudes and perceptions"
local econIndex_sd_name "Economic attitudes and perceptions"
local policyIndex_sd_name "Policy preferences"
local Dict_Syrian_name "Altruism to Syrians"

global regoutcomes SocialIndex_sd econIndex_sd policyIndex_sd Dict_Syrian


foreach H in abovemed_MCI palestinian_hertg nonnative_grandprt above_mediandist dist_mindset {
    local T "High"
    loc i=0  
    loc n : list sizeof global(regoutcomes) 
    mat `T'_plist = J(`n', 1, .) 
    foreach y in ${regoutcomes} {
        if "`H'"=="abovemed_MCI" {
            ivregress 2sls `y' (c.T_`T'Subsidy c.T_`T'Subsidy#c.`H' = c.A_`T'Subsidy c.A_`T'Subsidy#c.`H') ///
            `H' ${`T'SubsidyX_noMC}, r cl(Locality)
        }
        else {
            ivregress 2sls `y' (c.T_`T'Subsidy c.T_`T'Subsidy#c.`H' = c.A_`T'Subsidy c.A_`T'Subsidy#c.`H') ///
            `H' ${`T'SubsidyX}, r cl(Locality)
        }
        //ta `H' if e(sample)
        tempname M
        mat `M' = r(table)
        forv j=1/3 { //order is T , Txhet, het 
            loc `T'_b`j'_`y'  = string(`M'[1,`j'], "%15.2fc") 
            loc `T'_se`j'_`y' = string(`M'[2,`j'], "%12.2fc")
            loc `T'_p`j'_`y'  = string(`M'[4,`j'], "%12.2fc")
            loc `T'_star`j'_`y'=cond(``T'_p`j'_`y''<=.01,"***",cond(``T'_p`j'_`y''<=.05,"**",cond(``T'_p`j'_`y''<=.1,"*","")))              
        }
        loc `T'_N_`y' = string(e(N), "%15.0fc")
        qui su `y' if A_`T'Subsidy==0 
        loc `T'_mean_`y'= string(r(mean), "%12.2fc")
        loc `T'_sd_`y'  = string(r(sd), "%12.2fc")

    }
}


//////////////////////////////////////////////////////////////
//PUT ALL THE HETEROGENEITY RESULTS FOR SOCIAL ATTITUDES INTO 1 TABLE
//////////////////////////////////////////////////////////////
foreach H in abovemed_MCI palestinian_hertg nonnative_grandprt above_mediandist dist_mindset {

    if "`H'"=="abovemed_MCI" {
        ivregress 2sls SocialIndex_sd (c.T_HighSubsidy c.T_HighSubsidy#c.`H' = c.A_HighSubsidy c.A_HighSubsidy#c.`H') ///
        `H' ${HighSubsidyX_noMC}, r cl(Locality)
    }
    else {
        ivregress 2sls SocialIndex_sd (c.T_HighSubsidy c.T_HighSubsidy#c.`H' = c.A_HighSubsidy c.A_HighSubsidy#c.`H') ///
        `H' ${HighSubsidyX}, r cl(Locality)
    }
    //ta `H' if e(sample)
    tempname M
    mat `M' = r(table)
    forv j=1/3 { //order is T , Txhet, het 
        loc `H'_b`j'  = string(`M'[1,`j'], "%15.2fc") 
        loc `H'_se`j' = string(`M'[2,`j'], "%12.2fc")
        loc `H'_p`j'  = string(`M'[4,`j'], "%12.2fc")
        loc `H'_star`j'=cond(``H'_p`j''<=.01,"***",cond(``H'_p`j''<=.05,"**",cond(``H'_p`j''<=.1,"*","")))              
    }
    lincom T_HighSubsidy+c.T_HighSubsidy#c.`H'
    local `H'_lincomp = string(r(p),"%15.2fc")

    test (T_HighSubsidy=0) (c.T_HighSubsidy#c.`H'=0)
    local `H'_jointp = string(r(p),"%15.2fc")

    loc `H'_N = string(e(N), "%15.0fc")
    qui su SocialIndex_sd if A_HighSubsidy==0 
    loc `H'_mean= string(r(mean), "%12.2fc")
    loc `H'_sd  = string(r(sd), "%12.2fc")

}

file open fh using "${dtab}/Het_socialattitudes.tex", replace write
local row1 "Treat"
local row2 " "
foreach H in abovemed_MCI palestinian_hertg nonnative_grandprt above_mediandist /* dist_mindset */ {
    local row1 "`row1' & ``H'_b1'``H'_star1'"
    local row2 "`row2' & (``H'_se1')"
    }
file write fh "  `row1' \\  " _n
file write fh "  `row2' \\  " _n

file write fh " Above Median Marlow-Crowne & `abovemed_MCI_b3'`abovemed_MCI_star3' &&& \\  " _n
file write fh "  & (`abovemed_MCI_se3') &&& \\  " _n

file write fh " Treat*Above Median Marlow-Crowne & `abovemed_MCI_b2'`abovemed_MCI_star2' &&& \\  " _n
file write fh "  & (`abovemed_MCI_se2') &&& \\  " _n

file write fh " Palestinian Grandparents && `palestinian_hertg_b3'`palestinian_hertg_star3' && \\  " _n
file write fh "  && (`palestinian_hertg_se3') && \\  " _n

file write fh " Treat*Palestinian Grandparents && `palestinian_hertg_b2'`palestinian_hertg_star2' && \\  " _n
file write fh "  && (`palestinian_hertg_se2') && \\  " _n

file write fh " Non-Jordanian Grandparents &&& `nonnative_grandprt_b3'`nonnative_grandprt_star3' & \\  " _n
file write fh "  &&& (`nonnative_grandprt_se3') & \\  " _n

file write fh " Treat*Non-Jordanian Grandparents &&& `nonnative_grandprt_b2'`nonnative_grandprt_star2' & \\  " _n
file write fh "  &&& (`nonnative_grandprt_se2') & \\  " _n

file write fh " Above Median Distance &&&& `above_mediandist_b3'`above_mediandist_star3'  \\  " _n
file write fh "  &&&& (`above_mediandist_se3')  \\  " _n

file write fh " Treat*Above Median Distance &&&& `above_mediandist_b2'`above_mediandist_star2'  \\  " _n
file write fh "  &&& &(`above_mediandist_se2')  \\  " _n

file write fh " \midrule   " _n

local row1 "p-val: T + T*Het = 0"
local row3 "Control Mean"
local row4 "Control SD"
local row5 "N"


foreach H in abovemed_MCI palestinian_hertg nonnative_grandprt above_mediandist /* dist_mindset */ {
    local row1 "`row1' & ``H'_lincomp'"
    local row3 "`row3' & ``H'_mean'"
    local row4 "`row4' & ``H'_sd'"
    local row5 "`row5' & ``H'_N'"
    }

file write fh "   `row1'   \\  " _n
file write fh "   `row3'   \\  " _n
file write fh "   `row4'   \\  " _n
file write fh "   `row5'   \\  " _n


file close fh 
project, creates("${dtab}/Het_socialattitudes.tex") preserve




 