** -------------------------------------------- **									
* Author: Abdulrazzak Tamim 									
* First version: 17/Mar/2022									
** -------------------------------------------- **														

									
* User must define two global macros in order to run the program:									
* (1) "BoxDir" contains the raw data									
* (2) "GitDir" contains scripts									
									
*WARNING: Q-VALUES MAY NEED TO BE ADJUSTED IF SOME OUTCOMES ARE CHANGED GIVEN THE MISSING VALUES.									
								
									
clear all									
set more off									
program drop _all									
set maxvar 10000									
set seed 5693
								
* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

								
program main									
									
	ReadIn								
	T6								
									
end									
									
									
program ReadIn
    
	project,original("${da}/F2F_Outcomes.dta") preserve
	use "${da}/F2F_Outcomes.dta", clear
	
	project,original("${da}/Covariates_Compliance.dta") preserve
	merge 1:1 Key_USE using "${da}/Covariates_Compliance.dta"
		drop if _merge==2
		drop _merge
	
	project,original("${da}/children_baseline.dta") preserve
	merge 1:1 Key_USE using "${da}/children_baseline.dta"
		drop if _merge==2
		drop _merge
	/*
	merge 1:1 Key_USE using "${BoxDir}/RCT/2022 - F2F/cleaned/Localities_wKey.dta"
		drop if _merge==2
		drop _merge
	*/
//merge in Localities
project,original("${da}/SampleList_Final_deid.dta") preserve 
merge m:1 IID using "${da}/SampleList_Final_deid.dta", nogen assert(2 3 ) keep(3)  /// 
	keepusing(locality LocalityName Assignment IID) update 

replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"

project,original("${da}/LocalityAssignments_Complete.dta") preserve 
merge m:1 LocalityName using "${da}/LocalityAssignments_Complete.dta", assert(2 3) keep(3) ///
	keepusing(LocalityName _ID order GOVCODE FTreatment RETreatment) nogen //_ID and order have 334 unique vars (if keep 2 and 3, which looks right)
rename GOVCODE Gov
//check that treatment assignment is the same across files to double check its right
assert FTreatment=="Control" if Assignment=="In-FControl"
assert FTreatment=="Treatment" if Assignment=="In-FLEXTreat"
assert RETreatment=="Control" if Assignment=="In-REControl"
assert RETreatment=="Treatment" if Assignment=="In-RETreat"

//merge in locality quartiles
preserve 
project,original("${da}/LocalityAssignments_Quartiles.dta") preserve
use  "${da}/LocalityAssignments_Quartiles.dta", clear 
replace LocalityName = subinstr(LocalityName, "`=char(10)'" , "" , . )
tempfile quartiles 
save `quartiles',replace 
restore 
merge m:1 LocalityName using `quartiles',  assert(2 3) keep(3) ///
	keepusing(MAQuartile IRQuartile)

drop locality LocalityName _ID //a bunch of not-right locality vars 
rename order Locality

drop _merge	
	
	project,original("${da}/duplicateWeights.dta") preserve
	merge 1:1 IID using "${da}/duplicateWeights.dta"
		drop if _merge==2
		drop _merge
									
	ta q110, m								
	keep if q110==1 /*to remove if Lee Bounds are needed*/								
	//ren order Locality	
	
	g FLEX_Sample = regex(Assignment, "F")
	ta Assignment FLEX_Sample
									
end									
									
									
program T6									
	noisily display "In T6"
	ren AllSubsidyQrt_H AllSubsidyQrt
	ren TotalEarnings30D_PPP_W_IHS Earnings30D_PPP_W_IHS
	ren NetSalary30D_PPP_W_IHS Salary30D_PPP_W_IHS
	gl T6 BusinessDummy EmployeeDummy WorkingDummy /// 								
		  Earnings30D_PPP_W_IHS /*Taxes30D_PPP_W*/ TotalHours7D TotalHours7D_wChores /// 							
		  TypicalHoursM SalaryHours7D BusinessHours7D Hours7DAdults /// 							
		  Salary30D_PPP_W_IHS /*Profit30D_IHS_W*/ SeasonalWork Manufacturing Construction /// 							
		  Service ServiceH ServiceL Trade FormalBusiness /*Revenue30D_IHS_W*/ Revenue12M_PPP_W_IHS /// 							
		  /*BusinessWorkers30D_W*/ WaiveBusiness /*Profit30D_PPP_W*/ Profit12M_PPP /// 							
		  /*BusinessExp30D_PPP_W BusinessExp12M_PPP_W BusinessRent30D_PPP_W*/ /// 							
		  JobSearchWeeks ChoresChildcareFR							
									
	***Treatment-on-Treated								
	foreach T in High {
		noisily display "In for loop"
		if `"`T'"'=="All" { 
			gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
					HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID	i.FLEX_Sample			
				}
		else { 
			gl `T'SubsidyX FemaleFR i.AgeFR i.`T'SubsidyQrt i.Month_Year HighScMoreLow /// 
					HHSize_IA kids_hh0 i.Gov i.MAQuartile i.IRQuartile i.enumID			
			}	
			
		loc i=0	 						
		loc n : list sizeof global(T6) 							
		mat `T'_plist = J(`n', 1, .) 							
		foreach y in $T6 {							
			cap ivregress 2sls `y' (T_`T'Subsidy = A_`T'Subsidy) ${`T'SubsidyX} [pw=weightf2f], r cl(Locality)						
			tempname M						
			mat `M' = r(table)						
			loc `T'_b_`y'  = string(`M'[1,1], "%15.2fc")
			noisily di "Coefficient for `y' is ``T'_b_`y'"
			loc `T'_se_`y' = string(`M'[2,1], "%12.2fc")						
			loc `T'_p_`y'  = string(`M'[4,1], "%12.2fc")						
			loc `T'_star_`y'=cond(``T'_p_`y''<=.01,"***",cond(``T'_p_`y''<=.05,"**",cond(``T'_p_`y''<=.1,"*","")))						
			loc `T'_N_`y' = string(e(N), "%15.0fc")						
			su `y' if A_`T'Subsidy==0 						
			loc `T'_mean_`y'= string(r(mean), "%12.2fc")						
			loc `T'_sd_`y'  = string(r(sd), "%12.2fc")						
			loc i=`i'+1						
			mat `T'_plist[`i',1]=`M'[4,1]						
		}							
									
		***Q-Values							
		minq `T'_plist, q(`T'_qlist) step(0.001)							
		forv q=1/`i' {							
			loc `T'qval`q' = string(qlist[`q',1], "%15.2fc")						
			// di ``T'qval`q''						
		}
		
		loc j=0
		foreach y in $T6 { 
			local j = `j' + 1
			local q_`y' = string(`Highqval`j'', "%15.2fc")
		}


	}					
									
	loc lab_BusinessDummy           "Self-Employment (=1)"								
	loc lab_EmployeeDummy           "Wage-Employment (=1)"								
	loc lab_WorkingDummy            "Employment (=1)"								
	loc lab_Earnings30D_PPP_W_IHS    "Total Earnings in Last 30 Days (PPP, IHS)"								
	loc lab_Taxes30D_PPP_W          "Taxes Paid in Last 30 Days (USD PPP)"								
	loc lab_TotalHours7D            "Total Labor Hours Last Week"								
	loc lab_TotalHours7D_wChores    "Total Labor and Chores Hours Last Week"								
	loc lab_TypicalHoursM           "Total Labor Hours [Monthly Average]"								
	loc lab_SalaryHours7D           "Wage-Employment Hours Last Week"								
	loc lab_BusinessHours7D         "Self-Employment Hours Last Week"								
	loc lab_Hours7DAdults           "Wage-Employment Adult Labor Hours Last Week"								
	loc lab_Salary30D_PPP_W_IHS        "Net Wage-Employment Income Last Month (PPP,IHS)"								
	loc lab_Profit30D_IHS_W         "Self-Employment Profits Last Month (IHS)"								
	loc lab_SeasonalWork            "Any Seasonal Wage-Employment (=1)"								
	loc lab_Manufacturing           "Any Manufacturing Employment (=1)"								
	loc lab_Construction            "Any Construction Employment (=1)"								
	loc lab_Service                 "Any Service Employment (=1)"								
	loc lab_ServiceH                "Any High-Skill Service Employment (=1)"								
	loc lab_ServiceL                "Any Low-Skill Service Employment (=1)"								
	loc lab_Trade                   "Any Trade Employment (=1)"								
	loc lab_FormalBusiness          "Any Formal Business (=1)"								
	loc lab_Revenue30D_IHS_W        "Self-Employment Revenues Last Month (IHS)"								
	loc lab_Revenue12M_PPP_W_IHS          "Self-Employment Revenues Last Year (PPP,IHS)"								
	loc lab_BusinessWorkers30D_W    "Total Employees Last Month"								
	loc lab_WaiveBusiness           "Any Loss of Business Control (=1)"								
	loc lab_Profit30D_PPP_W         "Self-Employment Profits Last Month (USD PPP)"								
	loc lab_Profit12M_PPP           "Self-Employment Profits Last Year (USD PPP)"								
	loc lab_BusinessExp30D_PPP_W    "Self-Employment Expenses Last Month (USD PPP)"								
	loc lab_BusinessExp12M_PPP_W    "Self-Employment Expenses Last Year (USD PPP)"								
	loc lab_BusinessRent30D_PPP_W   "Self-Employment Rent Last Month (USD PPP)"								
	loc lab_JobSearchWeeks          "Job Search (Weeks)"								
	loc lab_ChoresChildcareFR       "Focus Respondent Childcare \& Chores (Hours)"								
									
	
	

	////////////
	//appendix
	////////////
	cap file close
	file open fh using "${dtab}/endline_emp_appendix.tex", replace write
	foreach T in High { 
		foreach y in Earnings30D_PPP_W_IHS TotalHours7D TypicalHoursM Salary30D_PPP_W_IHS {
			file write fh " `lab_`y'' & ``T'_b_`y'' ``T'_star_`y'' & (``T'_se_`y'') &   [`q_`y''] &  ``T'_mean_`y'' & (``T'_sd_`y'') &  ``T'_N_`y'' \\ " _n		
		}
	}
	file close fh
end

main
project,creates("${dtab}/endline_emp_appendix.tex") preserve