*-------------------------------------------------------------------------------
* CONSTRUCTING DATASET: PS_merge_alloutcomes.dta 
*-------------------------------------------------------------------------------

/*
NOTES: 

	- The do file that created each dataset used in this file can be found here: "/Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/Phone Survey/3. Construct/code/endline"

*/


clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"

*-------------------------------------------------------------------------------
* MERGE DATASETS + SAVE THE COMBINED CLEAN DATASET 
*-------------------------------------------------------------------------------

* Import Dwelling data
use "${dr}/Phone Survey/PS_T2_dwelling.dta", replace	

* Merge with Consumption data
merge 1:1 IID using "${dr}/Phone Survey/PS_T3_consumption.dta"	
	tab _ 
	drop _

* Merge with Migration data 	
merge 1:1 IID using "${dr}/Phone Survey/PS_T7_migration.dta"	
	tab _ 
	drop _

* Merge with Physical Health data
merge 1:1 IID using "${dr}/Phone Survey/PS_T8_physical_health.dta"
	tab _ 
	drop _
	
* Merge with Mental Health data
merge 1:1 IID using "${dr}/Phone Survey/PS_T9_mental_health.dta"	
	tab _ 
	drop _

* Merge with Child Outcomes data 
merge 1:1 IID using "${dr}/Phone Survey/PS_T13_child_outcomes.dta"	
	tab _ 
	drop _

* Merge with Education data 
merge 1:1 IID using "${dr}/Phone Survey/PS_T17_education.dta"	
	tab _ 
	drop _
	
* Merge with Covid data 
merge 1:1 IID using "${dr}/Phone Survey/PS_T19_20_21_COVID.dta"		
	tab _ 
	drop _

* Merge with HH Composition data 
merge 1:1 IID using "${dr}/Phone Survey/children_endline.dta"
	tab _ 
	drop _
		
* Winsorize some variables as specified in the PAP
local winsor housing_exp_ppp pc_housing_exp_ppp rent_pay_ppp mortgage_ppp /// 
food_c_assist_ppp health_exp_ppp medicine_exp_ppp hr_work_pre_covid hr_work_at_covid /// 
hr_work_aft_covid income_pre_covid_ppp income_at_covid_ppp income_aft_covid_ppp /// 
loan_pre_covid loan_at_covid loan_aft_covid /// 
log_loan_pre_covid log_loan_at_covid log_loan_aft_covid /// 
log_give_loan_pre log_give_loan_at log_give_loan_aft debt_ppp rent_agreed_ppp /// 
assist_person q6_2_05a q6_2_06a q6_2_07a q6_2_09b q6_2_10b q6_2_11b health_visits

foreach var in `winsor' {	
	winsor2 `var', s(_w) cuts (0 99) 
}	

* Save the clean dataset 
save "${da}/PS_all_outcomes.dta", replace
