*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY CHILD OUTCOMES (PS_T2_child_outcomes)
*-------------------------------------------------------------------------------

/*
NOTES: 

	- 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* NOTES FROM THE PRE-ANALYSIS PLAN 
*-------------------------------------------------------------------------------

/*

Table of Contents

***** Title from Table 13 in Pre-Analysis Plan ----- var name

***** 13.1 Count of non-adult dependents ----------- n_children
***** 13.2 School attendance ----------------------- tot_school_days; n_child_school; 
													school_day_per_child
***** 13.3 Child food security --------------------- hungry_days_child
*/


*-------------------------------------------------------------------------------
* CLEAN
*-------------------------------------------------------------------------------

* Load the dataset + merge 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

sort IID


*********************************
***** 13.2 School attendance*****
*********************************

ta q405_1 q409_1
ta q405_2 q409_2

keep IID q409_* q405_? q405_??

reshape long q405_ q409_, i(IID) j(num)
g age_skl = q405_<18 & q405_>=9
ta age_skl 
collapse (sum) tot_school_days=q409_  (sum) n_child_school=age_skl , by(IID)
ta n_child_school
gen school_day_per_child = tot_school_days/n_child_school

label var tot_school_days "#school days attended by all hh children in past 5 days"
label var n_child_school "#children in hh attended/didnt attend school in past 5 days"
label var school_day_per_child "#school days attended÷#children attended/didnt attend school"

merge 1:1 IID using "$dr/Phone Survey/00_raw_private/PS_clean_final.dta"

*binscatter n_children n_child_school 

tabstat school_day_per_child, by(n_child_school)
tabstat school_day_per_child, by(n_children)


***********************************
***** 13.3 Child food security*****
***********************************

tab q6_1_02b

gen hungry_days_child = q6_1_02b

tab hungry_days_child
label var hungry_days_child "# days in the last 7 days on which any child slept hungry"


gen hungry_bi_child=.
	replace hungry_bi_child=0 if q6_1_02b==0 & q6_1_02b!=.
	replace hungry_bi_child=1 if q6_1_02b!=0 & q6_1_02b!=.

ta hungry_bi_child q6_1_02b
label var hungry_bi_child "=1 if children slept hungry for at least 1 day in past 7 days"


*********************************************
***** 13.1 Count of non-adult dependents*****
*********************************************

/* defined as n_children */
label var n_children "# children in hh who are aged less than 18 years old"


*****************************************************************************
sum n_children school_day_per_child tot_school_days n_child_school hungry_days_child hungry_bi_child IID
des n_children school_day_per_child tot_school_days n_child_school hungry_days_child hungry_bi_child IID
keep n_children school_day_per_child tot_school_days n_child_school hungry_days_child hungry_bi_child IID


save "$dr/Phone Survey/PS_T13_child_outcomes.dta", replace
