*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY DWELLING (PS_T2_dwelling)
*-------------------------------------------------------------------------------

/*
NOTES: 

	- 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* NOTES FROM THE PRE-ANALYSIS PLAN 
*-------------------------------------------------------------------------------

/*

Table of Contents

***** Title from Table 2 in Pre-Analysis Plan ----- var name

***** 2.1 Housing material quality index ---------- material_index
***** 2.2 Toilet facility ------------------------- toilet
***** 2.3A Main Water source ---------------------- main_pipe
***** 2.3B Drinking water source ------------------ drink_pipe
***** 2.4 Ease of MAIN water access --------------- main_water_access
***** 2.5 Filter used in water drinking ----------- filter
***** 2.6 Safe drinking water --------------------- safe_water
***** 2.7 Electricity ----------------------------- electr
***** 2.8 Grid electricity ------------------------ grid
***** 2.9 Generator ------------------------------- generator
***** 2.10 Shared dwelling ------------------------ shared_hh
***** 2.11 Share of dwelling ---------------------- tot_families
***** 2.12 Rooms ---------------------------------- rooms
***** 2.13 Rooms occupied ------------------------- occupied_rooms
***** 2.14 Housing expenditure [Total] ------------ housing_exp_ppp
***** 2.15 Housing expenditure [Per Capita] ------- pc_housing_exp_ppp
***** 2.16 Rent payment --------------------------- rent_pay_ppp
***** 2.17 Household size ------------------------- hhsize
***** 2.20 Identification/Registration ------------ tot_id
***** 2.21 Homeownership --------------------------- own_house
***** 2.28 Household chores ------------------------ fr_chores; other_chores; 
													 tot_chores; childcare
***** 2.30 Amount of mortgage paid ---------------- mortgage_ppp
***** 1.1 Housing quality index ------------------- housing_index

*/

*-------------------------------------------------------------------------------
* CLEAN
*-------------------------------------------------------------------------------

* Get the USD to Jordanian Dollar PPP 2020 
import excel ///
"${dr}/Phone Survey/00_raw_private/Data_Extract_From_World_Development_IndicatorsJan2024.xlsx", ///
sheet("Data") cellrange(BM6:BM6) clear //BM grabs the private consumption PPP deflator for the year 2020 (the year of the survey). 
assert _n == 1
sum BM
gl usd2jod_ppp2020 = r(mean)

* Load the dataset + merge 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

merge 1:1 Key using "$dr/Phone Survey/00_raw_private/compliance.dta"
drop _merge

sort IID
des q501a-q509


*********************************************
***** 2.1 Housing material quality index*****
*********************************************

***Indicator for high-quality floor - tiles
	ta q503
	ta q503b
	ta q505a
	ta q505a
	ta q505a, nol
	ta q505a_other

	gen quality_floor=(q505a==3)
		replace quality_floor=. if q505a==.
		replace quality_floor=0 if q503b==1 /*caravan*/
		replace quality_floor=0 if q505a_other=="التراب" | q505a_other=="تراب" ///
		| q505a_other=="رمل" | q505a_other=="قماش خيمه" | q505a_other==	"بلاستيك" ///
		| q505a_other==	"بلاط وطين" | q505a_other== "مشع بلاستيك" 

		replace quality_floor=1 if q505a_other=="سراميك" | q505a_other=="سرميك" ///
		| q505a_other=="سيراميك" | q505a_other=="سيرتميك" | q505a_other=="سيرميك" /// 
		| q505a_other=="بلاط واسمنت"

	tab quality_floor
	sum quality_floor q505a q505a_other /*2,161 from q505a + 90 from other = 2251*/
	label var quality_floor "=1 if floors are made of tiles and 0 otherwise"
		
	
***Indicator for high-quality roof - Finished concrete or Tiles
	tab q505b
	tab q505b,nol

	tab q505b_other /* There are 10 obs. */
	//edit q505b_other if q505b_other!=" " 

	gen quality_roof=(q505b==4 | q505b==5)
		replace quality_roof=. if q505b==.
		replace quality_roof=0 if q503b==1 /*caravan*/
		replace quality_roof=0 if q505b_other!=" " 
			/*10 hh have wood, cement, brick or stone*/
			
		/*1841 obs. from q505b + 10 from q505b_other = 1851*/
	tab quality_roof
	label var quality_roof "=1 if roofs are made of concrete or tiles and 0 otherwise"	

egen material_index = rowtotal(quality_floor quality_roof), missing


	label var material_index "Housing material index (floor and roof)"
	ta material_index
	ta material_index quality_floor
	ta material_index quality_roof


******************************
***** 2.2 Toilet facility*****
******************************

tab q507
tab q507, nol
tab q507_other

//edit q507_other if q507_other!=" " 

gen toilet=(q507==3) 
	replace toilet=. if q507==.
	replace toilet=1 if q507_other=="عربي وفرنجي" | q507_other=="عربي فرنجي" /// 
		| q507_other=="حمامين واحد عربي والاخر افرنجي" | q507_other=="ارضي فرنجي" /// 
		| q507_other=="حمامين واحدوعربي ولاخر افرنجي" | q507_other=="عربي وفرني" /// 
		| q507_other=="حمام واحد فيه عربي وافرنجي" 	| q507_other=="ارضي وفرنجي" /// 
		| q507_other=="حمام واحد عربي افرنجي" | q507_other=="غربي فرنجي" /// 
		| q507_other=="عربي ولرنجي" | q507_other=="فرنجي وعربي" /// 
		| q507_other=="حمام واحد افرنجي وعربي" | q507_other=="واحد افرنجي وواحد عربي" /// 
		| q507_other=="حمامين عربي وافرنجي" /*they have two bathrooms*/
		
	replace toilet=0 if q507_other=="خيمه" | q507_other=="حفره في الارض" ///
		| q507_other=="حفره في الارض بجانب الكرفان مفصول عن الكرفان" /// 
		| q507_other=="حفره بالارض" | q507_other=="حفره" /*they have a hole in the ground*/
	
	
label var toilet "=1 if toilet, 0 if latrine, portable or no toilet"
tab toilet 

	
*********************************
***** 2.3A Main water source*****
*********************************

tab q508
tab q508, nol
tab q508_other
//edit q508_other if q508_other!=" " 

gen main_pipe=(q508a==1) 
	replace main_pipe=. if q508==.
	replace main_pipe=0 if q508_other!=" "  /* from neighbors and farm */
	replace main_pipe=. if q508_other=="لم يعرف مصدر المياه" /*didn't know water source*/

label var main_pipe "=1 if main water was piped, 0 otherwise"
tab main_pipe 

		
*************************************
***** 2.3B Drinking water source*****
*************************************

tab q508a
tab q508a, nol
tab q508a_other
//edit q508a_other if q508a_other!=" " 

gen drink_pipe=(q508a==1) 
	replace drink_pipe=. if q508a==.
	replace drink_pipe=0 if q508a_other!=" "  
		/* filter, neighbors, farm, or water tanks */

label var drink_pipe "=1 if drinking water was piped, 0 otherwise"
tab drink_pipe
sum drink_pipe q508a q508a_other
	/*2,259 from q508a + 53 from other = 2,312*/


*****************************************		
***** 2.4 Ease of MAIN water access*****
*****************************************		
		
tab q510
tab q510, nol

gen main_water_access=q510
	recode main_water_access (5=1) (4=2) (2=4) (1=5)

label var main_water_access "1-Very inaccessible main water, 5-Very accessible"
tab main_water_access q510
		
	
********************************************		
***** 2.5 Filter used in water drinking*****
********************************************			
		
tab q508b	
tab q508b,nol	

gen filter=(q508b==1) 
	replace filter=. if q508b==.

label var filter "=1 if hh treats drinking water, 0 otherwise"
tab filter q508b
		
		
**********************************		
***** 2.6 Safe drinking water*****
**********************************		

tab q509
tab q509, nol

gen safe_water=q509		
	recode safe_water (5=1) (4=2) (2=4) (1=5)

label var safe_water "1-Very infrequent access to safe drinking water, 5-Very frequent"
tab safe_water q509		
		
		
**************************	
***** 2.7 Electricity*****
**************************		
		
tab q506
tab q506, nol

gen electr=(q506==1)	
	replace electr=. if q506==.
		
label var electr "=1 if hh uses electricity and 0 otherwise"
tab electr			

		
*******************************	
***** 2.8 Grid electricity*****
*******************************		
		
tab q506a_1
tab q506a_1,nol
	
gen grid=(q506a_1==1)
	replace grid=. if q506a_1==.
	replace grid = 0 if q506==2

label var grid "=1 if hh gets electricity thru grid and 0 otherwise"
tab grid /* Note: 4 hh don't have electricity, which is why total # of obs. 
				  is 1899 and not 1903. */
	
	
************************	
***** 2.9 Generator*****
************************	
	
tab q506a_2
tab q506a_2,nol
	
gen generator=(q506a_2==1)
	replace generator=. if q506a_2==.
	replace generator = 0 if q506==2

label var generator "=1 if hh gets electricity thru generator and 0 otherwise"
tab generator	/* note: only 8 hh have generator */
	
		
*******************************	
***** 2.10 Shared dwelling*****
*******************************	
		
tab q502
tab q502,nol
tab q502b
tab q502b,nol

gen shared_hh = (q502b==1)
	replace shared_hh = . if q502==. 
	
label var shared_hh "=1 if hh shares dwelling and 0 otherwise"
tab shared_hh q502	


*********************************	
***** 2.11 Share of dwelling*****
*********************************

tab q502c
gen tot_families=1
	replace tot_families = 2 if q502c == 1
	replace tot_families = 3 if q502c == 2
	replace tot_families = . if q502 == .
	
label var tot_families "Total number of families occupying the same dwelling"
tab tot_families 


*********************	
***** 2.12 Rooms*****
*********************

tab q501
gen rooms= q501

label var rooms "Total number of separate rooms in dwelling excluding toilets and store rooms"
tab rooms q501


******************************	
***** 2.13 Rooms occupied*****
******************************

tab q502a
gen occupied_rooms = q502a
	replace occupied_rooms = rooms if q502 == 1 & q502!=.

label var occupied_rooms "Total number of rooms occupied by hh in dwelling"
tab occupied_rooms


*******************************************	
***** 2.14 Housing expenditure [Total]*****
*******************************************

des q511 q511a q511b q511d
su q511 q511a q511b q511d

*gen debt = cond(missing(q511a), 0, q511a) - cond(missing(q511b), 0, q511b)
gen debt =  q511a -  q511b
replace debt=. if q511a==. & q511b==.

//gen debt_ppp = ((debt/exc_jd)*cpi_jd)/ppp_jd
gen debt_ppp = debt/$usd2jod_ppp2020
//gen rent_agreed_ppp	= ((q511a/exc_jd)*cpi_jd)/ppp_jd
gen rent_agreed_ppp	= q511a/$usd2jod_ppp2020

*edit q511_other if q511_other!=" " 
*browse q511b q511d if q511_other!=" " ------> empty
	
egen housing_exp = rowtotal (q511b q511d), missing
	replace housing_exp = 0 if q511_other!=" " 
			/*These are hh that don't pay rent and don't have mortgage*/
	replace housing_exp = housing_exp + (100/12) if q511_other=="خيمه لارض ملك لناس مقابل 100دينار كل سنه"
			/* This person pays 100 dinars per year*/
	replace housing_exp = housing_exp + (140/12) if q511_other=="تدفع النرويجيه تدفع ايجار 140 للمالك"

label var housing_exp "Monthly rent paid in dinars plus mortgage payments"
sum housing_exp  /*1993 (from q511b) + 43 (q511d) + 62 (q511_other)= 2098. Seems good! */
ta housing_exp

//Converting to PPP $ 
//gen housing_exp_ppp = ((housing_exp/exc_jd)*cpi_jd)/ppp_jd
g housing_exp_ppp = housing_exp/$usd2jod_ppp2020
	label var housing_exp_ppp "Monthly rent paid plus mortgage payments in USD PPP"


************************************************	
***** 2.15 Housing expenditure [Per Capita]*****
************************************************	
	
gen pc_housing_exp=housing_exp/(q401+1) /*Added one to include FR in hhsize*/

label var pc_housing_exp "Per capita monthly rent agreed on in dinars + mortgage payments"
sum q401 housing_exp pc_housing_exp
	/*38 obs. were missing since hhsize is zero i.e. it excluded FR earlier*/
	
//Converting to PPP $ 
//gen pc_housing_exp_ppp = ((pc_housing_exp/exc_jd)*cpi_jd)/ppp_jd
g pc_housing_exp_ppp = pc_housing_exp/$usd2jod_ppp2020
	label var pc_housing_exp_ppp "Per capita monthly rent agreed on + mortgage payments in USD PPP"
	

****************************	
***** 2.16 Rent payment*****
****************************

des q511b
sum q511b

gen rent_pay = q511b 
	replace rent_pay = 0 if q511_other!=" " /*These are hh that don't pay */
	replace rent_pay = 100/12 if q511_other=="خيمه لارض ملك لناس مقابل 100دينار كل سنه"
	replace housing_exp = 140/12 if q511_other=="تدفع النرويجيه تدفع ايجار 140 للمالك"

label var rent_pay "Total amount in dinars the hh paid in rent in past 30 days"
sum q511b rent_pay 

//Converting to PPP $ 
//gen rent_pay_ppp = ((rent_pay/exc_jd)*cpi_jd)/ppp_jd
g rent_pay_ppp = rent_pay/$usd2jod_ppp2020
	label var rent_pay_ppp "Total amount hh paid for rent in past 30 days in USD PPP"
	
	
******************************	
***** 2.17 Household size*****
******************************

/* already defined as hhsize */
	replace hhsize = hhsize + 1 /*to include FR*/
	
label var hhsize "# people who eat at least 1 meal/day and sleep >=4 nights together"



*******************************************	
***** 2.20 Identification/Registration*****
*******************************************	
	
tab q205a /* MOI card */
	gen moi = (q205a == 1)	
	tab moi
label var moi "=1 if individual has MOI card and 0 otherwise"
		
		
tab q205b /* passport */
	gen passport = (q205b == 1)
	tab passport
label var passport "=1 if individual has passport and 0 otherwise"
	
	
tab q205c /* Residency permit */
	gen residency_per = (q205c == 1)
	tab residency_per
label var residency_per "=1 if individual has residency permit and 0 otherwise"


tab q205d /* Work permit */
	gen work_per = (q205d == 1) 
	tab work_per
label var work_per "=1 if individual has work permit and 0 otherwise"


tab q205e /* Family Book */
	gen family_book = (q205e == 1)
	tab family_book
label var family_book "=1 if individual has family book and 0 otherwise"


tab q205f /* Syrian ID */
	gen syrian_id = (q205f == 1)
	tab syrian_id
label var syrian_id "=1 if individual has Syrian ID and 0 otherwise"
	
	
tab q205g /* UNHCR File */
	gen unhcr = (q205g == 1)
	tab unhcr
label var unhcr "=1 if individual has UNHCR file and 0 otherwise"
	
	
gen tot_id = moi + passport + residency_per + work_per + family_book + syrian_id + unhcr
	sum tot_id
label var tot_id "total number of identification docs the FR has"


 
*****************************	
***** 2.21 Homeownership*****
*****************************

tab q511
tab q511,nol
tab q511_other

//edit q511_other if q511_other!=" " 
	/* There are 50 obs.*/

	gen own_house = (q511 == 1)
		replace own_house =. if q511==. 
		replace own_house=0 if q511_other!=" " /*tent, free,...etc.*/
		replace own_house=1 if q511_other=="ملك لزوجته" /*owned by his wife*/
			/*1853 from q511 + 50 from q511_other = 1903 obs.*/
	
label var own_house "=1 if hh owns dwelling and 0 otherwise"
tab own_house 
	
	
********************************
***** 2.28 Household chores*****
*********************************
	
sum q517 q518 q519a
des q517 q518 q519a

*FR chores
	gen chores_fr=q517 
		
	label var chores_fr "hours FR spent doing chores in past 7 days"
	
*FR childcare
	gen childcare_fr=q518 
		
	label var childcare_fr "hours FR spent doing childcare in last 7 days"
	
*FR chores + childcare
	egen chores_childcare_fr=rowtotal(chores_fr childcare_fr), missing
	
	label var chores_childcare_fr "hours FR spent doing chores+childcare in last 7 days"


*Other HH members chores +  childcare
	gen chores_childcare_hh=q519a 
		
	label var chores_childcare_hh "hours other hh members spent on chores+childcare in last 7 days"

su chores_fr childcare_fr chores_childcare_fr chores_childcare_hh


***************************************
***** 2.30 Amount of mortgage paid*****
***************************************

gen mortgage = q511d

sum mortgage
label var mortgage "Monthly amount in dinars hh pays for mortgage"

//Converting to PPP $
//gen mortgage_ppp = ((mortgage/exc_jd)*cpi_jd)/ppp_jd
g mortgage_ppp= mortgage/$usd2jod_ppp2020
	label var mortgage_ppp "Monthly amount in USD PPP hh pays for mortgage"

	
************************************
***** 1.1 Housing quality index*****
************************************

/*
	Indicator for high-quality floors -----	quality_floor 
	Indicator for high-quality roof -------	quality_roof
	Indicator for reliable electricity ----	grid
	Indicator for indoor plumbing ---------	main_pipe
	Indicator for water source ------------	drink_pipe
	# of people per room ------------------ ppl_room 
*/	

gen ppl_room = hhsize/occupied_rooms

label var ppl_room "Number of people per room occupied by hh members"
sum occupied_rooms hhsize ppl_room

********************************************************************************

**********************
***** FLEX index *****
**********************

local quality_index quality_floor quality_roof grid electr drink_pipe ppl_room
	foreach var in `quality_index' {
		sum `var' if As=="In-FControl" 
		local r(mean)
		local r(sd)
		gen `var'_nor = (`var'-`r(mean)')/`r(sd)'
		sum `var'_nor
	}
su quality_floor_nor quality_roof_nor grid_nor drink_pipe_nor ppl_room_nor if As=="In-FControl" 
egen housing_index_flex = rowtotal(quality_floor_nor quality_roof_nor grid_nor drink_pipe_nor)
replace housing_index_flex = housing_index_flex - ppl_room_nor
	
su housing_index_flex if As=="In-FControl" 
local r(mean)
local r(sd)
gen housing_index_flex_norm = (housing_index_flex -`r(mean)')/`r(sd)'
tabstat housing_index_flex_norm, by(As) stat(mean sd N)
su housing_index_flex_norm if As=="In-FControl" 
drop housing_index_flex
//drop quality_floor_nor quality_roof_nor grid_nor drink_pipe_nor ppl_room_nor
rename housing_index_flex_norm housing_index_flex
label var housing_index_flex "Housing index FLEX (floor, roof, grid, indoor plumbing, ppl/room)"

//second index for harmonized version
su quality_floor_nor quality_roof_nor electr_nor drink_pipe_nor ppl_room_nor if As=="In-FControl" 
egen housing_index_flex2 = rowtotal(quality_floor_nor quality_roof_nor electr_nor)
replace housing_index_flex2 = housing_index_flex2 - ppl_room_nor
su housing_index_flex2 if As=="In-FControl" 
local r(mean)
local r(sd)
gen housing_index_flex_norm2 = (housing_index_flex2 -`r(mean)')/`r(sd)'
tabstat housing_index_flex_norm2, by(As) stat(mean sd N)
su housing_index_flex_norm2 if As=="In-FControl" 
drop housing_index_flex2
drop quality_floor_nor quality_roof_nor grid_nor electr_nor drink_pipe_nor ppl_room_nor
rename housing_index_flex_norm2 housing_index_flex2
tabstat housing_index_flex housing_index_flex2, by(As) stat(mean sd)


********************
***** RE Index *****
********************

local quality_index quality_floor quality_roof grid electr drink_pipe ppl_room
	foreach var in `quality_index' {
		sum `var' if As=="In-REControl"
		local r(mean)
		local r(sd)
		gen `var'_nor = (`var'-`r(mean)')/`r(sd)'
		sum `var'_nor
	}
su quality_floor_nor quality_roof_nor grid_nor electr_nor drink_pipe_nor ppl_room_nor if As=="In-REControl" 
egen housing_index_re = rowtotal(quality_floor_nor quality_roof_nor grid_nor drink_pipe_nor), missing	
replace housing_index_re = housing_index_re - ppl_room_nor
su housing_index_re if As=="In-REControl" 
local r(mean)
local r(sd)
gen housing_index_re_norm = (housing_index_re -`r(mean)')/`r(sd)'
tabstat housing_index_re_norm, by(As) stat(mean sd N)
drop housing_index_re
//drop quality_floor_nor quality_roof_nor grid_nor drink_pipe_nor ppl_room_nor
rename housing_index_re_norm housing_index_re
label var housing_index_re "Housing index RE (floor, roof, grid, indoor plumbing, ppl/room)"
tabstat housing_index* quality_floor quality_roof grid drink_pipe ppl_room, by(As) stat (mean sd)
su housing_index_flex if As=="In-FControl"
su housing_index_re if As=="In-REControl" 

//second index for harmonized version
egen housing_index_re2 = rowtotal(quality_floor_nor quality_roof_nor electr_nor), missing	
replace housing_index_re2 = housing_index_re2 - ppl_room_nor
su housing_index_re2 if As=="In-REControl" 
local r(mean)
local r(sd)
gen housing_index_re_norm2 = (housing_index_re2 -`r(mean)')/`r(sd)'
tabstat housing_index_re_norm2, by(As) stat(mean sd N)
drop housing_index_re2
drop quality_floor_nor quality_roof_nor grid_nor electr_nor drink_pipe_nor ppl_room_nor
rename housing_index_re_norm2 housing_index_re2
tabstat housing_index_re housing_index_re2, by(As) stat(mean sd)


*********************
***** all Index *****
*********************

foreach var in quality_floor quality_roof grid electr drink_pipe ppl_room {
		su `var' if As=="In-REControl" | As=="In-FControl"
		g `var'_nor = (`var'-r(mean))/r(sd)
	}
egen housing_index_all = rowtotal(quality_floor_nor quality_roof_nor grid_nor drink_pipe_nor), missing	
replace housing_index_all = housing_index_all - ppl_room_nor
su housing_index_all if As=="In-REControl" | As=="In-FControl"
replace housing_index_all = (housing_index_all-r(mean))/r(sd)
tabstat housing_index_all housing_index_flex housing_index_re, by(As) stat(mean N)

//second index for harmonized version
egen housing_index_all2 = rowtotal(quality_floor_nor quality_roof_nor electr_nor), missing	
replace housing_index_all2 = housing_index_all2 - ppl_room_nor
su housing_index_all2 if As=="In-REControl" | As=="In-FControl"
replace housing_index_all2 = (housing_index_all2-r(mean))/r(sd)

destring total_duration, replace
	
***************************************
***** Gender and edu in HH roster *****
***************************************

forval i=1/17 {
gen edu_done_`i' = q407_`i'
label values edu_done_`i' q407_`i'
gen female_`i' = .
replace female_`i' = 1 if q404_`i'==2 & q404_`i'!=.
replace female_`i' = 0 if q404_`i'==1 & q404_`i'!=.
}

forval i=1/13{
gen school5days_`i' = q409_`i'
replace school5days_`i'=. if kid_`i'==0 & kid_`i'!=.

}

**********************************
***** Dwelling can be locked *****
**********************************

gen locked = . 
replace locked = 0 if q504 == 2
replace locked = 1 if q504 == 1
ta locked q504

gen temp_material=. 
replace temp_material = 0 if q503 == 2
replace temp_material = 1 if q503 == 1
ta temp_material q503

***************
***** HoH *****
***************

gen hoh=(q401a==1) if q401a!=.
ta hoh q401a

********************************************************************************

des housing_index* material_index toilet main_pipe drink_pipe ///
 main_water_access filter safe_water electr grid generator shared_hh tot_families ///
 rooms occupied_rooms housing_exp_ppp pc_housing_exp_ppp rent_pay_ppp hhsize tot_id ///
 own_house chores_fr childcare_fr chores_childcare_fr chores_childcare_hh mortgage_ppp
 
sum quality_floor quality_roof grid drink_pipe ppl_room

sum housing_index* material_index toilet main_pipe drink_pipe ///
 main_water_access filter safe_water electr grid generator shared_hh tot_families ///
 rooms occupied_rooms housing_exp_ppp pc_housing_exp_ppp rent_pay_ppp hhsize tot_id ///
 own_house chores_fr childcare_fr chores_childcare_fr chores_childcare_hh mortgage_ppp, sep(10)
 
des quality_floor quality_roof grid drink_pipe ppl_room

 
keep housing_index* material_index toilet main_pipe drink_pipe ///
 main_water_access filter safe_water electr grid generator shared_hh tot_families ///
 rooms occupied_rooms housing_exp_ppp pc_housing_exp_ppp rent_pay_ppp hhsize tot_id ///
 own_house chores_fr childcare_fr chores_childcare_fr chores_childcare_hh mortgage_ppp /// 
 quality_floor quality_roof ppl_room IID LocalityName locality Key_USE gender debt_ppp ///
 enumerator_name total_duration district subdistrict fr_age_in_months /// 
 memberage* adult_* kid_* female_* locked temp_material school5days_* edu_done_* /// 
 rent_agreed_ppp q202c q202a q202b SubmissionDate hoh q404_1
 	
save "$dr/Phone Survey/PS_T2_dwelling.dta", replace	
