*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY CONSUMPTION (PS_T3_consumption)
*-------------------------------------------------------------------------------

/*
NOTES: 

	- 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* NOTES FROM THE PRE-ANALYSIS PLAN 
*-------------------------------------------------------------------------------

* Get the USD to Jordanian Dollar PPP 2020 
import excel ///
"${dr}/Phone Survey/00_raw_private/Data_Extract_From_World_Development_IndicatorsJan2024.xlsx", ///
sheet("Data") cellrange(BM6:BM6) clear //BM grabs the private consumption PPP deflator for the year 2020 (the year of the survey). 
assert _n == 1
sum BM
gl usd2jod_ppp2020 = r(mean)

* Load the dataset + merge 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

merge 1:1 Key using "$da/PS_controls.dta", force
drop if _merge!=3
sort IID


*********************************************
***** 3.3 Food consumoption [assistance]*****
*********************************************

sum q6_1_05a

gen food_c_assist=q6_1_05a

sum food_c_assist
labe var food_c_assist "value in dinars of food consumed received as assistance"

//Converting to PPP $
//gen food_c_assist_ppp = ((food_c_assist/exc_jd)*cpi_jd)/ppp_jd
g food_c_assist_ppp = food_c_assist /$usd2jod_ppp2020
	label var food_c_assist_ppp "value in USD PPP of food consumed received as assistance"


*******************************
***** 3.6 Meal consumption*****
*******************************

sum q6_1_01

gen meals_yes = q6_1_01

sum meals_yes
label var meals_yes "# meals eaten yesterday"


****************************
***** 3.8 Food security*****
****************************

tab q6_1_01 
sum q6_1_05a

gen assist_person = food_c_assist_ppp/(hhsize+1) /* +1 to include FR since 
                                                    I am using the raw data*/
gen assist_person0 = food_c_assist_ppp/hhsize_b


********************************************************************************

sum food_c_assist_ppp meals_yes assist_person assist_person0 IID
des food_c_assist_ppp meals_yes assist_person assist_person0 IID  
	/*Team agreed not to include this measure since we control for baseline HH size*/
keep food_c_assist_ppp meals_yes assist_person IID


save "$dr/Phone Survey/PS_T3_consumption.dta", replace
