*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY MIGRATION (PS_T7_migration)
*-------------------------------------------------------------------------------

/*
NOTES: 

	- 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* NOTES FROM THE PRE-ANALYSIS PLAN 
*-------------------------------------------------------------------------------

/*

Table of Contents

***** Title from Table 7 in Pre-Analysis Plan ----- var name

***** 7.1 Respondent movement since 2011 ---------- moved_2011; moved_2019
***** 7.2 Number of times moved since 2019 -------- times_moved
***** 7.3 Respondent networks --------------------- travel_network
***** 7.5 IDP/Refugee camp resident --------------- live_camp
***** 7.12 Moving plans --------------------------- move_plan

*/

*-------------------------------------------------------------------------------
* CLEAN
*-------------------------------------------------------------------------------

* Load the dataset 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

sort IID


*********************************************
***** 7.1 Respondent movement since 2019*****
*********************************************

tab q709
tab q709, nol

gen moved_2019 = .
	replace moved_2019=0 if q709==2
	replace moved_2019=1 if q709==1
	
tab moved_2019 q709
label var moved_2019 "=1 if moved since October 2019"



***********************************************
***** 7.2 Number of times moved since 2019*****
***********************************************

tab q714_1
tab q714_2
tab q714_3
tab q714_4

tab q714_1,nol
tab q714_2,nol
tab q714_3,nol
tab q714_4,nol


gen times_moved=.
	replace times_moved = 0 			 	 if q709==2 /*did not move since Oct 2019*/
	replace times_moved = 1 				 if q709==1
			/*moved to another area right after the place lived in during Oct 2019*/
	replace times_moved = times_moved + 1  	 if q714_1==1 
	replace times_moved = times_moved + 1	 if q714_2==1 
	replace times_moved = times_moved + 1	 if q714_3==1 
	replace times_moved = times_moved + 1	 if q714_4==1
	
tab times_moved
tab times_moved mov

ta q711a_5 /*6 people moved 5 times - bingo! */
label var times_moved "# times moved since October 2019"



**********************************
***** 7.3 Respondent networks*****
**********************************

tab q715

gen travel_network = q715

tab travel_network q715 
label var travel_network "1 means knew 0 persons; 5 means more than 20"

su travel_network if regex(Assign,"FControl")
g travel_network_flex = (travel_network-r(mean))/r(sd) if regex(Assign,"F")
su travel_network if regex(Assign,"REControl")
g travel_network_re = (travel_network-r(mean))/r(sd) if regex(Assign,"RE")
tabstat travel_network_flex travel_network_re, by(Assign)


****************************************
***** 7.5 IDP/Refugee camp resident*****
****************************************

tab q709 /*219 moved since in 2019*/
tab q710a /*From these 219, no one was living in camp*/


tab q711a_1 if q714_1==0 /*did not move again after coming there - 37 in camp*/
tab q711a_1 if q714_1==0,nol

tab q711a_2 if q714_2==0 /*all are outside of camp*/

tab q711a_3 if q714_3==0 /*all are outside of camp*/

tab q711a_4 if q714_4==0 /*all are outside of camp*/

tab q711a_5 /*1 in camp*/
tab q711a_5,nol 


gen live_camp = 0
	replace live_camp = 1 if q711a_1==7 & q714_1==0
	replace live_camp = 1 if q711a_5==7 
	replace live_camp = . if q709==.

tab live_camp
label var live_camp "=1 if FR lives in a camp and 0 otherwise"	


	
****************************
***** 7.12 Moving plans*****
****************************

tab q717
tab q717,nol

gen move_plan=q717

sum move_plan q717
label var move_plan "1-moving on a specific date; 4 no intentions"



******************************************************************************

sum moved_2019 times_moved travel_network live_camp move_plan IID, sep(10)
des moved_2019 times_moved travel_network live_camp move_plan IID
keep moved_2019 times_moved travel_network* live_camp move_plan IID

save "$dr/Phone Survey/PS_T7_migration.dta", replace
