*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY PHYSICLA HEALTH (PS_T8_Physical_health)
*-------------------------------------------------------------------------------

/*
NOTES: 

	- 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* NOTES FROM THE PRE-ANALYSIS PLAN 
*-------------------------------------------------------------------------------

/*
Table of Contents

***** Title from Table 8 in Pre-Analysis Plan ----- var name
***** 8.2 Subjective health ----------------------- subj_health
***** 8.5 Disability ------------------------------ Disability1; Disability2;
													Disability3; Disability4
***** 8.9 Food security --------------------------- hungry_fr
***** 8.10 Food security adults ------------------- hungry_days_adult

*/


clear all
set more off
set maxvar 10000


*-------------------------------------------------------------------------------
* CLEAN
*-------------------------------------------------------------------------------

* Load the dataset + merge 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

sort IID


********************************
***** 8.2 Subjective health*****
********************************

tab q8_1_09
tab q8_1_09,nol

gen subj_health = q8_1_09
	recode subj_health (4=1) (3=2) (2=3) (1=4)
	
tab subj_health q8_1_09
label var subj_health "1-very poor subjective health, 4-good"



*************************
***** 8.5 Disability*****
*************************
des q8_1_14 q8_1_15 q8_1_16 q8_1_17 q8_1_18 q8_1_19
	tab q8_1_14
	tab q8_1_15
	tab q8_1_16
	tab q8_1_17
	tab q8_1_18
	tab q8_1_19
	
	tab q8_1_14,nol
	tab q8_1_15,nol
	tab q8_1_16,nol
	tab q8_1_17,nol
	tab q8_1_18,nol
	tab q8_1_19,nol

gen Vision = q8_1_14 
gen Hearing = q8_1_15  
gen Mobility = q8_1_16  
gen Cognition = q8_1_17  
gen Self_Care = q8_1_18  
gen Communication = q8_1_19 

	sum Vision Hearing Mobility Cognition Self_Care Communication


gen SumPoints=0 

	foreach v of var Vision Hearing Mobility Cognition Self_Care Communication{ 
		replace SumPoints=SumPoints + inlist(`v',2,3,4) 
} 

replace SumPoints=. if missing(Vision) & missing(Hearing) & /// 
missing(Mobility) & missing(Cognition) & missing(Self_Care) & missing(Communication) 

gen SUM_234=. if SumPoints==. 
replace SUM_234=1 if SumPoints==1 
replace SUM_234=2 if SumPoints==2 
replace SUM_234=3 if SumPoints==3 
replace SUM_234=4 if SumPoints==4 
replace SUM_234=5 if SumPoints==5 
replace SUM_234=6 if SumPoints==6 
replace SUM_234=0 if SumPoints==0 

tab SUM_234



gen SumPoints2=0 

	foreach v of var Vision Hearing Mobility Cognition Self_Care Communication{ 
		replace SumPoints2=SumPoints2 + inlist(`v',3,4) 
} 

replace SumPoints2=. if missing(Vision) & missing(Hearing) & /// 
missing(Mobility) & missing(Cognition) & missing(Self_Care) & missing(Communication)
 
gen SUM_34=. if SumPoints2==. 
replace SUM_34=1 if SumPoints2==1 
replace SUM_34=2 if SumPoints2==2 
replace SUM_34=3 if SumPoints2==3 
replace SUM_34=4 if SumPoints2==4 
replace SUM_34=5 if SumPoints2==5 
replace SUM_34=6 if SumPoints2==6 
replace SUM_34=0 if SumPoints2==0 
tabulate SUM_34

gen Disability1=2
	replace Disability1=1 if SUM_234 >=1
	
	replace Disability1=. if missing(Vision) & missing(Hearing) & missing(Mobility) & ///
	missing(Cognition) & missing(Self_Care) & missing(Communication)
	
tab Disability1	
label var Disability1 "=1 if at least one question is SOME DIFFICULTY/A LOT OF DIFFICULTY/CANNOT DO AT ALL"	
	
gen Disability2=2 
	replace Disability2=1 if (SUM_234 >=2 | SUM_34==1) 
	
	replace Disability2=. if missing(Vision) & missing(Hearing) & missing(Mobility) & /// 
	missing(Cognition) & missing(Self_Care) & missing(Communication)
	
tab Disability2
label var Disability2 "=1 if at least 2 questions are SOME DIFFICULTY or 1 question is A LOT OF DIFFICULTY/CANNOT DO AT ALL"	
	
	
gen Disability3=2 
	replace Disability3=1 if (inlist(Vision,3,4) | inlist(Hearing,3,4) | inlist(Mobility,3,4) | /// 
	inlist(Communication,3,4) | inlist(Self_Care,3,4) | inlist(Cognition,3,4))
	
	replace Disability3=. if missing(Vision) & missing(Hearing) & missing(Mobility) & /// 
	missing(Cognition) & missing(Self_Care) & missing(Communication) 
	
tab Disability3
label var Disability3 "=1 if any 1 question is A LOT OF DIFFICULTY/CANNOT DO AT ALL."	

	
	
gen Disability4=2 
	replace Disability4=1 if ((Vision==4) | (Hearing==4) | (Mobility==4) | (Communication==4) | /// 
	(Self_Care==4) | (Cognition==4)) 

	replace Disability4=. if missing(Vision) & missing(Hearing) & missing(Mobility) & /// 
	missing(Cognition) & missing(Self_Care) & missing(Communication) 
	
tab Disability4
label var Disability4 "=1 if any one domain is coded CANNOT DO AT ALL"	

//Recode from 1/2 to 1/0

forval i=1/4 {
	ta Disability`i'
	replace Disability`i'=0 if Disability`i'==2
	ta Disability`i'
}
//

su Disability*


****************************
***** 8.9 Food security*****
****************************

tab q6_1_02

gen hungry_fr = .
	replace hungry_fr = 0 if q6_1_02==0 & q6_1_02!=.
	replace hungry_fr = 1 if q6_1_02!=0 & q6_1_02!=.
	
tab hungry_fr
label var hungry_fr "=1 if FR slept hungry for at least 1 day last week"



************************************
***** 8.10 Food security adults*****
************************************

tab q6_1_02 
tab q6_1_02a

//FR
gen hungry_days_fr = q6_1_02

tab hungry_days_fr
label var hungry_days_fr "# days in the last 7 days FR went to sleep hungry"

//Other adults
gen hungry_days_other = q6_1_02a
tab hungry_days_other

label var hungry_days_other "# days in the last 7 days other adults went to sleep hungry"
sum hungry_days_fr hungry_days_other

gen hungry_bi_other = .
	replace hungry_bi_other = 0 if hungry_days_other==0
	replace hungry_bi_other = 1 if hungry_days_other!=0	
label var hungry_bi_other "=1 if other adults slept hungry for at least 1 day last week"	

********************************************************************************

sum subj_health Disability1 Disability2 Disability3 Disability4 hungry_fr hungry_days_* hungry_bi_other IID

des subj_health Disability1 Disability2 Disability3 Disability4 hungry_fr hungry_days_* hungry_bi_other IID

keep subj_health Disability1 Disability2 Disability3 Disability4 hungry_fr /// 
     hungry_days_* hungry_bi_other IID Vision Hearing Mobility Cognition Self_Care Communication 


save "$dr/Phone Survey/PS_T8_physical_health.dta", replace




