*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY DWELLING (PS_T2_dwelling)
*-------------------------------------------------------------------------------

/*
NOTES: 

	- 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* CLEAN
*-------------------------------------------------------------------------------

* Load the dataset + merge 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

sort IID

merge 1:1 Key using "$dr/Phone Survey/00_raw_private/compliance.dta", nogen


**********
** CESD **
**********
// sum of (non-refused), correctly indexed so that negative outcomes correspond to higher values

foreach var of varlist q8_2_01* {
replace `var'=. if `var'==-88 //replace refused with missing
tab `var', gen(`var'_)
label var `var'_1 "Not at all or less than 1 day"
label var `var'_2 "1-2 days"
label var `var'_3 "3-4 days"
label var `var'_4 "5-7 days"
}


global cesd "q8_2_01abothered q8_2_01bconcentration q8_2_01cdepressed q8_2_01dnoenergy q8_2_01ehopeful q8_2_01fafraid q8_2_01gpoorsleep q8_2_01hhappy q8_2_01ilonely q8_2_01jmotivation"

foreach outcome of varlist $cesd {
	tab `outcome', m
	* score "rarely or none of the time" as 0, not 1
	* "some or a little of the time" as 1 not 2
	* "occassionally or a moderate amount of time" as 2 not 3
	* "all of the time" as 3 not 4
	replace `outcome' = `outcome' - 1
}

label define cesd 0 "rarely or none of the time" 1 "some or a little of the time" 2 "occassionally or a moderate amount of time" 3 "all of the time"
label values $cesd cesd

*Recode positive outcomes values (hopeful, happy)
gen q8_2_01ehopeful_reverse=q8_2_01ehopeful
gen q8_2_01hhappy_reverse=q8_2_01hhappy
recode q8_2_01ehopeful_reverse q8_2_01hhappy_reverse (3=0) (0=3) (1=2) (2=1)
label values q8_2_01ehopeful_reverse cesd
label values q8_2_01hhappy_reverse cesd

**RUN FROM HERE


//gen CESD

global cesdupdate "q8_2_01abothered q8_2_01bconcentration q8_2_01cdepressed q8_2_01dnoenergy q8_2_01ehopeful_reverse q8_2_01fafraid q8_2_01gpoorsleep q8_2_01hhappy_reverse q8_2_01ilonely q8_2_01jmotivation"

egen cesd_score=rowmean($cesdupdate) 

/*
egen cesd_missings = rowmiss($cesdupdate)
replace cesd_score = . if cesd_missings>2
drop cesd_missings
*/

* scale up based on the 8, 9, or 10 responses available
replace cesd_score = cesd_score*10
label var cesd_score "CES-D Score"


/*Indicator for Depression (using CES-D Scale)
Ref: https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4059037/
Ref: https://www.sciencedirect.com/science/article/abs/pii/S0749379718306226 */

gen depressed = .
	replace depressed = 0 if cesd_score < 10 & cesd_score!=.
	replace depressed = 1 if cesd_score >= 10 & cesd_score!=.
	label var depressed "Indicator for Depressed"

	
*****Table 9: 19.23
/*
"Scores range from 0 (lowest) to 60 (highest), and patients are categorized into
 one of the following four groups: 
 a) not depressed (0–9 points), 
 b) mildly depressed (10–15 points), 
 c) moderately depressed (16–24 points), 
 or d) severely depressed (more than 25 points)."
 
 Source: https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5585982/
 
 This info applies to the 20 CES-D. Since ours is 10, I divide cut-off pts by 2.
 */
 
gen cesd_levels=.
	replace cesd_levels = 1 if cesd_score<=4.5 & cesd_score!=.
	replace cesd_levels = 2 if cesd_score>4.5 & cesd_score<=7.5 & cesd_score!=.
	replace cesd_levels = 3 if cesd_score>7.5 & cesd_score<=12 & cesd_score!=.
	replace cesd_levels = 4 if cesd_score>12 & cesd_score!=.
	 
label define cesd_1_4 1 "not depressed" 2 "mildly depressed" 3 "moderately depressed" /// 
4 "severely depressed"
label values cesd_levels cesd_1_4

tab cesd_levels
label var cesd_levels "Four categorical levels of depression based on CES-D"



***normalized positive score of CESD as Ted asked

gl cesd_norm q8_2_01abothered q8_2_01bconcentration q8_2_01cdepressed q8_2_01dnoenergy /// 
 q8_2_01fafraid q8_2_01gpoorsleep  q8_2_01ilonely q8_2_01jmotivation

 foreach var in $cesd_norm {
gen `var'_reverse=`var'
recode `var'_reverse (3=0) (0=3) (1=2) (2=1)
ta `var'_reverse `var'
ta `var'_reverse
}
ta q8_2_01hhappy 
ta q8_2_01ehopeful
 
*FLEX index
gl norm_cesd q8_2_01ehopeful q8_2_01hhappy q8_2_01abothered_reverse /// 
      q8_2_01bconcentration_reverse q8_2_01cdepressed_reverse q8_2_01dnoenergy_reverse /// 
	  q8_2_01fafraid_reverse q8_2_01gpoorsleep_reverse q8_2_01ilonely_reverse /// 
	  q8_2_01jmotivation_reverse
	  
	foreach x in $norm_cesd {
		sum `x' if Ass=="In-FControl" 
		local r(mean)
        local r(sd)
		gen `x'2 = (`x'-`r(mean)')/`r(sd)'
		sum `x'2
	}

egen cesd_norm_flex =rowtotal(q8_2_01ehopeful2 q8_2_01hhappy2 /// 
                              q8_2_01abothered_reverse2 q8_2_01bconcentration_reverse2 /// 
							  q8_2_01cdepressed_reverse2 q8_2_01dnoenergy_reverse2 /// 
	                          q8_2_01fafraid_reverse2 q8_2_01gpoorsleep_reverse2 /// 
							  q8_2_01ilonely_reverse2 q8_2_01jmotivation_reverse2), missing

su cesd_norm_flex if Ass=="In-FControl" 
local r(mean)
local r(sd)

gen cesd_norm2 = (cesd_norm_flex - `r(mean)')/`r(sd)'
drop cesd_norm_flex
rename cesd_norm2 cesd_norm_flex
drop q8_2_01*2
su cesd_norm_flex if Ass=="In-FControl" 
label var cesd_norm_flex "FLEX normalized positive CESD score"
	
	
**RE index
	foreach x in $norm_cesd {
		sum `x' if Ass=="In-REControl"
		local r(mean)
        local r(sd)
		gen `x'2 = (`x'-`r(mean)')/`r(sd)'
		sum `x'2
	}

egen cesd_norm_re =rowtotal(q8_2_01ehopeful2 q8_2_01hhappy2 /// 
                            q8_2_01abothered_reverse2 q8_2_01bconcentration_reverse2 /// 
						    q8_2_01cdepressed_reverse2 q8_2_01dnoenergy_reverse2 /// 
	                        q8_2_01fafraid_reverse2 q8_2_01gpoorsleep_reverse2 /// 
						    q8_2_01ilonely_reverse2 q8_2_01jmotivation_reverse2), missing

su cesd_norm_re if Ass=="In-REControl"
local r(mean)
local r(sd)

gen cesd_norm3 = (cesd_norm_re - `r(mean)')/`r(sd)'
drop cesd_norm_re
rename cesd_norm3 cesd_norm_re
drop q8_2_01*2
su cesd_norm_re if Ass=="In-REControl" 
label var cesd_norm_re "RE normalized positive CESD score"


**all index
	foreach x in $norm_cesd {
		sum `x' if Ass=="In-REControl" | Ass=="In-FControl" 
		local r(mean)
        local r(sd)
		gen `x'2 = (`x'-`r(mean)')/`r(sd)'
		sum `x'2
	}

egen cesd_norm_all =rowtotal(q8_2_01ehopeful2 q8_2_01hhappy2 /// 
                            q8_2_01abothered_reverse2 q8_2_01bconcentration_reverse2 /// 
						    q8_2_01cdepressed_reverse2 q8_2_01dnoenergy_reverse2 /// 
	                        q8_2_01fafraid_reverse2 q8_2_01gpoorsleep_reverse2 /// 
						    q8_2_01ilonely_reverse2 q8_2_01jmotivation_reverse2), missing

su cesd_norm_all if Ass=="In-REControl" | Ass=="In-FControl" 
local r(mean)
local r(sd)

gen cesd_norm3 = (cesd_norm_all - `r(mean)')/`r(sd)'
drop cesd_norm_all
rename cesd_norm3 cesd_norm_all

su cesd_norm_all if Ass=="In-REControl" | Ass=="In-FControl" 
label var cesd_norm_all "All normalized positive CESD score"



***normalized negative (regular) score of CESD and let's then multiply by -1
	foreach x in $cesdupdate {
		sum `x' if Ass=="In-FControl"
		local r(mean)
        local r(sd)
		gen `x'3 = (`x'-`r(mean)')/`r(sd)'
		sum `x'3
	}

egen cesd_norm_flex_neg =rowtotal(q8_2_01abothered3 q8_2_01bconcentration3 /// 
                                  q8_2_01cdepressed3 q8_2_01dnoenergy3 /// 
								  q8_2_01ehopeful_reverse3 q8_2_01fafraid3 /// 
								  q8_2_01gpoorsleep3 q8_2_01hhappy_reverse3 /// 
								  q8_2_01ilonely3 q8_2_01jmotivation3), missing

su cesd_norm_flex_neg if Ass=="In-FControl"
local r(mean)
local r(sd)        

gen cesd_not_norm = (cesd_norm_flex_neg -`r(mean)')/`r(sd)'
drop cesd_norm_flex_neg
rename cesd_not_norm cesd_norm_flex_neg

su cesd_norm_flex_neg if Ass=="In-FControl" 
label var cesd_norm_flex_neg "FLEX normalized nagtive CESD score"

gen test=-1*cesd_norm_flex_neg
su test cesd_norm_flex

/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
        test |      2,309     .021189    .9809901  -3.075338   1.747525
cesd_norm_~x |      2,309     .021189    .9809901  -3.075338   1.747525

*/

//Conclusion: reverse-coding and then normalizing is the same thing as normalizing
//and then multiplying by -1.

drop cesd_norm_flex_neg



****************************
** Perceived Stress Scale **
****************************

/* 1 never 2 almost never 3 sometimes 4 fairly often 5 very often 66 refusal 77 no response 99 DK */
tab q8_34_01nocontrol, m
tab q8_34_02overcome, m
tab q8_34_03goingwell, m
tab q8_34_04toomanyprobs, m

* reverse code 20.4.2 and 20.4.3 such that higher values correspond to more perceived stress
gen q8_34_02overcome_reverse = .
replace q8_34_02overcome_reverse = 1 if q8_34_02overcome==5
replace q8_34_02overcome_reverse = 2 if q8_34_02overcome==4
replace q8_34_02overcome_reverse = 3 if q8_34_02overcome==3
replace q8_34_02overcome_reverse = 4 if q8_34_02overcome==2
replace q8_34_02overcome_reverse = 5 if q8_34_02overcome==1
label var q8_34_02overcome_reverse "How often have you felt certain in your ability to overcome your own personal problems? (reverse-coded)"

gen q8_34_03goingwell_reverse = .
replace q8_34_03goingwell_reverse = 1 if q8_34_03goingwell==5
replace q8_34_03goingwell_reverse = 2 if q8_34_03goingwell==4
replace q8_34_03goingwell_reverse = 3 if q8_34_03goingwell==3
replace q8_34_03goingwell_reverse = 4 if q8_34_03goingwell==2
replace q8_34_03goingwell_reverse = 5 if q8_34_03goingwell==1
label var q8_34_03goingwell_reverse "How often have you felt that things were going your way? (reverse-coded)"

***FLEX index
local stress_vars q8_34_01nocontrol q8_34_04toomanyprobs q8_34_02overcome_reverse q8_34_03goingwell_reverse
	foreach var in `stress_vars' {
		sum `var' if Ass=="In-FControl"
		local r(mean)
		local r(sd)
		gen `var'2 = (`var'-`r(mean)')/`r(sd)'
		sum `var'2
	}

egen perceived_stress_scale_flex = rowtotal (q8_34_01nocontrol2 q8_34_04toomanyprobs2 /// 
	q8_34_02overcome_reverse2 q8_34_03goingwell_reverse2), missing 
 
su perceived_stress_scale_flex if Ass=="In-FControl" 
local r(mean)
local r(sd)

gen perceived_stress_scale_flex_norm = (perceived_stress_scale_flex -`r(mean)')/`r(sd)'

sum perceived_stress_scale_flex_norm if Ass=="In-FControl" 
drop perceived_stress_scale_flex 
rename perceived_stress_scale_flex_norm perceived_stress_scale_flex
 
drop q8_34_01nocontrol2 q8_34_04toomanyprobs2 q8_34_02overcome_reverse2 q8_34_03goingwell_reverse2
label var perceived_stress_scale "Perceived Stress Scale FLEX (done using z-scores)"


***RE index	
local stress_vars q8_34_01nocontrol q8_34_04toomanyprobs q8_34_02overcome_reverse q8_34_03goingwell_reverse
	foreach var in `stress_vars' {
		sum `var' if Ass=="In-REControl" 
		local r(mean)
		local r(sd)
		gen `var'2 = (`var'-`r(mean)')/`r(sd)'
		sum `var'2
	}

egen perceived_stress_scale_re = rowtotal (q8_34_01nocontrol2 q8_34_04toomanyprobs2 /// 
	q8_34_02overcome_reverse2 q8_34_03goingwell_reverse2), missing 
 
su perceived_stress_scale_re if Ass=="In-REControl" 
local r(mean)
local r(sd)

gen perceived_stress_scale_re_norm = (perceived_stress_scale_re -`r(mean)')/`r(sd)'

sum perceived_stress_scale_re_norm if Ass=="In-REControl" 
drop perceived_stress_scale_re 
rename perceived_stress_scale_re_norm perceived_stress_scale_re
drop q8_34_01nocontrol2 q8_34_04toomanyprobs2 q8_34_02overcome_reverse2 q8_34_03goingwell_reverse2
label var perceived_stress_scale_re "Perceived Stress Scale RE (done using z-scores)"
	
	
***all index	
local stress_vars q8_34_01nocontrol q8_34_04toomanyprobs q8_34_02overcome_reverse q8_34_03goingwell_reverse
	foreach var in `stress_vars' {
		sum `var' if Ass=="In-REControl" | Ass=="In-FControl" 
		local r(mean)
		local r(sd)
		gen `var'2 = (`var'-`r(mean)')/`r(sd)'
		sum `var'2
	}

egen perceived_stress_scale_all = rowtotal (q8_34_01nocontrol2 q8_34_04toomanyprobs2 /// 
	q8_34_02overcome_reverse2 q8_34_03goingwell_reverse2), missing 
 
su perceived_stress_scale_all if Ass=="In-REControl" | Ass=="In-FControl" 
local r(mean)
local r(sd)

gen perceived_stress_scale_all_norm = (perceived_stress_scale_all -`r(mean)')/`r(sd)'

sum perceived_stress_scale_all_norm if Ass=="In-REControl" | Ass=="In-FControl" 
drop perceived_stress_scale_all 
rename perceived_stress_scale_all_norm perceived_stress_scale_all
drop q8_34_01nocontrol2 q8_34_04toomanyprobs2 q8_34_02overcome_reverse2 q8_34_03goingwell_reverse2
label var perceived_stress_scale_all "Perceived Stress Scale All (done using z-scores)"

*****************

su perceived_stress_scale_flex if Ass=="In-FControl" 
su perceived_stress_scale_re if Ass=="In-REControl" 
su perceived_stress_scale_all if Ass=="In-REControl" | Ass=="In-FControl" 

gen perceived_stress_flex = -1*perceived_stress_scale_flex
	label var perceived_stress_flex "Normalized (positive) FLEX perceived stress scale"

gen perceived_stress_re = -1*perceived_stress_scale_re
	label var perceived_stress_re "Normalized (positive) RE perceived stress scale"
	
gen perceived_stress_all = -1*perceived_stress_scale_all
	label var perceived_stress_all "Normalized (positive) All perceived stress scale"

	
********************************************************************************
sum perceived_stress_* depressed cesd_score cesd_levels q8_2_01*_reverse ///
q8_2_01abothered q8_2_01bconcentration q8_2_01cdepressed q8_2_01dnoenergy /// 
q8_2_01ehopeful q8_2_01fafraid q8_2_01gpoorsleep q8_2_01hhappy /// 
q8_2_01ilonely q8_2_01jmotivation q8_34_0* IID cesd_norm*

des perceived_stress_* depressed cesd_score cesd_levels q8_2_01*_reverse ///
q8_2_01abothered q8_2_01bconcentration q8_2_01cdepressed q8_2_01dnoenergy /// 
q8_2_01ehopeful q8_2_01fafraid q8_2_01gpoorsleep q8_2_01hhappy /// 
q8_2_01ilonely q8_2_01jmotivation q8_34_0* IID cesd_norm*

keep perceived_stress_* depressed cesd_score cesd_levels q8_2_01*_reverse ///
q8_2_01abothered q8_2_01bconcentration q8_2_01cdepressed q8_2_01dnoenergy /// 
q8_2_01ehopeful q8_2_01fafraid q8_2_01gpoorsleep q8_2_01hhappy /// 
q8_2_01ilonely q8_2_01jmotivation q8_34_0* IID cesd_norm*
 

save "$dr/Phone Survey/PS_T9_mental_health.dta", replace
