import pandas as pd
import matplotlib.pyplot as plt
import csv
import numpy as np
from dotenv import load_dotenv

import os

# Load environment variables (see README.md for instructions on setting up the .env file)
load_dotenv()

# Get Dropbox path
DROPBOX_PATH = os.getenv('DROPBOX_PATH')


# Loading in an preparing data for Panel A
"""Takes in absolute file path to .csv file and returns delimiter to use. """
def test_delimiter(file_path):
    with open(file_path, 'r') as file:
        first_line = file.readline()
        dialect = csv.Sniffer().sniff(first_line)
        delimiter = dialect.delimiter
    print(f"The delimiter is: '{delimiter}'")

path_to_A = os.path.join(DROPBOX_PATH,'S-RLS Data/RCT/Predictions/Round 1/Effect of Shelter Program on Refugee Wellbeing_responses_final.csv')

sspp_df_A = pd.read_csv(path_to_A, delimiter=',')

# In this panel, we are interested in the predicted direct impacts - in panel B we focus on the social cohesion outcomes. The variable names can be found by looking through the dataframe in Excel / Numbers.

# Note: All predictions are measured in SDs. The questions below are in a separate part of the dataframe, so some manipulation is needed to get it up nicely.


first_part = sspp_df_A.loc[2:, ['Q9_1_1','Q9_2_1', 'SocRes_Label']]
first_question, last_question = 'Q10_1_1', 'Q15_1_1'
sspp_df_A = sspp_df_A.loc[2:, first_question:last_question] # access each question column and skip 2 first rows as they contained the descriptions.
sspp_df_A = first_part.join(sspp_df_A)

# Choose the column you want to move to the right (e.g., column 'B')
column_to_move = sspp_df_A['SocRes_Label']

# Drop the original column from the DataFrame
sspp_df_A = sspp_df_A.drop('SocRes_Label', axis=1)

# Insert the column to the right (at the end)
sspp_df_A['SocRes_Label'] = column_to_move

# Now add Researcher and Non-Researcher column (all empty ones are assumed Non-Researchers)
# Use numpy.where to create a new column 'Label'
sspp_df_A['Label'] = np.where(sspp_df_A['SocRes_Label'] == 'Yes', 'Researcher', 'Non-Researcher')

# Replace empty cells with 'Non-Researcher'
sspp_df_A['Label'].fillna('Non-Researcher', inplace=True)

sspp_df_A = sspp_df_A.drop('SocRes_Label', axis=1)
sspp_df_A = sspp_df_A.dropna()

sspp_df_A.to_csv(os.path.join('data','analysis','clean_panel_A_final.csv'))


# Loading and preparing data for Panel B
path_to_B = os.path.join(DROPBOX_PATH,'S-RLS Data/RCT/Predictions/Round 2/Effect of Shelter Program on Refugees and Their Neighbors_responses.csv')

test_delimiter(path_to_B)
sspp_B_df = pd.read_csv(path_to_B, delimiter=',')

# Select 3 relevant outcomes with respect to social cohesion. Can be determined by examining the file in Excel / Numbers.
occupation = sspp_B_df['1b_Label'][2:]

first_question, last_question = 'Q19_1', 'Q21_1'
sspp_B_df = sspp_B_df.loc[2:, first_question:last_question]
merged_df = sspp_B_df.assign(C=occupation)
sspp_B_df = merged_df

sspp_B_df.to_csv(os.path.join('data','analysis','clean_panel_B_final.csv'))
