*-------------------------------------------------------------------------------
* CLEANING: PHONE SURVEY COVID (PS_T19_20_21_COVID)
*-------------------------------------------------------------------------------

/*
NOTES: 

	-  Need a bit of organizing/cleaning. 

*/

clear all
set more off
program drop _all
set maxvar 10000

adopath ++ "$ado"


*-------------------------------------------------------------------------------
* CLEAN
*-------------------------------------------------------------------------------

* Get the USD to Jordanian Dollar PPP 2020 
import excel ///
"${dr}/Phone Survey/00_raw_private/Data_Extract_From_World_Development_IndicatorsJan2024.xlsx", ///
sheet("Data") cellrange(BM6:BM6) clear //BM grabs the private consumption PPP deflator for the year 2020 (the year of the survey). 
assert _n == 1
sum BM
gl usd2jod_ppp2020 = r(mean)

* Load the dataset + merge 
use "$dr/Phone Survey/00_raw_private/PS_clean_final.dta", clear

merge 1:1 Key using "$dr/Phone Survey/00_raw_private/compliance.dta"
drop _merge

sort IID


//COVID-19 Practices
//Stayed at Home: q908a
gen stayedathome=. 
replace stayedathome=3 if q908a==7
replace stayedathome=2 if q908a==5 | q908a==6 | q908a==4
replace stayedathome=1 if q908a==2 | q908a==3 | q908a==1
replace stayedathome=0 if q908a==0
replace stayedathome=. if q908a==.
label var stayedathome "Frquency FR stayed at home in the past 7 days"

label define cvpractices 0 "Never" 1 "Occasionally" 2 "Often" 3 "All the Time"
label values stayedathome cvpractices

//Calculate # of days FR left the house
gen daysoutside=7-q908a
gen socialdistanced=q908c/daysoutside

//Social distanced: q908c
gen socialdistanced_fr=.
replace socialdistanced_fr=3 if socialdistanced==1
replace socialdistanced_fr=2 if socialdistanced<1 & socialdistanced>=.5
replace socialdistanced_fr=1 if socialdistanced<.5 & socialdistanced>0
replace socialdistanced_fr=0 if q908c==0
replace socialdistanced_fr=. if q908c==.
label var socialdistanced_fr "Frequency FR socially distanced (while outside) in the past 7 days"
label values socialdistanced_fr cvpractices

// Attended social gathering (Y/N): q908b
gen socialgathering=1 if q908b>0
replace socialgathering=0 if q908b==0
replace socialgathering=. if q908b==.
label var socialgathering "Attended social gathering in the past 7 days (=1)"

// Attended religious activities (Y/N): q908d
gen attendedchurch=1 if q908d>0
replace attendedchurch=0 if q908d==0
replace attendedchurch=. if q908d==.
label var attendedchurch "Attended religious activities in the past 7 days (=1)"

// Went to the Market (Y/N): q908e
gen went2market=1 if q908e>0
replace went2market=0 if q908e==0
replace went2market=. if q908e==.
label var went2market "Went to the market in the past 7 days (=1)"

*Note by Abed: I will add leaving village here since it is missing
// Left village (Y/N): q908f
gen left_village=1 if q908f>0
	replace left_village=0 if q908f==0
	replace left_village=. if q908f==.
	
tab left_village q908f
label var left_village "=1 if FR left village in past 7 days"

/*Note by Abed: I am not sure why socialdistanced_fr and stayedathome are not 
			dummies but I will create them again below */
			
// Left home (Y/N): q908a
gen left_home=1 if daysoutside>0
	replace left_home=0 if daysoutside==0
	replace left_home=. if daysoutside==.
	
tab left_home daysoutside
label var left_home "=1 if FR left home in the past 7 days"

// Left home (Y/N): q908c
gen no_distancing_days = 7 - q908c

gen not_kept_distance=1 if no_distancing_days>0
	replace not_kept_distance=0 if no_distancing_days==0
	replace not_kept_distance=. if no_distancing_days==.
	
tab not_kept_distance q908c
tab not_kept_distance no_distancing_days
label var not_kept_distance "=1 if FR didn't keep 2-m distance in the past 7 days"


							   ********
					******************************
		**********************************************************
************Additions by Abdulrazzak Tamim - Oct. 14th, 2020 **************
		**********************************************************
					******************************
							   ********

//So far, we have:
sum stayedathome daysoutside socialdistanced socialdistanced_fr socialgathering ///
	attendedchurch went2market left_village left_home not_kept_distance ///
	no_distancing_days, sep(10)

tab left_home q908a
tab socialgathering  q908b
tab not_kept_distance  q908c
tab attendedchurch  q908d
tab went2market q908e
tab left_village q908f

	replace socialgathering = 0 if left_home == 0
	replace not_kept_distance = 0 if left_home == 0
	replace attendedchurch = 0 if left_home == 0
	replace went2market = 0 if left_home == 0
	replace left_village = 0 if left_home == 0

tab left_home 
tab socialgathering  
tab not_kept_distance  
tab attendedchurch  
tab went2market 
tab left_village 

***************************************************************************************************************************
		/*I will now follow tables 19, 20, and 21 :)  

***** Titles and numbers from Table 19 in PAP - var names 

***** 19.1 Tested for COVID [Adults] ---------- test_covid_adult; num_test_covid_adult
***** 19.2 Tested for COVID [Children] -------- test_covid_child; num_test_covid_child
***** 19.3/4 Positive COVID results [hh] ------ pos_covid_hh
***** 19.5 Access to testing ------------------ test_unable
***** 19.6 COVID-19 symptoms ------------------ tot_covid_sympt
***** 19.7 COVID-19 symptom index ------------- covid_sympt_index
***** 19.8 Symptomatic hh members ------------- sympt_adult; tot_sympt_hh
***** 19.9 Symptomatic children --------------- sympt_child
***** 19.10 Symptom appearance ---------------- sympt_appear
***** 19.11 Recovery -------------------------- recover_sympt_fr
***** 19.12 Recovery [Household] -------------- recover_sympt_hh
***** 19.14 COVID behavior index -------------- covid_behav_index
***** 19.15 Risky behavior -------------------- tot_covid_activities 
***** 19.16 Healthcare visits ----------------- health_visits
***** 19.17 Seen by a health professional ----- seen_by_prof
***** 19.18 Healthcare expenditures ----------- health_exp
***** 19.19 Medicine expenditures ------------- medicine_exp
***** 19.20 Healthcare visits foregone -------- foregone_health_visits
***** 19.21 Perceievd discrimination ---------- denied_service
***** 19.22  Major health problems ------------ major_health; num_major_health
***** 19.24  Overall food consumtpion --------- overall_food_change
***** 19.25  Cereal consumtpion --------------- cereal_change
***** 19.26  Meat consumtpion ----------------- meat_change
***** 19.27 Children learning [# activities] -- learn_activities
***** 19.28 Children learning [time spent] ---- learn_time
***** 19.29 Child happiness ------------------- happy_child
***** 19.30 Child alertness ------------------- alert_child



THIS CONVERSION IS OUTDATED
/* Generating variable for Exchange rate from Jordan to USD. 
The rate has been used by XE exchange rates: 
https://www.xe.com/currencytables/?from=JOD&date=2020-08-18 */

gen exc_jd = 1.4104372355 
	label var exc_jd "Exchange rate for JOD/USD for Aug-2020 - Sep-2020"

/*Generating the variable for inflation using the CPI index. The average has
  been calculated by the Department of Statistics from the Kingdom of Jordan */
  
gen cpi_jd = 0.85 
	label var cpi_jd "CPI average in Jordan within the months of August and September"
	
/*Generating the variable for the PPP conversion rate using the most recent available
  data in 2019. Data has been made available by the World Bank and can be found
  here: https://data.worldbank.org/indicator/PA.NUS.PPPC.RF?locations=JO*/
 
gen ppp_jd = 0.42 
	label var ppp_jd "PPP conversion rate for Jordanian dinars in 2018"

	
*/

*****************************************
***** 19.1 Tested for COVID [Adults]*****
*****************************************

tab q8_1_03_who_1
tab q8_1_03_who_2
tab q8_1_03_who_3 

tab q8_1_03_who_2,nol
tab q8_1_03_who_3,nol

*Indicator if adult tested for COVID
gen test_covid_adult = (q8_1_03_who_1==1 | q8_1_03_who_2==1)	
	replace test_covid_adult = . if q8_1_03_who_1==. & q8_1_03_who_2==.
	replace test_covid_adult = 0 if q8_1_03==2  
	replace test_covid_adult = 1 if  q8_1_03c_1==2 
	/*q8_1_03c_1 comes from the first 144 cases*/

tab q8_1_03_who_1
tab q8_1_03_who_2
tab test_covid_adult 
label var test_covid_adult "=1 if any adult tested for COVID"

	
*Number of adults tested for COVID
tab q8_1_03a

gen num_test_covid_adult = q8_1_03a
	replace num_test_covid_adult = num_test_covid_adult + 1 if q8_1_03_who_1==1 
	replace num_test_covid_adult = num_test_covid_adult + 1 if q8_1_03c_1==2 
	replace num_test_covid_adult = 0 if  q8_1_03==2
		
tab num_test_covid_adult /*2154 are zero from q8_1_03 and 87 are >0 from q8_1_03a=2,241*/
label var num_test_covid_adult "# adults tested for COVID"

		
		
*******************************************
***** 19.2 Tested for COVID [Children]*****
*******************************************
		
*Indicator if child tested for COVID
gen test_covid_child = (q8_1_03_who_3==1)	
	replace test_covid_child = . if q8_1_03_who_3==.
	replace test_covid_child = 1 if q8_1_03c_2==2 
	replace test_covid_child = 0 if q8_1_03==2

tab q8_1_03_who_3
tab test_covid_child 
tab test_covid_child q8_1_03_who_3
label var test_covid_child "=1 if any child tested for COVID"


*Number of children tested for COVID
tab q8_1_03b

gen num_test_covid_child = q8_1_03b
	replace num_test_covid_child = num_test_covid_child + 1 if q8_1_03c_2==2
	replace num_test_covid_child = 0 if  q8_1_03==2
		
tab num_test_covid_child	
label var num_test_covid_child "# children tested for COVID"


 
*******************************************
***** 19.3/19.4 Positive COVID results [hh]*****
*******************************************

tab q8_1_03c

gen pos_covid_hh = q8_1_03c
	replace pos_covid_hh=0 if q8_1_03c_1==2 | q8_1_03c_2==2

sum pos_covid_hh q8_1_03c
label var pos_covid_hh "# hh members tested COVID-positive [among who tested for COVID]"



*********************************
***** 19.5 Access to testing*****
*********************************

tab q8_1_04
tab q8_1_04,nol

gen test_unable = .
	replace test_unable = 1 if q8_1_04==1
	replace test_unable = 0 if q8_1_04==2
	
su test_unable
ta test_unable
label var test_unable "=1 if tried to get tested but was unable to"



*********************************
***** 19.6 COVID-19 symptoms*****
*********************************

tab q8_1_01_a /*fever*/
	tab q8_1_01_a, nol
		
tab q8_1_01_b /*cough*/
	tab q8_1_01_b, nol

tab q8_1_01_c /*tired*/
	tab q8_1_01_c, nol

tab q8_1_01_d /*myalgia*/
	tab q8_1_01_d, nol

tab q8_1_01_e /*headache*/
	tab q8_1_01_e, nol	

tab q8_1_01f /*diarrhea*/
	tab q8_1_01f,nol

tab q8_1_01g /*breathing difficulty*/
	tab q8_1_01g, nol

tab q8_1_01h /*runny nose*/
	tab q8_1_01h, nol
	
tab q8_1_01i /*sore throat*/
	tab q8_1_01i, nol	
	
tab q8_1_01j /*pneumonia*/
	tab q8_1_01j, nol	

tab q8_1_01k /*smell loss*/
	tab q8_1_01k, nol
	
***************************************************************************
gen fever = (q8_1_01_a==1)
	replace fever = . if q8_1_01_a == .
	
tab fever q8_1_01_a
label var fever "=1 if FR experienced fever in the past 14 days"

***************************************************************************
gen cough = (q8_1_01_b==1)
	replace cough = . if q8_1_01_b == .
	
tab cough q8_1_01_b
label var cough "=1 if FR experienced cough in the past 14 days"

***************************************************************************
gen tired = (q8_1_01_c==1)
	replace tired = . if q8_1_01_c == .
	
tab tired q8_1_01_c
label var tired "=1 if FR was tired in the past 14 days"

***************************************************************************
gen myalgia = (q8_1_01_d==1)
	replace myalgia = . if q8_1_01_d == .
	
tab myalgia q8_1_01_d
label var myalgia "=1 if FR experienced myalgia in the past 14 days"

***************************************************************************
gen headache = (q8_1_01_e==1)
	replace headache = . if q8_1_01_e == .
	
tab headache q8_1_01_e
label var headache "=1 if FR had headache in the past 14 days"

***************************************************************************
gen diarrhea = (q8_1_01f==1)
	replace diarrhea = . if q8_1_01f == .
	
tab diarrhea q8_1_01f
label var diarrhea "=1 if FR experienced diarrhea in the past 14 days"

***************************************************************************
gen breath_diff = (q8_1_01g==1)
	replace breath_diff = . if q8_1_01g == .
	
tab breath_diff q8_1_01g
label var breath_diff "=1 if FR experienced breathing difficulty in the past 14 days"

***************************************************************************
gen runny_nose = (q8_1_01h==1)
	replace runny_nose = . if q8_1_01h == .
	
tab runny_nose q8_1_01h
label var runny_nose "=1 if FR had runny nose in the past 14 days"

***************************************************************************
gen sore_throat = (q8_1_01i==1)
	replace sore_throat = . if q8_1_01i == .
	
tab sore_throat q8_1_01i
label var sore_throat "=1 if FR had sore throat in the past 14 days"

***************************************************************************
gen pneumonia = (q8_1_01j==1)
	replace pneumonia = . if q8_1_01j == .
	
tab pneumonia q8_1_01j
label var pneumonia "=1 if FR experienced pneumonia in the past 14 days"

***************************************************************************
gen smell_loss = (q8_1_01k==1)
	replace smell_loss = . if q8_1_01k == .
	
tab smell_loss q8_1_01k
label var smell_loss "=1 if FR experienced smell loss in the past 14 days"

***************************************************************************

egen tot_covid_sympt = rowtotal(fever cough tired myalgia headache diarrhea ///
	breath_diff runny_nose sore_throat pneumonia smell_loss), missing

label var tot_covid_sympt "sum of COVID symptoms experienced by FR in past 14 days"
tab tot_covid_sympt 

count if fever==. & cough==. & tired==. & myalgia==. & headache==. & diarrhea==. & ///
	breath_diff==. & runny_nose==. & sore_throat==. & pneumonia==. & smell_loss==. 
		/*# obs. is 0, so tot obs. 2312 seems good*/



**************************************
***** 19.7 COVID-19 symptom index*****
**************************************

gen covid_pos_bi = .
	replace covid_pos_bi=0 if pos_covid_hh==0 & pos_covid_hh!=.
	replace covid_pos_bi=1 if pos_covid_hh>0 & pos_covid_hh!=.
	
label var covid_pos_bi "=1 if there are hh members tested COVID-positive [among who tested]"

***FLEX index

local sym_index covid_pos_bi tot_covid_sympt
	foreach x in `sym_index' {
		sum `x' if Ass=="In-FControl" 
		local r(mean)
        local r(sd)
		gen `x'_norm = (`x'-`r(mean)')/`r(sd)'
		sum `x'_norm
	}


egen covid_sympt_index_flex = rowtotal(covid_pos_bi_norm tot_covid_sympt_norm), missing
sum covid_sympt_index_flex if Ass=="In-FControl" 
local r(mean)
local r(sd)

gen covid_sympt_index_flex_norm = (covid_sympt_index_flex - `r(mean)')/`r(sd)'
	sum covid_sympt_index_flex_norm if Ass=="In-FControl"  
	drop covid_sympt_index_flex
	rename covid_sympt_index_flex_norm covid_sympt_index_flex
	label var covid_sympt_index_flex "COVID Symptoms index FLEX (testing +ve and sum of symptoms)"
	sum covid_sympt_index_flex covid_pos_bi_norm tot_covid_sympt_norm covid_pos_bi
	drop covid_pos_bi_norm tot_covid_sympt_norm

	tabstat covid_sympt_index_flex, by(Ass) stat(mean sd)

	
**RE index
local sym_index covid_pos_bi tot_covid_sympt
	foreach x in `sym_index' {
		sum `x' if Ass=="In-REControl" 
		local r(mean)
        local r(sd)
		gen `x'_norm = (`x'-`r(mean)')/`r(sd)'
		sum `x'_norm

	}


egen covid_sympt_index_re = rowtotal(covid_pos_bi_norm tot_covid_sympt_norm), missing
sum covid_sympt_index_re if Ass=="In-REControl" 
local r(mean)
local r(sd)

gen covid_sympt_index_re_norm = (covid_sympt_index_re - `r(mean)')/`r(sd)'
	sum covid_sympt_index_re_norm
	drop covid_sympt_index_re
	rename covid_sympt_index_re_norm covid_sympt_index_re
	label var covid_sympt_index_re "COVID Symptoms index RE (testing +ve and sum of symptoms)"
	sum covid_sympt_index_re covid_pos_bi_norm tot_covid_sympt_norm covid_pos_bi
	drop covid_pos_bi_norm tot_covid_sympt_norm

	tabstat covid_sympt_index_re, by(Ass) stat(mean sd)	
	
	
su covid_sympt_index_flex if Ass=="In-FControl" 
su covid_sympt_index_re	if Ass=="In-REControl" 

*all index
	foreach x in covid_pos_bi tot_covid_sympt {
		su `x' if Ass=="In-REControl" | Ass=="In-FControl" 
		g `x'_norm = (`x'-r(mean))/r(sd)
	}

egen covid_sympt_index_all = rowtotal(covid_pos_bi_norm tot_covid_sympt_norm), m
su covid_sympt_index_all if Ass=="In-REControl" | Ass=="In-FControl" 
replace covid_sympt_index_all = (covid_sympt_index_all - r(mean))/r(sd)
	

**************************************
***** 19.8 Symptomatic hh members*****
**************************************

tab q8_1_02 /*135 others in same hh had symptoms*/
tab q8_1_02_2a /*other adults*/
tab q8_1_02_2b /*children*/

ta q8_1_02_2a q8_1_02, m
ta q8_1_02_2b q8_1_02, m

//symptomatic adults (other than FR)
g sympt_adult = .
replace sympt_adult = 0 if q8_1_02==2
replace sympt_adult = q8_1_02_2a if q8_1_02_2a!=.
replace sympt_adult=. if hhsize==0 //no other adults

tab sympt_adult q8_1_02_2a
label var sympt_adult "total number of symptomatic adults in hh"

//symptomatic children
gen sympt_child = .
replace sympt_child = 0 if q8_1_02==2
replace sympt_child = q8_1_02_2b if q8_1_02_2b!=.
replace sympt_child = . if n_children==0 //no children

tab sympt_child q8_1_02_2b
label var sympt_child "total number of symptomatic children in hh"

//overall
egen tot_sympt_hh = rowtotal(sympt_adult sympt_child), missing
replace tot_sympt_hh = tot_sympt_hh + 1 if tot_covid_sympt !=0 &!mi(tot_covid_sympt) /* +1 for FR*/

tab tot_sympt_hh
label var tot_sympt_hh "total number of symptomatic individuals in hh"

ta sympt_adult q8_1_02, m
ta sympt_child q8_1_02, m
su sympt_adult sympt_child



************************************
***** 19.9 Symptomatic children*****
************************************

/*defined in 19.8 as sympt_child*/



***********************************
***** 19.10 Symptom appearance*****
***********************************

ta  q8_1_01a
	
gen sympt_appear = q8_1_01a

sum sympt_appear q8_1_01a
ta sympt_appear

replace sympt_appear=. if sympt_appear>120
	/*This was suggested by Sam since these days are unrealistic*/
	
label var sympt_appear "days before these symptoms first appear"
	
	


*************************
***** 19.11 Recovery*****
*************************

tab q8_1_01b
tab q8_1_01b, nol

gen recover_sympt_fr = (q8_1_01b==1)
	replace recover_sympt_fr = . if q8_1_01b==.
	
tab recover_sympt_fr q8_1_01b
label var recover_sympt_fr "=1 if FR was symptomatic and recovered"



*************************************
***** 19.12 Recovery [Household]*****
*************************************

tab q8_1_02_2c /*other hh members (adults/children)*/
tab q8_1_02_2c,nol

gen recover_sympt_hh = .
	replace recover_sympt_hh=0 if q8_1_02_2c==2 
	replace recover_sympt_hh=0 if q8_1_01b==2
	replace recover_sympt_hh=1 if q8_1_02_2c==1 | q8_1_01b==1
 
sum recover_sympt_hh q8_1_02_2c q8_1_01b
count if q8_1_01b==. & q8_1_02_2c!=. /*45, so total is 505 + 45 = 550*/
label var recover_sympt_hh "=1 if any hh members were symptomatic and recovered"



*************************************
***** 19.14 COVID behavior index*****
*************************************


tab left_home 
tab socialgathering	
tab not_kept_distance 
tab attendedchurch 
tab went2market 
tab left_village


***FLEX index
local actions left_home socialgathering not_kept_distance attendedchurch went2market left_village	
	foreach x in `actions' {
		sum `x' if Ass=="In-FControl" 
		local r(mean)
        local r(sd)
		gen `x'_norm = (`x'-`r(mean)')/`r(sd)'
		sum `x'_norm

	}

egen covid_behav_index_flex = rowtotal(left_home_norm socialgathering_norm not_kept_distance_norm ///
 attendedchurch_norm went2market_norm left_village_norm), missing
 
sum covid_behav_index_flex if Ass=="In-FControl" 
local r(mean)
local r(sd)

gen covid_behav_index_flex_norm = (covid_behav_index_flex - `r(mean)')/`r(sd)'
	sum covid_behav_index_flex_norm if Ass=="In-FControl" 
	
drop covid_behav_index_flex 
rename covid_behav_index_flex_norm covid_behav_index_flex
label var covid_behav_index_flex "FLEX COVID behavior index of 6 vars, where each =1 if FR was not cautious"

sum covid_behav_index_flex left_home_norm socialgathering_norm not_kept_distance_norm /// 
	attendedchurch_norm went2market_norm left_village_norm	

drop left_home_norm socialgathering_norm not_kept_distance_norm /// 
	attendedchurch_norm went2market_norm left_village_norm	
	/*since an indicator of 1 means an action against safety regulations, this
	index can be interpreted as larger values being bad, so to speak */
		
		
		
		
***RE index
local actions left_home socialgathering not_kept_distance attendedchurch went2market left_village	
	foreach x in `actions' {
		sum `x' if Ass=="In-REControl" 
		local r(mean)
        local r(sd)
		gen `x'_norm = (`x'-`r(mean)')/`r(sd)'
		sum `x'_norm

	}


egen covid_behav_index_re = rowtotal(left_home_norm socialgathering_norm not_kept_distance_norm ///
 attendedchurch_norm went2market_norm left_village_norm), missing
 
sum covid_behav_index_re if Ass=="In-REControl" 
local r(mean)
local r(sd)

gen covid_behav_index_re_norm = (covid_behav_index_re - `r(mean)')/`r(sd)'
	sum covid_behav_index_re_norm if Ass=="In-REControl" 
	
drop covid_behav_index_re
rename covid_behav_index_re_norm covid_behav_index_re
label var covid_behav_index_re "RE COVID behavior index of 6 vars, where each =1 if FR was not cautious"

sum covid_behav_index_re left_home_norm socialgathering_norm not_kept_distance_norm /// 
	attendedchurch_norm went2market_norm left_village_norm	

drop left_home_norm socialgathering_norm not_kept_distance_norm ///
 attendedchurch_norm went2market_norm left_village_norm
 
*all index
	foreach x in left_home socialgathering not_kept_distance attendedchurch went2market left_village {
		su `x' if Ass=="In-REControl" | Ass=="In-FControl" 
		g `x'_norm = (`x'-r(mean))/r(sd)
	}

egen covid_behav_index_all = rowtotal(left_home_norm socialgathering_norm not_kept_distance_norm ///
 attendedchurch_norm went2market_norm left_village_norm), m
su covid_behav_index_all if Ass=="In-REControl" | Ass=="In-FControl" 
replace covid_behav_index_all = (covid_behav_index_all - r(mean))/r(sd)
su covid_behav_index_all 

	
*******************************
***** 19.15 Risky behavior*****
*******************************	

gen tot_covid_activities = left_home + socialgathering + not_kept_distance + ///
	attendedchurch + went2market + left_village
	
tab tot_covid_activities
label var tot_covid_activities "Number of activities that increase risk of COVID"
	
count if q908a==7 & q908b==0 & q908c==7 & q908d==0 & q908e==0 & q908f==0
	/*things seem fine, no one followed ALL safety procedures*/
	
	
	
**********************************
***** 19.16 Healthcare visits*****
**********************************	
	
tab q8_1_05

gen health_visits = q8_1_05

tab health_visits 
label var health_visits "number of visits to hospital/clinic since March 15"
	
	
	
**********************************************
***** 19.17 Seen by a health professional*****
**********************************************		
	
tab q8_1_06
tab q8_1_06,nol
	
gen seen_by_prof = (q8_1_06==1)
	replace seen_by_prof = . if q8_1_06==.
		
tab seen_by_prof q8_1_06
label var seen_by_prof "=1 if FR wa seen by a medical professional"
	

	
****************************************
***** 19.18 Healthcare expenditures*****
****************************************
	
sum q8_1_06a

gen health_exp = q8_1_06a

sum health_exp q8_1_06a
label var health_exp "total expenses for medical care in dinars since COVID"

//Converting to PPP $ 
*gen health_exp_ppp = ((health_exp/exc_jd)*cpi_jd)/ppp_jd
gen health_exp_ppp = health_exp/$usd2jod_ppp2020
	label var health_exp_ppp "total expenses for medical care in USD PPP since COVID"
	

	
**************************************
***** 19.19 Medicine expenditures*****
**************************************

sum q8_1_06b

gen medicine_exp = q8_1_06b

sum medicine_exp q8_1_06b
label var medicine_exp "total expenses for medicines in dinars since COVID"

//Converting to PPP $ 
*gen medicine_exp_ppp = ((medicine_exp/exc_jd)*cpi_jd)/ppp_jd
gen medicine_exp_ppp = medicine_exp/$usd2jod_ppp2020
	label var medicine_exp_ppp "total expenses for medicines in USD PPP since COVID"
	

	
*******************************************
***** 19.20 Healthcare visits foregone*****
*******************************************
	
su q8_1_08

gen foregone_health_visits = q8_1_08

sum foregone_health_visits q8_1_08
label var foregone_health_visits "# times FR wanted to see Dr. but didn't since COVID"
	
	

*****************************************
***** 19.21 Perceieved discrimination*****
*****************************************	
	
tab q907
tab q907,nol

gen denied_service = (q907==1)
	replace denied_service=. if q907==.

tab denied_service q907
label var denied_service "=1 if FR felt denied service because of refugee status"
	
	
	
***************************************
***** 19.22  Major health problems*****
***************************************	

*Binary
	tab q8_1_10
	tab q8_1_10, nol
		
	gen major_health = (q8_1_10==1)
		replace major_health = . if q8_1_10==.
			
	tab q8_1_10 major_health
	label var major_health "=1 if FR faced a major health problem since October 2019"

*Number
	tab q8_1_10a 

	gen num_major_health = q8_1_10a
		replace num_major_health=0 if q8_1_10==2

	tab q8_1_10  num_major_health
	sum q8_1_10  num_major_health
	label var num_major_health "# of major health problems faced since October 2019"



****************************************
***** 19.23  Mental health outcomes*****
****************************************

/*Created by Sarah from Table 9*/



******************************************
***** 19.24  Overall food consumtpion*****
******************************************

/*Adapted from Sarah's code and modified*/

tab q6_1_03a
tab q6_1_03a,nol

recode q6_1_03*(2=0)(3=-1)

label define consumptionchange -1 "Consumption Decreased" 1 "Consumption Increased" 0 "No Change"
label values q6_1_03* consumptionchange

gen overall_food_change = q6_1_03a
	tab overall_food_change q6_1_03a
	label var overall_food_change "-1 food consumtpion decreased; 1 increased; 0 same"


	
************************************
***** 19.25  Cereal consumtpion*****
************************************

tab q6_1_03b
tab q6_1_03b,nol

gen cereal_change = q6_1_03b
	tab cereal_change q6_1_03b
	label var cereal_change "-1 cereal consumtpion decreased; 1 increased; 0 same"

	

*************************************
***** 19.26  Protein consumtpion*****
*************************************

tab q6_1_03c
tab q6_1_03c,nol

gen meat_change = q6_1_03c
	tab meat_change q6_1_03c
	label var meat_change "-1 meat consumtpion decreased; 1 increased; 0 same"
	
	
	
*************************************************
***** 19.27 Children learning [# activities]*****
*************************************************	
	
tab q914_1 /*no learning-related activity*/
tab q914_1,nol
	
tab q914_2 /*Use self-prepared materials*/
tab q914_2,nol

tab q914_3 /*Homework/teaching materials prepared/assigned by the school */
tab q914_3,nol
	
tab q914_4 /*E-learning modules prepared by the school */
tab q914_4,nol

tab q914_5 /*Free online/mobile educational videos */
tab q914_5,nol

tab q914_6 /*Educational radio programs */
tab q914_6,nol

tab q914_7 /*Reading school textbooks */
tab q914_7,nol

tab q914_8 /*Reading for pleasure */
tab q914_8,nol

tab q914__96 /*Other: 33 obs. */
tab q914__96,nol	

	
tab q914_other
//edit q914_other if q914_other!= " "

gen other_activity = q914__96
	replace other_activity = 0 if q914_other=="لا يوجد اطفال في المدرسه" ///
	| q914_other=="لا يوجد اطفال في المدارس" | q914_other=="لا ينطبق اطفالها لا يذهبون الى المدرسه" ///
	| q914_other=="لا يوجد اطفال في المدرسه ولا يوجد طرق للتعلم" | q914_other=="لا ينطبق اطفاله صغار" /// 
 	| q914_other=="لا ينطبق اطفاله صغار"  

	tab other_activity

egen learn_activities = rowtotal (q914_2 q914_3 q914_4 q914_5 q914_6 q914_7 q914_8 ///
	other_activity), missing
	
tab learn_activities
label var learn_activities "number of learning-related activities in last 24 hrs"

gen learn_act_bi = .
	replace learn_act_bi = 0 if q914_1==1 & q914_1!=.
	replace learn_act_bi = 1 if q914_1==0 & q914_1!=.
	
ta learn_act_bi
ta learn_act_bi q914_1
label var learn_act_bi "=1 if children did any learninging activity in last 24 hrs"

ta learn_activities learn_act_bi
su learn_activities learn_act_bi

//edit q914_other if learn_activities==0 & learn_act_bi==1

replace learn_activities=. if q914_other=="لا ينطبق اطفالها لا يذهبون الى المدرسه" ///
	| q914_other=="لا ينطبق اطفاله صغار" | q914_other=="لا ينطبق اطفاله صغار"  

replace learn_act_bi=. if q914_other=="لا ينطبق اطفالها لا يذهبون الى المدرسه" ///
	| q914_other=="لا ينطبق اطفاله صغار" | q914_other=="لا ينطبق اطفاله صغار"

replace learn_act_bi=0 if q914_other=="لا يوجد اطفال في المدرسه" | /// 
q914_other=="لا يوجد اطفال في المدارس" | q914_other=="لا يوجد اطفال في المدرسه ولا يوجد طرق للتعلم" 
	
	ta learn_activities learn_act_bi
	
	

//Gen Oldest Child
**gen oldestchildage

forval i=1/17 {
g age5to18_`i' = q405_`i'>=5 & q405_`i'<=18
}

egen N5to18 = rowtotal(age5to18_*)
gen has5to18= N5to18>0
replace has5to18=. if N5to18==.


//For School-Age Children
gen learn_activities_5to18=.
replace learn_activities_5to18=learn_activities if has5to18==1

	
	
***********************************************
***** 19.28 Children learning [time spent]*****
***********************************************

tab q914b
tab q914c

egen learn_time = rowmean(q914b q914c)

sum learn_time q914b q914c

label var learn_time "average hours children spent on learning activities in past 24 hours"

gen  learn_time_high = q914b 
	label var learn_time_high "Most hours child spent on learning activities in past 24 hours"
	
gen  learn_time_low = q914c
	label var learn_time_low "Least hours child spent on learning activities in past 24 hours"


gen learn_time_5to18=.
replace learn_time_5to18=learn_time if has5to18==1

	
	
********************************
***** 19.29 Child happiness*****
********************************

tab q915a

gen happy_child = q915a

tab happy_child q915a
label var happy_child "1-sad child; 7-happy"



********************************
***** 19.30 Child alertness*****
********************************

tab q915b
gen alert_child = q915b

tab alert_child q915b
label var alert_child "1-tired child; 7-alert"
su alert_child if regex(Assign,"FControl")
g alert_child_flex = (alert_child-r(mean))/r(sd) if regex(Assign,"F")
su alert_child if regex(Assign,"REControl")
g alert_child_re = (alert_child-r(mean))/r(sd) if regex(Assign,"RE")
tabstat alert_child_flex alert_child_re, by(Assign)



******************************************************************************

/*
	Moving on to Table 20 :)

***** Titles and numbers from Table 20 in PAP --- var names (11 vars)

***** 20.1 Avrg hrs worked [before lockdown] ---- hr_work_pre_covid
***** 20.2 Avrg hrs worked [during lockdown] ---- hr_work_at_covid
***** 20.3 Avrg hrs worked [after lockdown] ----- hr_work_aft_covid
***** 20.4 Avrg income [before lockdown] -------- income_pre_covid
***** 20.5 Avrg income [during lockdown] -------- income_at_covid
***** 20.6 Avrg income [after lockdown] --------- income_aft_covid
***** 20.7 Assets sold [before lockdown] -------- asset_sold_pre_covid
***** 20.8 Assets sold [during lockdown] -------- asset_sold_at_covid
***** 20.9 Assets sold [during lockdown] -------- asset_sold_aft_covid
***** 20.10 Work missed ------------------------- miss_days_covid
***** 20.11 Jobs lost --------------------------- jobloss

*/


*************************************************
***** 20.1 Avrg hrs worked [before lockdown]*****
*************************************************

sum q6_2_02

gen hr_work_pre_covid = q6_2_02

sum hr_work_pre_covid q6_2_02
label var hr_work_pre_covid "Weekly hours worked by adults prior to COVID restrictions"


*************************************************
***** 20.2 Avrg hrs worked [during lockdown]*****
*************************************************

sum q6_2_03


gen hr_work_at_covid = q6_2_03
replace hr_work_at_covid=0 if q6_2_01==3 /*no work*/

sum hr_work_at_covid q6_2_03
label var hr_work_at_covid "Weekly hours worked by adults during COVID restrictions"



************************************************
***** 20.3 Avrg hrs worked [after lockdown]*****
************************************************

sum q6_2_04


gen hr_work_aft_covid = q6_2_04
replace hr_work_aft_covid=0 if q6_2_01==3 /*no work*/

sum hr_work_aft_covid q6_2_04
label var hr_work_aft_covid "Weekly hours worked by adults after COVID restrictions"



*********************************************
***** 20.4 Avrg income [before lockdown]*****
*********************************************

sum q6_2_02a 

gen income_pre_covid = q6_2_02a

sum income_pre_covid q6_2_02a
label var income_pre_covid "Weekly income of all adult hh members in dinars before lockdown"

//Converting to PPP $
*gen income_pre_covid_ppp = ((income_pre_covid/exc_jd)*cpi_jd)/ppp_jd
gen income_pre_covid_ppp = income_pre_covid/$usd2jod_ppp2020
	label var income_pre_covid_ppp "Weekly income of all adult hh members in USD PPP before lockdown"



*********************************************
***** 20.5 Avrg income [during lockdown]*****
*********************************************

sum q6_2_03a 

gen income_at_covid = q6_2_03a

sum income_at_covid q6_2_03a
label var income_at_covid "Weekly income of all adult hh members in dinars during lockdown"

//Converting to PPP $
*gen income_at_covid_ppp = ((income_at_covid/exc_jd)*cpi_jd)/ppp_jd
gen income_at_covid_ppp = income_at_covid/$usd2jod_ppp2020
	label var income_at_covid_ppp "Weekly income of all adult hh members in USD PPP during lockdown"



********************************************
***** 20.6 Avrg income [after lockdown]*****
********************************************

sum q6_2_04a 

gen income_aft_covid = q6_2_04a

sum income_aft_covid q6_2_04a
label var income_aft_covid "Weekly income of all adult hh members in dinars after lockdown"

//Converting to PPP $
*gen income_aft_covid_ppp = ((income_aft_covid/exc_jd)*cpi_jd)/ppp_jd
gen income_aft_covid_ppp = income_aft_covid/$usd2jod_ppp2020
	label var income_aft_covid_ppp "Weekly income of all adult hh members in USD PPP after lockdown"



*********************************************
***** 20.7 Assets sold [before lockdown]*****
*********************************************

tab q6_2_12 

gen asset_sold_pre_covid = 1
	replace asset_sold_pre_covid = 0 if q6_2_12=="1"
	replace asset_sold_pre_covid = . if q6_2_12==" " | q6_2_12=="-96"
	
sum asset_sold_pre_covid q6_2_12
tab asset_sold_pre_covid q6_2_12
label var asset_sold_pre_covid "=1 if hh sold assets before lockdown or rented out dwelling"
 

 
*********************************************
***** 20.8 Assets sold [during lockdown]*****
*********************************************

tab q6_2_13 

gen asset_sold_at_covid = 1
	replace asset_sold_at_covid = 0 if q6_2_13=="1"
	replace asset_sold_at_covid = . if q6_2_13==" " | q6_2_13=="-96"
	
sum asset_sold_at_covid q6_2_13
tab asset_sold_at_covid q6_2_13
label var asset_sold_at_covid "=1 if hh sold assets during lockdown or rented out dwelling"



*********************************************
***** 20.9 Assets sold [during lockdown]*****
*********************************************

tab q6_2_14 

gen asset_sold_aft_covid = 1
	replace asset_sold_aft_covid = 0 if q6_2_14=="1"
	replace asset_sold_aft_covid = . if q6_2_14==" " | q6_2_14=="-96"
	
sum asset_sold_aft_covid q6_2_14
tab asset_sold_aft_covid q6_2_14
label var asset_sold_aft_covid "=1 if hh sold assets after lockdown or rented out dwelling"



****************************
***** 20.10 Work missed*****
****************************

sum q8_1_07
gen miss_days_covid = q8_1_07

sum miss_days_covid q8_1_07
label var miss_days_covid "days of work missed due to poor health since COVID"



**************************
***** 20.11 Jobs lost*****
**************************

tab q6_2_01
tab q6_2_01,nol

gen jobloss = (q6_2_01==1)
	replace jobloss=. if q6_2_01==.
	
sum jobloss q6_2_01
tab jobloss q6_2_01
label var jobloss "=1 if any adult hh member lost their job during/after lockdown"

gen jobloss2 = jobloss
	replace jobloss2=. if q6_2_01==3
	
label var jobloss2 "job loss indicator but for who had a job pre-COVID only"


******************************************************************************
/*
	Finally, Table 21! 

***** Titles and numbers from Table 20 in PAP --- var names (12 vars)

***** 21.1 Loans taken pre-lockdown [Log] ------- loan_2020; loan_pre_covid; log_loan_pre_covid
***** 21.2 Loans taken during lockdown [Log] ---- loan_at_covid; log_loan_at_covid
***** 21.3 Loans taken after lockdown [Log] ----- loan_aft_covid; log_loan_aft_covid
***** 21.4 Loans given before lockdown [Log] ---- loan_aft_covid; log_loan_aft_covid
***** 21.5 Loans given during lockdown [Log] ---- give_loan_at_covid; log_give_loan_at
***** 21.6 Loans after during lockdown [Log] ---- give_loan_aft_covid; log_give_loan_aft

*/


**********************************************
***** 21.1 Loans taken pre-lockdown [Log]*****
**********************************************

tab q6_2_01a /*have you taken any loan in 2020? This is a filter question*/
tab q6_2_01a,nol

*Binary

	tab q6_2_05
	tab q6_2_05,nol
	sum q6_2_05a

	gen loan_pre_covid = (q6_2_05==1)
		replace loan_pre_covid=. if q6_2_05==.
		replace loan_pre_covid=0 if q6_2_01a==2

	tab loan_pre_covid q6_2_05
	sum loan_pre_covid q6_2_05
	label var loan_pre_covid "=1 if FR took loan from bank/lender/friend before lockdown"

	
*Amount

	gen log_loan_pre_covid = log(q6_2_05a) 

	sum log_loan_pre_covid q6_2_05a
	label var log_loan_pre_covid "log of amount of loan taken before lockdown in dinars"

	

*************************************************
***** 21.2 Loans taken during lockdown [Log]*****
*************************************************

*Binary

	tab q6_2_06
	tab q6_2_06,nol
	sum q6_2_06a

	gen loan_at_covid = (q6_2_06==1)
		replace loan_at_covid=. if q6_2_06==.
		replace loan_at_covid=0 if q6_2_01a==2

	tab loan_at_covid q6_2_06
	sum loan_at_covid q6_2_06
	label var loan_at_covid "=1 if FR took loan from bank/lender/friend during lockdown"

	
*Amount

	gen log_loan_at_covid = log(q6_2_06a) 

	sum log_loan_at_covid q6_2_06
	label var log_loan_at_covid "log of amount of loan taken during lockdown in dinars"



************************************************
***** 21.3 Loans taken after lockdown [Log]*****
************************************************

*Binary

	tab q6_2_07
	tab q6_2_07,nol
	sum q6_2_07a

	gen loan_aft_covid = (q6_2_07==1)
		replace loan_aft_covid=. if q6_2_07==.
		replace loan_aft_covid=0 if q6_2_01a==2

	tab loan_aft_covid q6_2_07
	sum loan_aft_covid q6_2_07
	label var loan_aft_covid "=1 if FR took loan from bank/lender/friend after lockdown"

	
*Amount

	gen log_loan_aft_covid = log(q6_2_07a) 

	sum log_loan_aft_covid q6_2_07a
	label var log_loan_aft_covid "log of amount of loan taken after lockdown in dinars"


************************************************
***** 21.4 Loans given before lockdown [Log]*****
************************************************

tab q6_2_08 /*have you given any loan in 2020? This is a filter question*/

sum q6_2_09 q6_2_09b

*Binary
tab q6_2_09
tab q6_2_09,nol
sum q6_2_09b

gen give_loan_pre_covid = (q6_2_09==1)
		replace give_loan_pre_covid=. if q6_2_09==.
		replace give_loan_pre_covid=0 if q6_2_08==2

	tab give_loan_pre_covid q6_2_09
	sum give_loan_pre_covid q6_2_09
	label var give_loan_pre_covid "=1 if FR lent someone outside hh before lockdown"

	
*Amount 		/*only 13 obs.*/

	gen log_give_loan_pre = log(q6_2_09b) 

	sum log_give_loan_pre q6_2_09b
	label var log_give_loan_pre "log of amount lent before lockdown in dinars"

	
	
************************************************
***** 21.5 Loans given during lockdown [Log]*****
************************************************

*Binary		
tab q6_2_10		
tab q6_2_10,nol		
sum q6_2_10b		
		
gen give_loan_at_covid = (q6_2_10==1)		
		replace give_loan_at_covid=. if q6_2_10==.
		replace give_loan_at_covid=0 if q6_2_08==2
		
	tab give_loan_at_covid q6_2_10	
	sum give_loan_at_covid q6_2_10	
	label var give_loan_at_covid "=1 if FR lent someone outside hh during lockdown"	
		
		
*Amount			/*only 3 obs.*/	
		
	gen log_give_loan_at = log(q6_2_10b) 	
		
	sum log_give_loan_at q6_2_10b	
	label var log_give_loan_at "log of amount lent during lockdown in dinars"	

	

*************************************************
***** 21.6 Loans after during lockdown [Log]*****
*************************************************

*Binary		
tab q6_2_11		
tab q6_2_11,nol		
sum q6_2_11b		
		
gen give_loan_aft_covid = (q6_2_11==1)		
		replace give_loan_aft_covid=. if q6_2_11==.
		replace give_loan_aft_covid=0 if q6_2_08==2
		
	tab give_loan_aft_covid q6_2_11	
	sum give_loan_aft_covid q6_2_11	
	label var give_loan_aft_covid "=1 if FR lent someone outside hh after lockdown"	
		
		
*Amount		/*only 4 obs.*/
		
	gen log_give_loan_aft = log(q6_2_11b) 	
		
	sum log_give_loan_aft q6_2_11b	
	label var log_give_loan_aft "log of amount lent after lockdown in dinars"	



******************************************************************************
su covid_sympt_index_re covid_behav_index_re if Ass=="In-REControl" & receivere==0
su covid_sympt_index_flex covid_behav_index_flex if Ass=="In-FControl" & receiveflex==0

sum test_covid_adult num_test_covid_adult test_covid_child num_test_covid_child /// 
	pos_covid_hh test_unable tot_covid_sympt covid_sympt_index* sympt_adult tot_sympt_hh /// 
	sympt_child sympt_appear recover_sympt_fr recover_sympt_hh covid_behav_index* /// 
	tot_covid_activities health_visits seen_by_prof health_exp_ppp medicine_exp_ppp /// 
	foregone_health_visits denied_service major_health num_major_health overall_food_change /// 
	cereal_change meat_change learn_activities learn_time /// 
	happy_child alert_child, sep(10)

sum hr_work_pre_covid hr_work_at_covid hr_work_aft_covid income_pre_covid_ppp ///
	income_at_covid_ppp income_aft_covid_ppp asset_sold_pre_covid asset_sold_at_covid ///
	asset_sold_aft_covid miss_days_covid jobloss , sep(10)
 
sum loan_pre_covid log_loan_pre_covid loan_at_covid log_loan_at_covid /// 
	loan_aft_covid log_loan_aft_covid give_loan_pre_covid log_give_loan_pre /// 
	give_loan_at_covid log_give_loan_at give_loan_aft_covid log_give_loan_aft, sep(10)
	
sum covid_pos_bi tot_covid_sympt left_home socialgathering /// 
not_kept_distance attendedchurch went2market left_village

 
 
des test_covid_adult num_test_covid_adult test_covid_child num_test_covid_child /// 
	pos_covid_hh test_unable tot_covid_sympt covid_sympt_index* sympt_adult tot_sympt_hh /// 
	sympt_child sympt_appear recover_sympt_fr recover_sympt_hh covid_behav_index* /// 
	tot_covid_activities health_visits seen_by_prof health_exp_ppp medicine_exp_ppp /// 
	foregone_health_visits denied_service major_health num_major_health overall_food_change /// 
	cereal_change meat_change learn_activities learn_time /// 
	happy_child alert_child

des hr_work_pre_covid hr_work_at_covid hr_work_aft_covid income_pre_covid_ppp ///
	income_at_covid_ppp income_aft_covid_ppp asset_sold_pre_covid asset_sold_at_covid ///
	asset_sold_aft_covid miss_days_covid jobloss 
 
des loan_pre_covid log_loan_pre_covid loan_at_covid log_loan_at_covid /// 
	loan_aft_covid log_loan_aft_covid give_loan_pre_covid log_give_loan_pre /// 
	give_loan_at_covid log_give_loan_at give_loan_aft_covid log_give_loan_aft
 
des covid_pos_bi tot_covid_sympt left_home socialgathering /// 
not_kept_distance attendedchurch went2market left_village

keep test_covid_adult num_test_covid_adult test_covid_child num_test_covid_child /// 
	pos_covid_hh test_unable tot_covid_sympt covid_sympt_index* sympt_adult tot_sympt_hh /// 
	sympt_child sympt_appear recover_sympt_fr recover_sympt_hh covid_behav_index* /// 
	tot_covid_activities health_visits seen_by_prof health_exp_ppp medicine_exp_ppp /// 
	foregone_health_visits denied_service major_health num_major_health overall_food_change /// 
	cereal_change meat_change learn_activities* learn_time* happy_child alert_child* /// 
	hr_work_pre_covid hr_work_at_covid hr_work_aft_covid income_pre_covid_ppp ///
	income_at_covid_ppp income_aft_covid_ppp asset_sold_pre_covid asset_sold_at_covid ///
	asset_sold_aft_covid miss_days_covid jobloss jobloss2 loan_pre_covid /// 
	log_loan_pre_covid loan_at_covid log_loan_at_covid /// 
	loan_aft_covid log_loan_aft_covid give_loan_pre_covid log_give_loan_pre /// 
	give_loan_at_covid log_give_loan_at give_loan_aft_covid log_give_loan_aft /// 
	covid_pos_bi tot_covid_sympt left_home socialgathering ///
	not_kept_distance attendedchurch went2market left_village learn_act_bi IID /// 
	q6_2_05a q6_2_06a q6_2_07a q6_2_09b q6_2_10b q6_2_11b

 
 
 save "$dr/Phone Survey/PS_T19_20_21_COVID.dta", replace


